@@ -1,20 +1,13 @@
-from __future__ import unicode_literals
-
 import datetime
 
 import pytz
 
-from moto.packages.boto.ec2.elb.attributes import (
-    LbAttributes,
-    ConnectionSettingAttribute,
-    ConnectionDrainingAttribute,
-    AccessLogAttribute,
-    CrossZoneLoadBalancingAttribute,
-)
-from moto.packages.boto.ec2.elb.policies import Policies, OtherPolicy
-from moto.compat import OrderedDict
+from collections import OrderedDict
 from moto.core import BaseBackend, BaseModel, CloudFormationModel
+from moto.core.utils import BackendDict
 from moto.ec2.models import ec2_backends
+from moto.ec2.exceptions import InvalidInstanceIdError
+from uuid import uuid4
 from .exceptions import (
     BadHealthCheckDefinition,
     DuplicateLoadBalancerName,
@@ -22,8 +15,11 @@ from .exceptions import (
     EmptyListenersError,
     InvalidSecurityGroupError,
     LoadBalancerNotFoundError,
+    PolicyNotFoundError,
     TooManyTagsError,
+    CertificateNotFoundException,
 )
+from .policies import AppCookieStickinessPolicy, LbCookieStickinessPolicy, OtherPolicy
 
 
 class FakeHealthCheck(BaseModel):
@@ -75,27 +71,26 @@ class FakeLoadBalancer(CloudFormationModel):
         name,
         zones,
         ports,
-        scheme="internet-facing",
+        scheme=None,
         vpc_id=None,
         subnets=None,
         security_groups=None,
+        elb_backend=None,
     ):
         self.name = name
         self.health_check = None
-        self.instance_ids = []
+        self.instance_sparse_ids = []
+        self.instance_autoscaling_ids = []
         self.zones = zones
         self.listeners = []
         self.backends = []
         self.created_time = datetime.datetime.now(pytz.utc)
-        self.scheme = scheme
+        self.scheme = scheme or "internet-facing"
         self.attributes = FakeLoadBalancer.get_default_attributes()
-        self.policies = Policies()
-        self.policies.other_policies = []
-        self.policies.app_cookie_stickiness_policies = []
-        self.policies.lb_cookie_stickiness_policies = []
+        self.policies = []
         self.security_groups = security_groups or []
         self.subnets = subnets or []
-        self.vpc_id = vpc_id or "vpc-56e10e3d"
+        self.vpc_id = vpc_id
         self.tags = {}
         self.dns_name = "%s.us-east-1.elb.amazonaws.com" % (name)
 
@@ -110,6 +105,14 @@ class FakeLoadBalancer(CloudFormationModel):
                     "ssl_certificate_id", port.get("SSLCertificateId")
                 ),
             )
+            if (
+                listener.ssl_certificate_id
+                and not listener.ssl_certificate_id.startswith("arn:aws:iam:")
+            ):
+                elb_backend._register_certificate(
+                    listener.ssl_certificate_id, self.dns_name
+                )
+
             self.listeners.append(listener)
 
             # it is unclear per the AWS documentation as to when or how backend
@@ -119,6 +122,11 @@ class FakeLoadBalancer(CloudFormationModel):
             )
             self.backends.append(backend)
 
+    @property
+    def instance_ids(self):
+        """Return all the instances attached to the ELB"""
+        return self.instance_sparse_ids + self.instance_autoscaling_ids
+
     @staticmethod
     def cloudformation_name_type():
         return "LoadBalancerName"
@@ -130,7 +138,7 @@ class FakeLoadBalancer(CloudFormationModel):
 
     @classmethod
     def create_from_cloudformation_json(
-        cls, resource_name, cloudformation_json, region_name
+        cls, resource_name, cloudformation_json, region_name, **kwargs
     ):
         properties = cloudformation_json["Properties"]
 
@@ -201,6 +209,16 @@ class FakeLoadBalancer(CloudFormationModel):
     def physical_resource_id(self):
         return self.name
 
+    @classmethod
+    def has_cfn_attr(cls, attr):
+        return attr in [
+            "CanonicalHostedZoneName",
+            "CanonicalHostedZoneNameID",
+            "DNSName",
+            "SourceSecurityGroup.GroupName",
+            "SourceSecurityGroup.OwnerAlias",
+        ]
+
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
 
@@ -226,23 +244,11 @@ class FakeLoadBalancer(CloudFormationModel):
 
     @classmethod
     def get_default_attributes(cls):
-        attributes = LbAttributes()
-
-        cross_zone_load_balancing = CrossZoneLoadBalancingAttribute()
-        cross_zone_load_balancing.enabled = False
-        attributes.cross_zone_load_balancing = cross_zone_load_balancing
-
-        connection_draining = ConnectionDrainingAttribute()
-        connection_draining.enabled = False
-        attributes.connection_draining = connection_draining
-
-        access_log = AccessLogAttribute()
-        access_log.enabled = False
-        attributes.access_log = access_log
-
-        connection_settings = ConnectionSettingAttribute()
-        connection_settings.idle_timeout = 60
-        attributes.connecting_settings = connection_settings
+        attributes = dict()
+        attributes["cross_zone_load_balancing"] = {"enabled": False}
+        attributes["connection_draining"] = {"enabled": False}
+        attributes["access_log"] = {"enabled": False}
+        attributes["connection_settings"] = {"idle_timeout": 60}
 
         return attributes
 
@@ -259,20 +265,15 @@ class FakeLoadBalancer(CloudFormationModel):
             del self.tags[key]
 
     def delete(self, region):
-        """ Not exposed as part of the ELB API - used for CloudFormation. """
+        """Not exposed as part of the ELB API - used for CloudFormation."""
         elb_backends[region].delete_load_balancer(self.name)
 
 
 class ELBBackend(BaseBackend):
-    def __init__(self, region_name=None):
-        self.region_name = region_name
+    def __init__(self, region_name, account_id):
+        super().__init__(region_name, account_id)
         self.load_balancers = OrderedDict()
 
-    def reset(self):
-        region_name = self.region_name
-        self.__dict__ = {}
-        self.__init__(region_name)
-
     def create_load_balancer(
         self,
         name,
@@ -287,12 +288,24 @@ class ELBBackend(BaseBackend):
         if subnets:
             subnet = ec2_backend.get_subnet(subnets[0])
             vpc_id = subnet.vpc_id
+        elif zones:
+            subnets = [
+                ec2_backend.get_default_subnet(availability_zone=zone).id
+                for zone in zones
+            ]
+            subnet = ec2_backend.get_subnet(subnets[0])
+            vpc_id = subnet.vpc_id
         if name in self.load_balancers:
             raise DuplicateLoadBalancerName(name)
         if not ports:
             raise EmptyListenersError()
         if not security_groups:
-            security_groups = []
+            sg = ec2_backend.create_security_group(
+                name=f"default_elb_{uuid4()}",
+                description="ELB created security group used when no security group is specified during ELB creation - modifications could impact traffic to future ELBs",
+                vpc_id=vpc_id,
+            )
+            security_groups = [sg.id]
         for security_group in security_groups:
             if ec2_backend.get_security_group_from_id(security_group) is None:
                 raise InvalidSecurityGroupError()
@@ -304,6 +317,7 @@ class ELBBackend(BaseBackend):
             subnets=subnets,
             security_groups=security_groups,
             vpc_id=vpc_id,
+            elb_backend=self,
         )
         self.load_balancers[name] = new_load_balancer
         return new_load_balancer
@@ -318,7 +332,7 @@ class ELBBackend(BaseBackend):
                 ssl_certificate_id = port.get("ssl_certificate_id")
                 for listener in balancer.listeners:
                     if lb_port == listener.load_balancer_port:
-                        if protocol != listener.protocol:
+                        if protocol.lower() != listener.protocol.lower():
                             raise DuplicateListenerError(name, lb_port)
                         if instance_port != listener.instance_port:
                             raise DuplicateListenerError(name, lb_port)
@@ -326,6 +340,12 @@ class ELBBackend(BaseBackend):
                             raise DuplicateListenerError(name, lb_port)
                         break
                 else:
+                    if ssl_certificate_id and not ssl_certificate_id.startswith(
+                        "arn:aws:iam::"
+                    ):
+                        self._register_certificate(
+                            ssl_certificate_id, balancer.dns_name
+                        )
                     balancer.listeners.append(
                         FakeListener(
                             lb_port, instance_port, protocol, ssl_certificate_id
@@ -347,6 +367,35 @@ class ELBBackend(BaseBackend):
         else:
             return balancers
 
+    def describe_load_balancer_policies(self, lb_name, policy_names):
+        lb = self.describe_load_balancers([lb_name])[0]
+        policies = lb.policies
+        if policy_names:
+            policies = [p for p in policies if p.policy_name in policy_names]
+            if len(policy_names) != len(policies):
+                raise PolicyNotFoundError()
+        return policies
+
+    def describe_instance_health(self, lb_name, instances):
+        provided_ids = [i["InstanceId"] for i in instances]
+        registered_ids = self.get_load_balancer(lb_name).instance_ids
+        ec2_backend = ec2_backends[self.region_name]
+        if len(provided_ids) == 0:
+            provided_ids = registered_ids
+        instances = []
+        for instance_id in provided_ids:
+            if instance_id not in registered_ids:
+                instances.append({"InstanceId": instance_id, "State": "Unknown"})
+            else:
+                try:
+                    instance = ec2_backend.get_instance(instance_id)
+                    state = "InService" if instance.is_running() else "OutOfService"
+                    instances.append({"InstanceId": instance_id, "State": state})
+                except InvalidInstanceIdError:
+                    pass
+
+        return instances
+
     def delete_load_balancer_listeners(self, name, ports):
         balancer = self.load_balancers.get(name, None)
         listeners = []
@@ -363,6 +412,10 @@ class ELBBackend(BaseBackend):
     def delete_load_balancer(self, load_balancer_name):
         self.load_balancers.pop(load_balancer_name, None)
 
+    def delete_load_balancer_policy(self, lb_name, policy_name):
+        lb = self.get_load_balancer(lb_name)
+        lb.policies = [p for p in lb.policies if p.policy_name != policy_name]
+
     def get_load_balancer(self, load_balancer_name):
         return self.load_balancers.get(load_balancer_name)
 
@@ -392,7 +445,7 @@ class ELBBackend(BaseBackend):
         load_balancer.health_check = check
         return check
 
-    def set_load_balancer_listener_sslcertificate(
+    def set_load_balancer_listener_ssl_certificate(
         self, name, lb_port, ssl_certificate_id
     ):
         balancer = self.load_balancers.get(name, None)
@@ -400,61 +453,94 @@ class ELBBackend(BaseBackend):
             for idx, listener in enumerate(balancer.listeners):
                 if lb_port == listener.load_balancer_port:
                     balancer.listeners[idx].ssl_certificate_id = ssl_certificate_id
-
+                    if ssl_certificate_id:
+                        self._register_certificate(
+                            ssl_certificate_id, balancer.dns_name
+                        )
         return balancer
 
-    def register_instances(self, load_balancer_name, instance_ids):
+    def register_instances(
+        self, load_balancer_name, instance_ids, from_autoscaling=False
+    ):
         load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.instance_ids.extend(instance_ids)
+        attr_name = (
+            "instance_sparse_ids"
+            if not from_autoscaling
+            else "instance_autoscaling_ids"
+        )
+
+        actual_instance_ids = getattr(load_balancer, attr_name)
+        actual_instance_ids.extend(instance_ids)
         return load_balancer
 
-    def deregister_instances(self, load_balancer_name, instance_ids):
+    def deregister_instances(
+        self, load_balancer_name, instance_ids, from_autoscaling=False
+    ):
         load_balancer = self.get_load_balancer(load_balancer_name)
+        attr_name = (
+            "instance_sparse_ids"
+            if not from_autoscaling
+            else "instance_autoscaling_ids"
+        )
+        actual_instance_ids = getattr(load_balancer, attr_name)
+
         new_instance_ids = [
             instance_id
-            for instance_id in load_balancer.instance_ids
+            for instance_id in actual_instance_ids
             if instance_id not in instance_ids
         ]
-        load_balancer.instance_ids = new_instance_ids
-        return load_balancer
 
-    def set_cross_zone_load_balancing_attribute(self, load_balancer_name, attribute):
-        load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.attributes.cross_zone_load_balancing = attribute
-        return load_balancer
-
-    def set_access_log_attribute(self, load_balancer_name, attribute):
-        load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.attributes.access_log = attribute
-        return load_balancer
-
-    def set_connection_draining_attribute(self, load_balancer_name, attribute):
-        load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.attributes.connection_draining = attribute
-        return load_balancer
-
-    def set_connection_settings_attribute(self, load_balancer_name, attribute):
-        load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.attributes.connecting_settings = attribute
-        return load_balancer
-
-    def create_lb_other_policy(self, load_balancer_name, other_policy):
-        load_balancer = self.get_load_balancer(load_balancer_name)
-        if other_policy.policy_name not in [
-            p.policy_name for p in load_balancer.policies.other_policies
-        ]:
-            load_balancer.policies.other_policies.append(other_policy)
+        setattr(load_balancer, attr_name, new_instance_ids)
 
         return load_balancer
 
-    def create_app_cookie_stickiness_policy(self, load_balancer_name, policy):
+    def modify_load_balancer_attributes(
+        self,
+        load_balancer_name,
+        cross_zone=None,
+        connection_settings=None,
+        connection_draining=None,
+        access_log=None,
+    ):
         load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.policies.app_cookie_stickiness_policies.append(policy)
+        if cross_zone:
+            load_balancer.attributes["cross_zone_load_balancing"] = cross_zone
+        if connection_settings:
+            load_balancer.attributes["connection_settings"] = connection_settings
+        if connection_draining:
+            load_balancer.attributes["connection_draining"] = connection_draining
+            if "timeout" not in connection_draining:
+                load_balancer.attributes["connection_draining"][
+                    "timeout"
+                ] = 300  # default
+        if access_log:
+            load_balancer.attributes["access_log"] = access_log
+
+    def create_lb_other_policy(
+        self, load_balancer_name, policy_name, policy_type_name, policy_attrs
+    ):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        if policy_name not in [p.policy_name for p in load_balancer.policies]:
+            load_balancer.policies.append(
+                OtherPolicy(policy_name, policy_type_name, policy_attrs)
+            )
+
         return load_balancer
 
-    def create_lb_cookie_stickiness_policy(self, load_balancer_name, policy):
+    def create_app_cookie_stickiness_policy(
+        self, load_balancer_name, policy_name, cookie_name
+    ):
         load_balancer = self.get_load_balancer(load_balancer_name)
-        load_balancer.policies.lb_cookie_stickiness_policies.append(policy)
+        policy = AppCookieStickinessPolicy(policy_name, cookie_name)
+        load_balancer.policies.append(policy)
+        return load_balancer
+
+    def create_lb_cookie_stickiness_policy(
+        self, load_balancer_name, policy_name, cookie_expiration_period
+    ):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        policy = LbCookieStickinessPolicy(policy_name, cookie_expiration_period)
+        load_balancer.policies.append(policy)
         return load_balancer
 
     def set_load_balancer_policies_of_backend_server(
@@ -474,16 +560,54 @@ class ELBBackend(BaseBackend):
     ):
         load_balancer = self.get_load_balancer(load_balancer_name)
         listener = [
-            l
-            for l in load_balancer.listeners
-            if int(l.load_balancer_port) == load_balancer_port
+            l_listener
+            for l_listener in load_balancer.listeners
+            if int(l_listener.load_balancer_port) == load_balancer_port
         ][0]
         listener_idx = load_balancer.listeners.index(listener)
         listener.policy_names = policies
         load_balancer.listeners[listener_idx] = listener
         return load_balancer
 
+    def _register_certificate(self, ssl_certificate_id, dns_name):
+        from moto.acm.models import acm_backends, AWSResourceNotFoundException
 
-elb_backends = {}
-for region in ec2_backends.keys():
-    elb_backends[region] = ELBBackend(region)
+        acm_backend = acm_backends[self.region_name]
+        try:
+            acm_backend.set_certificate_in_use_by(ssl_certificate_id, dns_name)
+        except AWSResourceNotFoundException:
+            raise CertificateNotFoundException()
+
+    def enable_availability_zones_for_load_balancer(
+        self, load_balancer_name, availability_zones
+    ):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        load_balancer.zones = sorted(
+            list(set(load_balancer.zones + availability_zones))
+        )
+        return load_balancer.zones
+
+    def disable_availability_zones_for_load_balancer(
+        self, load_balancer_name, availability_zones
+    ):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        load_balancer.zones = sorted(
+            list(
+                set([az for az in load_balancer.zones if az not in availability_zones])
+            )
+        )
+        return load_balancer.zones
+
+    def attach_load_balancer_to_subnets(self, load_balancer_name, subnets):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        load_balancer.subnets = list(set(load_balancer.subnets + subnets))
+        return load_balancer.subnets
+
+    def detach_load_balancer_from_subnets(self, load_balancer_name, subnets):
+        load_balancer = self.get_load_balancer(load_balancer_name)
+        load_balancer.subnets = [s for s in load_balancer.subnets if s not in subnets]
+        return load_balancer.subnets
+
+
+# Use the same regions as EC2
+elb_backends = BackendDict(ELBBackend, "ec2")
