@@ -1,33 +1,9 @@
-import boto
-from unittest import SkipTest
 from collections.abc import Iterable, Mapping
+from uuid import UUID
+
 from sure import assertion
 
 
-def version_tuple(v):
-    return tuple(map(int, (v.split("."))))
-
-
-# Note: See https://github.com/spulec/moto/issues/201 for why this is a
-# separate method.
-def skip_test():
-    raise SkipTest
-
-
-class requires_boto_gte(object):
-    """Decorator for requiring boto version greater than or equal to 'version'"""
-
-    def __init__(self, version):
-        self.version = version
-
-    def __call__(self, test):
-        boto_version = version_tuple(boto.__version__)
-        required = version_tuple(self.version)
-        if boto_version >= required:
-            return test
-        return skip_test
-
-
 @assertion
 def containing_item_with_attributes(context, **kwargs):
     contains = False
@@ -58,3 +34,12 @@ def match_dict(context, dict_value):
         assert k in context.obj, f"No such key '{k}' in {context.obj}"
         context.obj[k].should.equal(v)
     return True
+
+
+@assertion
+def match_uuid4(context):
+    try:
+        uuid_obj = UUID(context.obj, version=4)
+    except ValueError:
+        return False
+    return str(uuid_obj) == context.obj
