@@ -16,16 +16,19 @@ from unittest import SkipTest, mock
 
 
 RESOURCE_FOLDER = os.path.join(os.path.dirname(__file__), "resources")
-_GET_RESOURCE = lambda x: open(os.path.join(RESOURCE_FOLDER, x), "rb").read()
-CA_CRT = _GET_RESOURCE("ca.pem")
-CA_KEY = _GET_RESOURCE("ca.key")
-SERVER_CRT = _GET_RESOURCE("star_moto_com.pem")
+
+
+def get_resource(filename):
+    return open(os.path.join(RESOURCE_FOLDER, filename), "rb").read()
+
+
+CA_CRT = get_resource("ca.pem")
+CA_KEY = get_resource("ca.key")
+SERVER_CRT = get_resource("star_moto_com.pem")
 SERVER_COMMON_NAME = "*.moto.com"
-SERVER_CRT_BAD = _GET_RESOURCE("star_moto_com-bad.pem")
-SERVER_KEY = _GET_RESOURCE("star_moto_com.key")
-BAD_ARN = "arn:aws:acm:us-east-2:{}:certificate/_0000000-0000-0000-0000-000000000000".format(
-    ACCOUNT_ID
-)
+SERVER_CRT_BAD = get_resource("star_moto_com-bad.pem")
+SERVER_KEY = get_resource("star_moto_com.key")
+BAD_ARN = f"arn:aws:acm:us-east-2:{ACCOUNT_ID}:certificate/_0000000-0000-0000-0000-000000000000"
 
 
 def _import_cert(client):
@@ -57,7 +60,7 @@ def test_import_certificate_with_tags():
         Certificate=SERVER_CRT,
         PrivateKey=SERVER_KEY,
         CertificateChain=CA_CRT,
-        Tags=[{"Key": "Environment", "Value": "QA"}, {"Key": "KeyOnly"},],
+        Tags=[{"Key": "Environment", "Value": "QA"}, {"Key": "KeyOnly"}],
     )
     arn = resp["CertificateArn"]
 
@@ -157,13 +160,23 @@ def test_describe_certificate():
     client = boto3.client("acm", region_name="eu-central-1")
     arn = _import_cert(client)
 
-    resp = client.describe_certificate(CertificateArn=arn)
+    try:
+        resp = client.describe_certificate(CertificateArn=arn)
+    except OverflowError:
+        pytest.skip("This test requires 64-bit time_t")
     resp["Certificate"]["CertificateArn"].should.equal(arn)
     resp["Certificate"]["DomainName"].should.equal(SERVER_COMMON_NAME)
     resp["Certificate"]["Issuer"].should.equal("Moto")
     resp["Certificate"]["KeyAlgorithm"].should.equal("RSA_2048")
     resp["Certificate"]["Status"].should.equal("ISSUED")
     resp["Certificate"]["Type"].should.equal("IMPORTED")
+    resp["Certificate"].should.have.key("RenewalEligibility").equals("INELIGIBLE")
+    resp["Certificate"].should.have.key("Options")
+    resp["Certificate"].should.have.key("DomainValidationOptions").length_of(1)
+
+    validation_option = resp["Certificate"]["DomainValidationOptions"][0]
+    validation_option.should.have.key("DomainName").equals(SERVER_COMMON_NAME)
+    validation_option.shouldnt.have.key("ValidationDomain")
 
 
 @mock_acm
@@ -399,7 +412,7 @@ def test_request_certificate_with_tags():
         DomainName="google.com",
         IdempotencyToken=token,
         SubjectAlternativeNames=["google.com", "www.google.com", "mail.google.com"],
-        Tags=[{"Key": "Environment", "Value": "Prod"}, {"Key": "KeyOnly"},],
+        Tags=[{"Key": "Environment", "Value": "Prod"}, {"Key": "KeyOnly"}],
     )
     arn_2 = resp["CertificateArn"]
 
@@ -429,7 +442,7 @@ def test_operations_with_invalid_tags():
     # request certificate with invalid tags
     with pytest.raises(ClientError) as ex:
         client.request_certificate(
-            DomainName="example.com", Tags=[{"Key": "X" * 200, "Value": "Valid"}],
+            DomainName="example.com", Tags=[{"Key": "X" * 200, "Value": "Valid"}]
         )
     ex.value.response["Error"]["Code"].should.equal("ValidationException")
     ex.value.response["Error"]["Message"].should.contain(
@@ -524,6 +537,14 @@ def test_request_certificate_no_san():
     resp2 = client.describe_certificate(CertificateArn=resp["CertificateArn"])
     resp2.should.contain("Certificate")
 
+    resp2["Certificate"].should.have.key("RenewalEligibility").equals("INELIGIBLE")
+    resp2["Certificate"].should.have.key("Options")
+    resp2["Certificate"].should.have.key("DomainValidationOptions").length_of(1)
+
+    validation_option = resp2["Certificate"]["DomainValidationOptions"][0]
+    validation_option.should.have.key("DomainName").equals("google.com")
+    validation_option.should.have.key("ValidationDomain").equals("google.com")
+
 
 # Also tests the SAN code
 @mock_acm
@@ -573,7 +594,7 @@ def test_request_certificate_issued_status_with_wait_in_envvar():
     client = boto3.client("acm", region_name="eu-central-1")
 
     with freeze_time("2012-01-01 12:00:00"):
-        resp = client.request_certificate(DomainName="google.com",)
+        resp = client.request_certificate(DomainName="google.com")
     arn = resp["CertificateArn"]
 
     with freeze_time("2012-01-01 12:00:00"):
