@@ -1,10 +1,11 @@
+import base64
 import botocore.client
 import boto3
 import hashlib
-import json
 import sure  # noqa # pylint: disable=unused-import
 import pytest
 
+from botocore.exceptions import ClientError
 from freezegun import freeze_time
 from moto import mock_lambda, mock_s3
 from moto.core.models import ACCOUNT_ID
@@ -117,39 +118,23 @@ def test_create_function_from_aws_bucket():
         Description="test lambda function",
         Timeout=3,
         MemorySize=128,
+        PackageType="ZIP",
         Publish=True,
         VpcConfig={"SecurityGroupIds": ["sg-123abc"], "SubnetIds": ["subnet-123abc"]},
     )
-    # this is hard to match against, so remove it
-    result["ResponseMetadata"].pop("HTTPHeaders", None)
-    # Botocore inserts retry attempts not seen in Python27
-    result["ResponseMetadata"].pop("RetryAttempts", None)
-    result.pop("LastModified")
-    result.should.equal(
-        {
-            "FunctionName": function_name,
-            "FunctionArn": "arn:aws:lambda:{}:{}:function:{}".format(
-                _lambda_region, ACCOUNT_ID, function_name
-            ),
-            "Runtime": "python2.7",
-            "Role": result["Role"],
-            "Handler": "lambda_function.lambda_handler",
-            "CodeSha256": hashlib.sha256(zip_content).hexdigest(),
-            "CodeSize": len(zip_content),
-            "Description": "test lambda function",
-            "Timeout": 3,
-            "MemorySize": 128,
-            "Version": "1",
-            "VpcConfig": {
-                "SecurityGroupIds": ["sg-123abc"],
-                "SubnetIds": ["subnet-123abc"],
-                "VpcId": "vpc-123abc",
-            },
-            "ResponseMetadata": {"HTTPStatusCode": 201},
-            "State": "Active",
-            "Layers": [],
-        }
+
+    result.should.have.key("FunctionName").equals(function_name)
+    result.should.have.key("FunctionArn").equals(
+        "arn:aws:lambda:{}:{}:function:{}".format(
+            _lambda_region, ACCOUNT_ID, function_name
+        )
     )
+    result.should.have.key("Runtime").equals("python2.7")
+    result.should.have.key("Handler").equals("lambda_function.lambda_handler")
+    result.should.have.key("CodeSha256").equals(
+        base64.b64encode(hashlib.sha256(zip_content).digest()).decode("utf-8")
+    )
+    result.should.have.key("State").equals("Active")
 
 
 @mock_lambda
@@ -188,16 +173,46 @@ def test_create_function_from_zipfile():
             "Description": "test lambda function",
             "Timeout": 3,
             "MemorySize": 128,
-            "CodeSha256": hashlib.sha256(zip_content).hexdigest(),
+            "CodeSha256": base64.b64encode(hashlib.sha256(zip_content).digest()).decode(
+                "utf-8"
+            ),
             "Version": "1",
             "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
             "ResponseMetadata": {"HTTPStatusCode": 201},
             "State": "Active",
             "Layers": [],
+            "TracingConfig": {"Mode": "PassThrough"},
         }
     )
 
 
+@mock_lambda
+@pytest.mark.parametrize(
+    "tracing_mode",
+    [(None, "PassThrough"), ("PassThrough", "PassThrough"), ("Active", "Active")],
+)
+def test_create_function__with_tracingmode(tracing_mode):
+    conn = boto3.client("lambda", _lambda_region)
+    source, output = tracing_mode
+    zip_content = get_test_zip_file1()
+    function_name = str(uuid4())[0:6]
+    kwargs = dict(
+        FunctionName=function_name,
+        Runtime="python2.7",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"ZipFile": zip_content},
+        Description="test lambda function",
+        Timeout=3,
+        MemorySize=128,
+        Publish=True,
+    )
+    if source:
+        kwargs["TracingConfig"] = {"Mode": source}
+    result = conn.create_function(**kwargs)
+    result.should.have.key("TracingConfig").should.equal({"Mode": output})
+
+
 @mock_lambda
 @mock_s3
 @freeze_time("2015-01-01 00:00:00")
@@ -240,7 +255,7 @@ def test_get_function():
     result["Code"]["RepositoryType"].should.equal("S3")
 
     result["Configuration"]["CodeSha256"].should.equal(
-        hashlib.sha256(zip_content).hexdigest()
+        base64.b64encode(hashlib.sha256(zip_content).digest()).decode("utf-8")
     )
     result["Configuration"]["CodeSize"].should.equal(len(zip_content))
     result["Configuration"]["Description"].should.equal("test lambda function")
@@ -306,7 +321,9 @@ def test_get_function_configuration(key):
 
     result = conn.get_function_configuration(FunctionName=name_or_arn)
 
-    result["CodeSha256"].should.equal(hashlib.sha256(zip_content).hexdigest())
+    result["CodeSha256"].should.equal(
+        base64.b64encode(hashlib.sha256(zip_content).digest()).decode("utf-8")
+    )
     result["CodeSize"].should.equal(len(zip_content))
     result["Description"].should.equal("test lambda function")
     result.should.contain("FunctionArn")
@@ -338,6 +355,38 @@ def test_get_function_configuration(key):
         conn.get_function_configuration(FunctionName="junk", Qualifier="$LATEST")
 
 
+@pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
+@mock_lambda
+@mock_s3
+def test_get_function_code_signing_config(key):
+    bucket_name = str(uuid4())
+    s3_conn = boto3.client("s3", _lambda_region)
+    s3_conn.create_bucket(
+        Bucket=bucket_name,
+        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
+    )
+
+    zip_content = get_test_zip_file1()
+    s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
+    conn = boto3.client("lambda", _lambda_region)
+    function_name = str(uuid4())[0:6]
+
+    fxn = conn.create_function(
+        FunctionName=function_name,
+        Runtime="python3.7",
+        Role=get_role_name(),
+        Handler="lambda_function.lambda_handler",
+        Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
+        CodeSigningConfigArn="csc:arn",
+    )
+    name_or_arn = fxn[key]
+
+    result = conn.get_function_code_signing_config(FunctionName=name_or_arn)
+
+    result["FunctionName"].should.equal(function_name)
+    result["CodeSigningConfigArn"].should.equal("csc:arn")
+
+
 @mock_lambda
 @mock_s3
 def test_get_function_by_arn():
@@ -451,6 +500,25 @@ def test_delete_unknown_function():
     ).should.throw(botocore.client.ClientError)
 
 
+@mock_lambda
+@pytest.mark.parametrize(
+    "name",
+    [
+        "bad_function_name",
+        f"arn:aws:lambda:eu-west-1:{ACCOUNT_ID}:function:bad_function_name",
+    ],
+)
+def test_publish_version_unknown_function(name):
+    client = boto3.client("lambda", "eu-west-1")
+    with pytest.raises(ClientError) as exc:
+        client.publish_version(FunctionName=name, Description="v2")
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("ResourceNotFoundException")
+    err["Message"].should.equal(
+        f"Function not found: arn:aws:lambda:eu-west-1:{ACCOUNT_ID}:function:bad_function_name"
+    )
+
+
 @mock_lambda
 @mock_s3
 def test_publish():
@@ -546,7 +614,9 @@ def test_list_create_list_get_delete_list():
             "RepositoryType": "S3",
         },
         "Configuration": {
-            "CodeSha256": hashlib.sha256(zip_content).hexdigest(),
+            "CodeSha256": base64.b64encode(hashlib.sha256(zip_content).digest()).decode(
+                "utf-8"
+            ),
             "CodeSize": len(zip_content),
             "Description": "test lambda function",
             "FunctionName": function_name,
@@ -559,6 +629,8 @@ def test_list_create_list_get_delete_list():
             "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
             "State": "Active",
             "Layers": [],
+            "LastUpdateStatus": "Successful",
+            "TracingConfig": {"Mode": "PassThrough"},
         },
         "ResponseMetadata": {"HTTPStatusCode": 200},
     }
@@ -619,90 +691,6 @@ def test_list_create_list_get_delete_list():
     func_names.shouldnt.contain(function_name)
 
 
-@mock_lambda
-@mock_s3
-def test_tags():
-    """
-    test list_tags -> tag_resource -> list_tags -> tag_resource -> list_tags -> untag_resource -> list_tags integration
-    """
-    bucket_name = str(uuid4())
-    s3_conn = boto3.client("s3", _lambda_region)
-    s3_conn.create_bucket(
-        Bucket=bucket_name,
-        CreateBucketConfiguration={"LocationConstraint": _lambda_region},
-    )
-
-    zip_content = get_test_zip_file2()
-    s3_conn.put_object(Bucket=bucket_name, Key="test.zip", Body=zip_content)
-    conn = boto3.client("lambda", _lambda_region)
-    function_name = str(uuid4())[0:6]
-
-    function = conn.create_function(
-        FunctionName=function_name,
-        Runtime="python2.7",
-        Role=get_role_name(),
-        Handler="lambda_function.handler",
-        Code={"S3Bucket": bucket_name, "S3Key": "test.zip"},
-        Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
-    )
-
-    # List tags when there are none
-    conn.list_tags(Resource=function["FunctionArn"])["Tags"].should.equal(dict())
-
-    # List tags when there is one
-    conn.tag_resource(Resource=function["FunctionArn"], Tags=dict(spam="eggs"))[
-        "ResponseMetadata"
-    ]["HTTPStatusCode"].should.equal(200)
-    conn.list_tags(Resource=function["FunctionArn"])["Tags"].should.equal(
-        dict(spam="eggs")
-    )
-
-    # List tags when another has been added
-    conn.tag_resource(Resource=function["FunctionArn"], Tags=dict(foo="bar"))[
-        "ResponseMetadata"
-    ]["HTTPStatusCode"].should.equal(200)
-    conn.list_tags(Resource=function["FunctionArn"])["Tags"].should.equal(
-        dict(spam="eggs", foo="bar")
-    )
-
-    # Untag resource
-    conn.untag_resource(Resource=function["FunctionArn"], TagKeys=["spam", "trolls"])[
-        "ResponseMetadata"
-    ]["HTTPStatusCode"].should.equal(204)
-    conn.list_tags(Resource=function["FunctionArn"])["Tags"].should.equal(
-        dict(foo="bar")
-    )
-
-    # Untag a tag that does not exist (no error and no change)
-    conn.untag_resource(Resource=function["FunctionArn"], TagKeys=["spam"])[
-        "ResponseMetadata"
-    ]["HTTPStatusCode"].should.equal(204)
-
-
-@mock_lambda
-def test_tags_not_found():
-    """
-    Test list_tags and tag_resource when the lambda with the given arn does not exist
-    """
-    conn = boto3.client("lambda", _lambda_region)
-    conn.list_tags.when.called_with(
-        Resource="arn:aws:lambda:{}:function:not-found".format(ACCOUNT_ID)
-    ).should.throw(botocore.client.ClientError)
-
-    conn.tag_resource.when.called_with(
-        Resource="arn:aws:lambda:{}:function:not-found".format(ACCOUNT_ID),
-        Tags=dict(spam="eggs"),
-    ).should.throw(botocore.client.ClientError)
-
-    conn.untag_resource.when.called_with(
-        Resource="arn:aws:lambda:{}:function:not-found".format(ACCOUNT_ID),
-        TagKeys=["spam"],
-    ).should.throw(botocore.client.ClientError)
-
-
 @mock_lambda
 @freeze_time("2015-01-01 00:00:00")
 def test_get_function_created_with_zipfile():
@@ -722,7 +710,6 @@ def test_get_function_created_with_zipfile():
     )
 
     response = conn.get_function(FunctionName=function_name)
-    response["Configuration"].pop("LastModified")
 
     response["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     assert len(response["Code"]) == 2
@@ -730,100 +717,26 @@ def test_get_function_created_with_zipfile():
     assert response["Code"]["Location"].startswith(
         "s3://awslambda-{0}-tasks.s3-{0}.amazonaws.com".format(_lambda_region)
     )
-    response["Configuration"].should.equal(
-        {
-            "CodeSha256": hashlib.sha256(zip_content).hexdigest(),
-            "CodeSize": len(zip_content),
-            "Description": "test lambda function",
-            "FunctionArn": "arn:aws:lambda:{}:{}:function:{}".format(
-                _lambda_region, ACCOUNT_ID, function_name
-            ),
-            "FunctionName": function_name,
-            "Handler": "lambda_function.handler",
-            "MemorySize": 128,
-            "Role": get_role_name(),
-            "Runtime": "python2.7",
-            "Timeout": 3,
-            "Version": "$LATEST",
-            "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
-            "State": "Active",
-            "Layers": [],
-        }
+    response.should.have.key("Configuration")
+    config = response["Configuration"]
+    config.should.have.key("CodeSha256").equals(
+        base64.b64encode(hashlib.sha256(zip_content).digest()).decode("utf-8")
     )
-
-
-@pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-def test_add_function_permission(key):
-    """
-    Parametrized to ensure that we can add permission by using the FunctionName and the FunctionArn
-    """
-    conn = boto3.client("lambda", _lambda_region)
-    zip_content = get_test_zip_file1()
-    function_name = str(uuid4())[0:6]
-    f = conn.create_function(
-        FunctionName=function_name,
-        Runtime="python2.7",
-        Role=(get_role_name()),
-        Handler="lambda_function.handler",
-        Code={"ZipFile": zip_content},
-        Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
+    config.should.have.key("CodeSize").equals(len(zip_content))
+    config.should.have.key("Description").equals("test lambda function")
+    config.should.have.key("FunctionArn").equals(
+        f"arn:aws:lambda:{_lambda_region}:{ACCOUNT_ID}:function:{function_name}"
     )
-    name_or_arn = f[key]
-
-    response = conn.add_permission(
-        FunctionName=name_or_arn,
-        StatementId="1",
-        Action="lambda:InvokeFunction",
-        Principal="432143214321",
-        SourceArn="arn:aws:lambda:us-west-2:account-id:function:helloworld",
-        SourceAccount="123412341234",
-        EventSourceToken="blah",
-        Qualifier="2",
-    )
-    assert "Statement" in response
-    res = json.loads(response["Statement"])
-    assert res["Action"] == "lambda:InvokeFunction"
-
-
-@pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
-@mock_lambda
-def test_get_function_policy(key):
-    conn = boto3.client("lambda", _lambda_region)
-    zip_content = get_test_zip_file1()
-    function_name = str(uuid4())[0:6]
-    f = conn.create_function(
-        FunctionName=function_name,
-        Runtime="python2.7",
-        Role=get_role_name(),
-        Handler="lambda_function.handler",
-        Code={"ZipFile": zip_content},
-        Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
-    )
-    name_or_arn = f[key]
-
-    conn.add_permission(
-        FunctionName=name_or_arn,
-        StatementId="1",
-        Action="lambda:InvokeFunction",
-        Principal="432143214321",
-        SourceArn="arn:aws:lambda:us-west-2:account-id:function:helloworld",
-        SourceAccount="123412341234",
-        EventSourceToken="blah",
-        Qualifier="2",
-    )
-
-    response = conn.get_policy(FunctionName=name_or_arn)
-
-    assert "Policy" in response
-    res = json.loads(response["Policy"])
-    assert res["Statement"][0]["Action"] == "lambda:InvokeFunction"
+    config.should.have.key("FunctionName").equals(function_name)
+    config.should.have.key("Handler").equals("lambda_function.handler")
+    config.should.have.key("MemorySize").equals(128)
+    config.should.have.key("Role").equals(get_role_name())
+    config.should.have.key("Runtime").equals("python2.7")
+    config.should.have.key("Timeout").equals(3)
+    config.should.have.key("Version").equals("$LATEST")
+    config.should.have.key("State").equals("Active")
+    config.should.have.key("Layers").equals([])
+    config.should.have.key("LastUpdateStatus").equals("Successful")
 
 
 @mock_lambda
@@ -1031,7 +944,6 @@ def test_update_function_zip(key):
     )
 
     response = conn.get_function(FunctionName=function_name, Qualifier="2")
-    response["Configuration"].pop("LastModified")
 
     response["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     assert len(response["Code"]) == 2
@@ -1039,26 +951,16 @@ def test_update_function_zip(key):
     assert response["Code"]["Location"].startswith(
         "s3://awslambda-{0}-tasks.s3-{0}.amazonaws.com".format(_lambda_region)
     )
-    response["Configuration"].should.equal(
-        {
-            "CodeSha256": hashlib.sha256(zip_content_two).hexdigest(),
-            "CodeSize": len(zip_content_two),
-            "Description": "test lambda function",
-            "FunctionArn": "arn:aws:lambda:{}:{}:function:{}:2".format(
-                _lambda_region, ACCOUNT_ID, function_name
-            ),
-            "FunctionName": function_name,
-            "Handler": "lambda_function.lambda_handler",
-            "MemorySize": 128,
-            "Role": fxn["Role"],
-            "Runtime": "python2.7",
-            "Timeout": 3,
-            "Version": "2",
-            "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
-            "State": "Active",
-            "Layers": [],
-        }
+
+    config = response["Configuration"]
+    config.should.have.key("CodeSize").equals(len(zip_content_two))
+    config.should.have.key("Description").equals("test lambda function")
+    config.should.have.key("FunctionArn").equals(
+        f"arn:aws:lambda:{_lambda_region}:{ACCOUNT_ID}:function:{function_name}:2"
     )
+    config.should.have.key("FunctionName").equals(function_name)
+    config.should.have.key("Version").equals("2")
+    config.should.have.key("LastUpdateStatus").equals("Successful")
 
 
 @mock_lambda
@@ -1077,7 +979,7 @@ def test_update_function_s3():
     conn = boto3.client("lambda", _lambda_region)
     function_name = str(uuid4())[0:6]
 
-    fxn = conn.create_function(
+    conn.create_function(
         FunctionName=function_name,
         Runtime="python2.7",
         Role=get_role_name(),
@@ -1100,7 +1002,6 @@ def test_update_function_s3():
     )
 
     response = conn.get_function(FunctionName=function_name, Qualifier="2")
-    response["Configuration"].pop("LastModified")
 
     response["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     assert len(response["Code"]) == 2
@@ -1108,26 +1009,19 @@ def test_update_function_s3():
     assert response["Code"]["Location"].startswith(
         "s3://awslambda-{0}-tasks.s3-{0}.amazonaws.com".format(_lambda_region)
     )
-    response["Configuration"].should.equal(
-        {
-            "CodeSha256": hashlib.sha256(zip_content_two).hexdigest(),
-            "CodeSize": len(zip_content_two),
-            "Description": "test lambda function",
-            "FunctionArn": "arn:aws:lambda:{}:{}:function:{}:2".format(
-                _lambda_region, ACCOUNT_ID, function_name
-            ),
-            "FunctionName": function_name,
-            "Handler": "lambda_function.lambda_handler",
-            "MemorySize": 128,
-            "Role": fxn["Role"],
-            "Runtime": "python2.7",
-            "Timeout": 3,
-            "Version": "2",
-            "VpcConfig": {"SecurityGroupIds": [], "SubnetIds": []},
-            "State": "Active",
-            "Layers": [],
-        }
+
+    config = response["Configuration"]
+    config.should.have.key("CodeSha256").equals(
+        base64.b64encode(hashlib.sha256(zip_content_two).digest()).decode("utf-8")
     )
+    config.should.have.key("CodeSize").equals(len(zip_content_two))
+    config.should.have.key("Description").equals("test lambda function")
+    config.should.have.key("FunctionArn").equals(
+        f"arn:aws:lambda:{_lambda_region}:{ACCOUNT_ID}:function:{function_name}:2"
+    )
+    config.should.have.key("FunctionName").equals(function_name)
+    config.should.have.key("Version").equals("2")
+    config.should.have.key("LastUpdateStatus").equals("Successful")
 
 
 @mock_lambda
@@ -1156,40 +1050,22 @@ def test_create_function_with_unknown_arn():
     )
 
 
-@pytest.mark.parametrize("key", ["FunctionName", "FunctionArn"])
 @mock_lambda
-def test_remove_function_permission(key):
+def test_remove_unknown_permission_throws_error():
     conn = boto3.client("lambda", _lambda_region)
     zip_content = get_test_zip_file1()
     function_name = str(uuid4())[0:6]
     f = conn.create_function(
         FunctionName=function_name,
-        Runtime="python2.7",
+        Runtime="python3.7",
         Role=(get_role_name()),
         Handler="lambda_function.handler",
         Code={"ZipFile": zip_content},
-        Description="test lambda function",
-        Timeout=3,
-        MemorySize=128,
-        Publish=True,
     )
-    name_or_arn = f[key]
+    arn = f["FunctionArn"]
 
-    conn.add_permission(
-        FunctionName=name_or_arn,
-        StatementId="1",
-        Action="lambda:InvokeFunction",
-        Principal="432143214321",
-        SourceArn="arn:aws:lambda:us-west-2:account-id:function:helloworld",
-        SourceAccount="123412341234",
-        EventSourceToken="blah",
-        Qualifier="2",
-    )
-
-    remove = conn.remove_permission(
-        FunctionName=name_or_arn, StatementId="1", Qualifier="2",
-    )
-    remove["ResponseMetadata"]["HTTPStatusCode"].should.equal(204)
-    policy = conn.get_policy(FunctionName=name_or_arn, Qualifier="2")["Policy"]
-    policy = json.loads(policy)
-    policy["Statement"].should.equal([])
+    with pytest.raises(ClientError) as exc:
+        conn.remove_permission(FunctionName=arn, StatementId="1")
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("ResourceNotFoundException")
+    err["Message"].should.equal("No policy is associated with the given resource.")
