@@ -127,15 +127,28 @@ def test_submit_job():
 
     # Test that describe_jobs() returns timestamps in milliseconds
     # github.com/spulec/moto/issues/4364
-    resp = batch_client.describe_jobs(jobs=[job_id])
-    created_at = resp["jobs"][0]["createdAt"]
-    started_at = resp["jobs"][0]["startedAt"]
-    stopped_at = resp["jobs"][0]["stoppedAt"]
+    job = batch_client.describe_jobs(jobs=[job_id])["jobs"][0]
+    created_at = job["createdAt"]
+    started_at = job["startedAt"]
+    stopped_at = job["stoppedAt"]
 
     created_at.should.be.greater_than(start_time_milliseconds)
     started_at.should.be.greater_than(start_time_milliseconds)
     stopped_at.should.be.greater_than(start_time_milliseconds)
 
+    # Verify we track attempts
+    job.should.have.key("attempts").length_of(1)
+    attempt = job["attempts"][0]
+    attempt.should.have.key("container")
+    attempt["container"].should.have.key("containerInstanceArn")
+    attempt["container"].should.have.key("logStreamName").equals(
+        job["container"]["logStreamName"]
+    )
+    attempt["container"].should.have.key("networkInterfaces")
+    attempt["container"].should.have.key("taskArn")
+    attempt.should.have.key("startedAt").equals(started_at)
+    attempt.should.have.key("stoppedAt").equals(stopped_at)
+
 
 @mock_logs
 @mock_ec2
@@ -147,8 +160,8 @@ def test_list_jobs():
     ec2_client, iam_client, _, _, batch_client = _get_clients()
     _, _, _, iam_arn = _setup(ec2_client, iam_client)
 
-    job_def_name = "sleep5"
-    commands = ["sleep", "5"]
+    job_def_name = "sleep2"
+    commands = ["sleep", "2"]
     job_def_arn, queue_arn = prepare_job(batch_client, commands, iam_arn, job_def_name)
 
     resp = batch_client.submit_job(
@@ -160,6 +173,17 @@ def test_list_jobs():
     )
     job_id2 = resp["jobId"]
 
+    all_jobs = batch_client.list_jobs(jobQueue=queue_arn)["jobSummaryList"]
+    all_jobs.should.have.length_of(2)
+    for job in all_jobs:
+        job.should.have.key("createdAt")
+        job.should.have.key("jobDefinition")
+        job.should.have.key("jobName")
+        # This is async, so we can't be sure where we are in the process
+        job.should.have.key("status").within(
+            ["SUBMITTED", "PENDING", "STARTING", "RUNNABLE", "RUNNING"]
+        )
+
     batch_client.list_jobs(jobQueue=queue_arn, jobStatus="SUCCEEDED")[
         "jobSummaryList"
     ].should.have.length_of(0)
@@ -168,9 +192,17 @@ def test_list_jobs():
     for job_id in [job_id1, job_id2]:
         _wait_for_job_status(batch_client, job_id, "SUCCEEDED")
 
-    batch_client.list_jobs(jobQueue=queue_arn, jobStatus="SUCCEEDED")[
+    succeeded_jobs = batch_client.list_jobs(jobQueue=queue_arn, jobStatus="SUCCEEDED")[
         "jobSummaryList"
-    ].should.have.length_of(2)
+    ]
+    succeeded_jobs.should.have.length_of(2)
+    for job in succeeded_jobs:
+        job.should.have.key("createdAt")
+        job.should.have.key("jobDefinition")
+        job.should.have.key("jobName")
+        job.should.have.key("status").equals("SUCCEEDED")
+        job.should.have.key("stoppedAt")
+        job.should.have.key("container").should.have.key("exitCode").equals(0)
 
 
 @mock_logs
@@ -191,11 +223,11 @@ def test_terminate_job():
     )
     job_id = resp["jobId"]
 
-    _wait_for_job_status(batch_client, job_id, "RUNNING")
+    _wait_for_job_status(batch_client, job_id, "RUNNING", seconds_to_wait=120)
 
     batch_client.terminate_job(jobId=job_id, reason="test_terminate")
 
-    _wait_for_job_status(batch_client, job_id, "FAILED")
+    _wait_for_job_status(batch_client, job_id, "FAILED", seconds_to_wait=120)
 
     resp = batch_client.describe_jobs(jobs=[job_id])
     resp["jobs"][0]["jobName"].should.equal("test1")
@@ -225,7 +257,7 @@ def test_cancel_pending_job():
     # We need to be able to cancel a job that has not been started yet
     # Locally, our jobs start so fast that we can't cancel them in time
     # So delay our job, by letting it depend on a slow-running job
-    commands = ["sleep", "1"]
+    commands = ["sleep", "10"]
     job_def_arn, queue_arn = prepare_job(batch_client, commands, iam_arn, "deptest")
 
     resp = batch_client.submit_job(
@@ -270,11 +302,13 @@ def test_cancel_running_job():
         jobName="test_job_name", jobQueue=queue_arn, jobDefinition=job_def_arn
     )
     job_id = resp["jobId"]
-    _wait_for_job_status(batch_client, job_id, "STARTING")
+    _wait_for_job_statuses(
+        batch_client, job_id, statuses=["RUNNABLE", "STARTING", "RUNNING"]
+    )
 
     batch_client.cancel_job(jobId=job_id, reason="test_cancel")
     # We cancelled too late, the job was already running. Now we just wait for it to succeed
-    _wait_for_job_status(batch_client, job_id, "SUCCEEDED", seconds_to_wait=5)
+    _wait_for_job_status(batch_client, job_id, "SUCCEEDED", seconds_to_wait=30)
 
     resp = batch_client.describe_jobs(jobs=[job_id])
     resp["jobs"][0]["jobName"].should.equal("test_job_name")
@@ -282,17 +316,22 @@ def test_cancel_running_job():
 
 
 def _wait_for_job_status(client, job_id, status, seconds_to_wait=30):
+    _wait_for_job_statuses(client, job_id, [status], seconds_to_wait)
+
+
+def _wait_for_job_statuses(client, job_id, statuses, seconds_to_wait=30):
     wait_time = datetime.datetime.now() + datetime.timedelta(seconds=seconds_to_wait)
     last_job_status = None
     while datetime.datetime.now() < wait_time:
         resp = client.describe_jobs(jobs=[job_id])
         last_job_status = resp["jobs"][0]["status"]
-        if last_job_status == status:
+        if last_job_status in statuses:
             break
+        time.sleep(0.1)
     else:
         raise RuntimeError(
             "Time out waiting for job status {status}!\n Last status: {last_status}".format(
-                status=status, last_status=last_job_status
+                status=statuses, last_status=last_job_status
             )
         )
 
@@ -460,7 +499,7 @@ def test_failed_dependencies():
             "image": "busybox:latest",
             "vcpus": 1,
             "memory": 128,
-            "command": ["exi1", "1"],
+            "command": ["exit", "1"],
         },
     )
     job_def_arn_failure = resp["jobDefinitionArn"]
@@ -747,7 +786,7 @@ def test_submit_job_with_timeout():
     _, _, _, iam_arn = _setup(ec2_client, iam_client)
 
     job_def_name = str(uuid4())[0:6]
-    commands = ["sleep", "3"]
+    commands = ["sleep", "30"]
     job_def_arn, queue_arn = prepare_job(batch_client, commands, iam_arn, job_def_name)
 
     resp = batch_client.submit_job(
@@ -770,7 +809,7 @@ def test_submit_job_with_timeout_set_at_definition():
     _, _, _, iam_arn = _setup(ec2_client, iam_client)
 
     job_def_name = str(uuid4())[0:6]
-    commands = ["sleep", "3"]
+    commands = ["sleep", "30"]
     _, queue_arn = prepare_job(batch_client, commands, iam_arn, job_def_name)
     resp = batch_client.register_job_definition(
         jobDefinitionName=job_def_name,
