@@ -12,12 +12,12 @@ from moto.cloudformation.models import FakeStack
 from moto.cloudformation.parsing import (
     resource_class_from_type,
     parse_condition,
+    Output,
 )
 from moto import mock_cloudformation, mock_sqs, mock_ssm, settings
 from moto.sqs.models import Queue
 from moto.s3.models import FakeBucket
 from moto.cloudformation.utils import yaml_tag_constructor
-from moto.packages.boto.cloudformation.stack import Output
 
 
 dummy_template = {
@@ -566,7 +566,7 @@ def test_ssm_parameter_parsing():
             stack_id="test_id",
             name="test_stack",
             template=ssm_parameter_template_json,
-            parameters={"SingleParamCfn": "/path/to/single/param",},
+            parameters={"SingleParamCfn": "/path/to/single/param"},
             region_name="us-west-1",
         )
 
