@@ -24,10 +24,9 @@ def test_put_metric_data_no_dimensions():
     )
 
     metrics = conn.list_metrics()["Metrics"]
-    metrics.should.have.length_of(1)
-    metric = metrics[0]
-    metric["Namespace"].should.equal("tester")
-    metric["MetricName"].should.equal("metric")
+    metrics.should.contain(
+        {"Namespace": "tester", "MetricName": "metric", "Dimensions": []}
+    )
 
 
 @mock_cloudwatch
@@ -75,10 +74,9 @@ def test_put_metric_data_with_statistics():
     )
 
     metrics = conn.list_metrics()["Metrics"]
-    metrics.should.have.length_of(1)
-    metric = metrics[0]
-    metric["Namespace"].should.equal("tester")
-    metric["MetricName"].should.equal("statmetric")
+    metrics.should.contain(
+        {"Namespace": "tester", "MetricName": "statmetric", "Dimensions": []}
+    )
     # TODO: test statistics - https://github.com/spulec/moto/issues/1615
 
 
@@ -107,6 +105,31 @@ def test_get_metric_statistics():
     datapoint["Sum"].should.equal(1.5)
 
 
+@mock_cloudwatch
+def test_get_metric_invalid_parameter_combination():
+    conn = boto3.client("cloudwatch", region_name="us-east-1")
+    utc_now = datetime.now(tz=pytz.utc)
+
+    conn.put_metric_data(
+        Namespace="tester",
+        MetricData=[dict(MetricName="metric", Value=1.5, Timestamp=utc_now)],
+    )
+
+    with pytest.raises(ClientError) as exc:
+        # make request without both statistics or extended statistics parameters
+        conn.get_metric_statistics(
+            Namespace="tester",
+            MetricName="metric",
+            StartTime=utc_now - timedelta(seconds=60),
+            EndTime=utc_now + timedelta(seconds=60),
+            Period=60,
+        )
+
+    err = exc.value.response["Error"]
+    err["Code"].should.equal("InvalidParameterCombination")
+    err["Message"].should.equal("Must specify either Statistics or ExtendedStatistics")
+
+
 @mock_cloudwatch
 def test_get_metric_statistics_dimensions():
     conn = boto3.client("cloudwatch", region_name="us-east-1")
@@ -170,7 +193,6 @@ def test_get_metric_statistics_dimensions():
             Statistics=["Average", "Sum"],
             **params[0],
         )
-        print(stats)
         stats["Datapoints"].should.have.length_of(1)
         datapoint = stats["Datapoints"][0]
         datapoint["Sum"].should.equal(params[1])
@@ -313,30 +335,30 @@ def test_list_metrics():
     cloudwatch = boto3.client("cloudwatch", "eu-west-1")
     # Verify namespace has to exist
     res = cloudwatch.list_metrics(Namespace="unknown/")["Metrics"]
-    res.should.be.empty
+    res.should.equal([])
     # Create some metrics to filter on
     create_metrics(cloudwatch, namespace="list_test_1/", metrics=4, data_points=2)
     create_metrics(cloudwatch, namespace="list_test_2/", metrics=4, data_points=2)
     # Verify we can retrieve everything
     res = cloudwatch.list_metrics()["Metrics"]
-    len(res).should.equal(16)  # 2 namespaces * 4 metrics * 2 data points
+    assert len(res) >= 16  # 2 namespaces * 4 metrics * 2 data points
     # Verify we can filter by namespace/metric name
     res = cloudwatch.list_metrics(Namespace="list_test_1/")["Metrics"]
-    len(res).should.equal(8)  # 1 namespace * 4 metrics * 2 data points
+    res.should.have.length_of(8)  # 1 namespace * 4 metrics * 2 data points
     res = cloudwatch.list_metrics(Namespace="list_test_1/", MetricName="metric1")[
         "Metrics"
     ]
-    len(res).should.equal(2)  # 1 namespace * 1 metrics * 2 data points
+    res.should.have.length_of(2)  # 1 namespace * 1 metrics * 2 data points
     # Verify format
     res.should.equal(
         [
-            {"Namespace": "list_test_1/", "Dimensions": [], "MetricName": "metric1",},
-            {"Namespace": "list_test_1/", "Dimensions": [], "MetricName": "metric1",},
+            {"Namespace": "list_test_1/", "Dimensions": [], "MetricName": "metric1"},
+            {"Namespace": "list_test_1/", "Dimensions": [], "MetricName": "metric1"},
         ]
     )
     # Verify unknown namespace still has no results
     res = cloudwatch.list_metrics(Namespace="unknown/")["Metrics"]
-    res.should.be.empty
+    res.should.equal([])
 
 
 @mock_cloudwatch
@@ -353,29 +375,34 @@ def test_list_metrics_paginated():
     # Add a boatload of metrics
     create_metrics(cloudwatch, namespace="test", metrics=100, data_points=1)
     # Verify that a single page is returned until we've reached 500
-    first_page = cloudwatch.list_metrics()
-    first_page["Metrics"].shouldnt.be.empty
+    first_page = cloudwatch.list_metrics(Namespace="test")
+    first_page["Metrics"].should.have.length_of(100)
+
     len(first_page["Metrics"]).should.equal(100)
     create_metrics(cloudwatch, namespace="test", metrics=200, data_points=2)
-    first_page = cloudwatch.list_metrics()
+    first_page = cloudwatch.list_metrics(Namespace="test")
     len(first_page["Metrics"]).should.equal(500)
     first_page.shouldnt.contain("NextToken")
     # Verify that adding more data points results in pagination
     create_metrics(cloudwatch, namespace="test", metrics=60, data_points=10)
-    first_page = cloudwatch.list_metrics()
+    first_page = cloudwatch.list_metrics(Namespace="test")
     len(first_page["Metrics"]).should.equal(500)
-    first_page["NextToken"].shouldnt.be.empty
+    first_page["NextToken"].shouldnt.equal(None)
     # Retrieve second page - and verify there's more where that came from
-    second_page = cloudwatch.list_metrics(NextToken=first_page["NextToken"])
+    second_page = cloudwatch.list_metrics(
+        Namespace="test", NextToken=first_page["NextToken"]
+    )
     len(second_page["Metrics"]).should.equal(500)
     second_page.should.contain("NextToken")
     # Last page should only have the last 100 results, and no NextToken (indicating that pagination is finished)
-    third_page = cloudwatch.list_metrics(NextToken=second_page["NextToken"])
+    third_page = cloudwatch.list_metrics(
+        Namespace="test", NextToken=second_page["NextToken"]
+    )
     len(third_page["Metrics"]).should.equal(100)
     third_page.shouldnt.contain("NextToken")
     # Verify that we can't reuse an existing token
     with pytest.raises(ClientError) as e:
-        cloudwatch.list_metrics(NextToken=first_page["NextToken"])
+        cloudwatch.list_metrics(Namespace="test", NextToken=first_page["NextToken"])
     e.value.response["Error"]["Message"].should.equal(
         "Request parameter NextToken is invalid"
     )
@@ -400,6 +427,53 @@ def test_list_metrics_without_value():
     results[0]["Dimensions"].should.equal([{"Name": "D1", "Value": "V1"}])
 
 
+@mock_cloudwatch
+def test_list_metrics_with_same_dimensions_different_metric_name():
+    cloudwatch = boto3.client("cloudwatch", "eu-west-1")
+
+    # create metrics with same namespace and dimensions but different metric names
+    cloudwatch.put_metric_data(
+        Namespace="unique/",
+        MetricData=[
+            {
+                "MetricName": "metric1",
+                "Dimensions": [{"Name": "D1", "Value": "V1"}],
+                "Unit": "Seconds",
+            }
+        ],
+    )
+
+    cloudwatch.put_metric_data(
+        Namespace="unique/",
+        MetricData=[
+            {
+                "MetricName": "metric2",
+                "Dimensions": [{"Name": "D1", "Value": "V1"}],
+                "Unit": "Seconds",
+            }
+        ],
+    )
+
+    results = cloudwatch.list_metrics(Namespace="unique/")["Metrics"]
+    results.should.have.length_of(2)
+
+    # duplicating existing metric
+    cloudwatch.put_metric_data(
+        Namespace="unique/",
+        MetricData=[
+            {
+                "MetricName": "metric1",
+                "Dimensions": [{"Name": "D1", "Value": "V1"}],
+                "Unit": "Seconds",
+            }
+        ],
+    )
+
+    # asserting only unique values are returned
+    results = cloudwatch.list_metrics(Namespace="unique/")["Metrics"]
+    results.should.have.length_of(2)
+
+
 def create_metrics(cloudwatch, namespace, metrics=5, data_points=5):
     for i in range(0, metrics):
         metric_name = "metric" + str(i)
@@ -424,6 +498,78 @@ def create_metrics_with_dimensions(cloudwatch, namespace, data_points=5):
         )
 
 
+@mock_cloudwatch
+def test_get_metric_data_for_multiple_metrics_w_same_dimensions():
+    utc_now = datetime.now(tz=pytz.utc)
+    cloudwatch = boto3.client("cloudwatch", "eu-west-1")
+    namespace = "my_namespace/"
+    cloudwatch.put_metric_data(
+        Namespace=namespace,
+        MetricData=[
+            {
+                "MetricName": "metric1",
+                "Dimensions": [{"Name": "Name", "Value": "B"}],
+                "Value": 50,
+            },
+            {
+                "MetricName": "metric2",
+                "Dimensions": [{"Name": "Name", "Value": "B"}],
+                "Value": 25,
+                "Unit": "Microseconds",
+            },
+        ],
+    )
+    # get_metric_data 1
+    response1 = cloudwatch.get_metric_data(
+        MetricDataQueries=[
+            {
+                "Id": "result1",
+                "MetricStat": {
+                    "Metric": {
+                        "Namespace": namespace,
+                        "MetricName": "metric1",
+                        "Dimensions": [{"Name": "Name", "Value": "B"}],
+                    },
+                    "Period": 60,
+                    "Stat": "Sum",
+                },
+            },
+        ],
+        StartTime=utc_now - timedelta(seconds=60),
+        EndTime=utc_now + timedelta(seconds=60),
+    )
+    #
+    len(response1["MetricDataResults"]).should.equal(1)
+
+    res1 = response1["MetricDataResults"][0]
+    res1["Values"].should.equal([50.0])
+
+    # get_metric_data 2
+    response2 = cloudwatch.get_metric_data(
+        MetricDataQueries=[
+            {
+                "Id": "result2",
+                "MetricStat": {
+                    "Metric": {
+                        "Namespace": namespace,
+                        "MetricName": "metric2",
+                        "Dimensions": [{"Name": "Name", "Value": "B"}],
+                    },
+                    "Period": 60,
+                    "Stat": "Sum",
+                },
+            },
+        ],
+        StartTime=utc_now - timedelta(seconds=60),
+        EndTime=utc_now + timedelta(seconds=60),
+    )
+    #
+    len(response2["MetricDataResults"]).should.equal(1)
+
+    res2 = response2["MetricDataResults"][0]
+    res2["Values"].should.equal([25.0])
+
+
 @mock_cloudwatch
 def test_get_metric_data_within_timeframe():
     utc_now = datetime.now(tz=pytz.utc)
@@ -568,7 +714,7 @@ def test_get_metric_data_partially_within_timeframe():
         return response
 
     response = get_data(
-        start=yesterday - timedelta(seconds=60), end=utc_now + timedelta(seconds=60),
+        start=yesterday - timedelta(seconds=60), end=utc_now + timedelta(seconds=60)
     )
 
     # Assert Last week's data is not returned
@@ -711,6 +857,114 @@ def test_get_metric_data_for_multiple_metrics():
     res2["Values"].should.equal([25.0])
 
 
+@mock_cloudwatch
+def test_get_metric_data_for_dimensions():
+    utc_now = datetime.now(tz=pytz.utc)
+    cloudwatch = boto3.client("cloudwatch", "eu-west-1")
+    namespace = "my_namespace/"
+
+    # If the metric is created with multiple dimensions, then the data points for that metric can be retrieved only by specifying all the configured dimensions.
+    # https://aws.amazon.com/premiumsupport/knowledge-center/cloudwatch-getmetricstatistics-data/
+    server_prod = {"Name": "Server", "Value": "Prod"}
+    dimension_berlin = [server_prod, {"Name": "Domain", "Value": "Berlin"}]
+    dimension_frankfurt = [server_prod, {"Name": "Domain", "Value": "Frankfurt"}]
+
+    # put metric data
+    cloudwatch.put_metric_data(
+        Namespace=namespace,
+        MetricData=[
+            {
+                "MetricName": "metric1",
+                "Value": 50,
+                "Dimensions": dimension_berlin,
+                "Unit": "Seconds",
+                "Timestamp": utc_now,
+            }
+        ],
+    )
+    cloudwatch.put_metric_data(
+        Namespace=namespace,
+        MetricData=[
+            {
+                "MetricName": "metric1",
+                "Value": 25,
+                "Unit": "Seconds",
+                "Dimensions": dimension_frankfurt,
+                "Timestamp": utc_now,
+            }
+        ],
+    )
+    # get_metric_data
+    response = cloudwatch.get_metric_data(
+        MetricDataQueries=[
+            {
+                "Id": "result1",
+                "MetricStat": {
+                    "Metric": {
+                        "Namespace": namespace,
+                        "MetricName": "metric1",
+                        "Dimensions": dimension_frankfurt,
+                    },
+                    "Period": 60,
+                    "Stat": "SampleCount",
+                },
+            },
+            {
+                "Id": "result2",
+                "MetricStat": {
+                    "Metric": {
+                        "Namespace": namespace,
+                        "MetricName": "metric1",
+                        "Dimensions": dimension_berlin,
+                    },
+                    "Period": 60,
+                    "Stat": "Sum",
+                },
+            },
+            {
+                "Id": "result3",
+                "MetricStat": {
+                    "Metric": {
+                        "Namespace": namespace,
+                        "MetricName": "metric1",
+                        "Dimensions": [server_prod],
+                    },
+                    "Period": 60,
+                    "Stat": "Sum",
+                },
+            },
+            {
+                "Id": "result4",
+                "MetricStat": {
+                    "Metric": {"Namespace": namespace, "MetricName": "metric1"},
+                    "Period": 60,
+                    "Stat": "Sum",
+                },
+            },
+        ],
+        StartTime=utc_now - timedelta(seconds=60),
+        EndTime=utc_now + timedelta(seconds=60),
+    )
+    #
+    len(response["MetricDataResults"]).should.equal(4)
+
+    res1 = [res for res in response["MetricDataResults"] if res["Id"] == "result1"][0]
+    # expect sample count for dimension_frankfurt
+    res1["Values"].should.equal([1.0])
+
+    res2 = [res for res in response["MetricDataResults"] if res["Id"] == "result2"][0]
+    # expect sum for dimension_berlin
+    res2["Values"].should.equal([50.0])
+
+    res3 = [res for res in response["MetricDataResults"] if res["Id"] == "result3"][0]
+    # expect no result, as server_prod is only a part of other dimensions, e.g. there is no match
+    res3["Values"].should.equal([])
+
+    res4 = [res for res in response["MetricDataResults"] if res["Id"] == "result4"][0]
+    # expect sum of both metrics, as we did not filter for dimensions
+    res4["Values"].should.equal([75.0])
+
+
 @mock_cloudwatch
 @mock_s3
 def test_cloudwatch_return_s3_metrics():
@@ -845,7 +1099,7 @@ def test_put_metric_alarm():
     alarm["AlarmDescription"].should.equal("test alarm")
     alarm["AlarmConfigurationUpdatedTimestamp"].should.be.a(datetime)
     alarm["AlarmConfigurationUpdatedTimestamp"].tzinfo.should.equal(tzutc())
-    alarm["ActionsEnabled"].should.be.ok
+    alarm["ActionsEnabled"].should.equal(True)
     alarm["OKActions"].should.equal([sns_topic_arn])
     alarm["AlarmActions"].should.equal([sns_topic_arn])
     alarm["InsufficientDataActions"].should.equal([sns_topic_arn])
@@ -915,7 +1169,7 @@ def test_put_metric_alarm_with_percentile():
     alarm["AlarmDescription"].should.equal("test alarm")
     alarm["AlarmConfigurationUpdatedTimestamp"].should.be.a(datetime)
     alarm["AlarmConfigurationUpdatedTimestamp"].tzinfo.should.equal(tzutc())
-    alarm["ActionsEnabled"].should.be.ok
+    alarm["ActionsEnabled"].should.equal(True)
     alarm["StateValue"].should.equal("OK")
     alarm["StateReason"].should.equal("Unchecked: Initial alarm creation")
     alarm["StateUpdatedTimestamp"].should.be.a(datetime)
