@@ -57,7 +57,7 @@ def test_list_tags_for_resource_with_unknown_resource():
     )
 
     # then
-    response["Tags"].should.be.empty
+    response["Tags"].should.equal([])
 
 
 @mock_cloudwatch
@@ -114,7 +114,7 @@ def test_tag_resource_error_not_exists():
             ResourceARN=make_arn_for_alarm(
                 region=region_name, account_id=ACCOUNT_ID, alarm_name="unknown"
             ),
-            Tags=[{"Key": "key-1", "Value": "value-1"},],
+            Tags=[{"Key": "key-1", "Value": "value-1"}],
         )
 
     # then
