@@ -1,5 +1,4 @@
 from botocore.exceptions import ClientError
-from moto import mock_cloudformation_deprecated, mock_ec2_deprecated
 from moto import mock_cloudformation, mock_ec2
 from tests import EXAMPLE_AMI_ID
 from tests.test_cloudformation.fixtures import ec2_classic_eip
@@ -8,10 +7,6 @@ from tests.test_cloudformation.fixtures import vpc_eip
 from tests.test_cloudformation.fixtures import vpc_eni
 from tests.test_cloudformation.fixtures import vpc_single_instance_in_subnet
 from uuid import uuid4
-import boto
-import boto.ec2
-import boto.cloudformation
-import boto.vpc
 import boto3
 import json
 import sure  # noqa # pylint: disable=unused-import
@@ -113,31 +108,6 @@ def test_delete_stack_with_resource_missing_delete_attr():
     ec2.describe_vpcs(VpcIds=[vpc_id])["Vpcs"].should.have.length_of(1)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-@mock_cloudformation_deprecated
-def test_elastic_network_interfaces_cloudformation():
-    template = vpc_eni.template
-    template_json = json.dumps(template)
-    conn = boto.cloudformation.connect_to_region("us-west-1")
-    conn.create_stack("test_stack", template_body=template_json)
-    ec2_conn = boto.ec2.connect_to_region("us-west-1")
-    eni = ec2_conn.get_all_network_interfaces()[0]
-    eni.private_ip_addresses.should.have.length_of(1)
-
-    stack = conn.describe_stacks()[0]
-    resources = stack.describe_resources()
-    cfn_eni = [
-        resource
-        for resource in resources
-        if resource.resource_type == "AWS::EC2::NetworkInterface"
-    ][0]
-    cfn_eni.physical_resource_id.should.equal(eni.id)
-
-    outputs = {output.key: output.value for output in stack.outputs}
-    outputs["ENIIpAddress"].should.equal(eni.private_ip_addresses[0].private_ip_address)
-
-
 @mock_ec2
 @mock_cloudformation
 def test_elastic_network_interfaces_cloudformation_boto3():
@@ -276,7 +246,7 @@ def test_attach_vpn_gateway():
             },
             "DEVLAB1DCGateway": {
                 "Type": "AWS::EC2::VPNGateway",
-                "Properties": {"Type": "ipsec.1",},
+                "Properties": {"Type": "ipsec.1"},
             },
             "DEVLAB1VPGAttaching": {
                 "Type": "AWS::EC2::VPCGatewayAttachment",
@@ -724,3 +694,69 @@ def get_secgroup_by_tag(ec2, sg_):
     return ec2.describe_security_groups(
         Filters=[{"Name": "tag:sg-name", "Values": [sg_]}]
     )["SecurityGroups"][0]
+
+
+@mock_cloudformation
+@mock_ec2
+def test_vpc_endpoint_creation():
+    ec2 = boto3.resource("ec2", region_name="us-west-1")
+    ec2_client = boto3.client("ec2", region_name="us-west-1")
+    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
+    subnet1 = ec2.create_subnet(
+        VpcId=vpc.id, CidrBlock="10.0.0.0/24", AvailabilityZone="us-west-1a"
+    )
+
+    subnet_template = {
+        "AWSTemplateFormatVersion": "2010-09-09",
+        "Parameters": {
+            "EndpointSubnetId": {"Type": "String"},
+            "EndpointVpcId": {"Type": "String"},
+            "EndpointServiceName": {"Type": "String"},
+        },
+        "Resources": {
+            "GwlbVpcEndpoint": {
+                "Type": "AWS::EC2::VPCEndpoint",
+                "Properties": {
+                    "ServiceName": {"Ref": "EndpointServiceName"},
+                    "SubnetIds": [{"Ref": "EndpointSubnetId"}],
+                    "VpcEndpointType": "GatewayLoadBalancer",
+                    "VpcId": {"Ref": "EndpointVpcId"},
+                },
+            }
+        },
+        "Outputs": {
+            "EndpointId": {
+                "Description": "Id of the endpoint created",
+                "Value": {"Ref": "GwlbVpcEndpoint"},
+            },
+        },
+    }
+    cf = boto3.client("cloudformation", region_name="us-west-1")
+    template_json = json.dumps(subnet_template)
+    stack_name = str(uuid4())[0:6]
+    cf.create_stack(
+        StackName=stack_name,
+        TemplateBody=template_json,
+        Parameters=[
+            {"ParameterKey": "EndpointSubnetId", "ParameterValue": subnet1.id},
+            {"ParameterKey": "EndpointVpcId", "ParameterValue": vpc.id},
+            {"ParameterKey": "EndpointServiceName", "ParameterValue": "serv_name"},
+        ],
+    )
+    resources = cf.list_stack_resources(StackName=stack_name)["StackResourceSummaries"]
+    resources.should.have.length_of(1)
+    resources[0].should.have.key("LogicalResourceId").equals("GwlbVpcEndpoint")
+    vpc_endpoint_id = resources[0]["PhysicalResourceId"]
+
+    outputs = cf.describe_stacks(StackName=stack_name)["Stacks"][0]["Outputs"]
+    outputs.should.have.length_of(1)
+    outputs[0].should.equal({"OutputKey": "EndpointId", "OutputValue": vpc_endpoint_id})
+
+    endpoint = ec2_client.describe_vpc_endpoints(VpcEndpointIds=[vpc_endpoint_id])[
+        "VpcEndpoints"
+    ][0]
+    endpoint.should.have.key("VpcId").equals(vpc.id)
+    endpoint.should.have.key("ServiceName").equals("serv_name")
+    endpoint.should.have.key("State").equals("available")
+    endpoint.should.have.key("SubnetIds").equals([subnet1.id])
+    endpoint.should.have.key("VpcEndpointType").equals("GatewayLoadBalancer")
