@@ -1,53 +1,17 @@
 import pytest
 
-import boto
 import boto3
-from boto.exception import EC2ResponseError
 from botocore.exceptions import ClientError
 from uuid import uuid4
 
 import sure  # noqa # pylint: disable=unused-import
 
-from moto import mock_ec2, mock_ec2_deprecated
+from moto import mock_ec2
 from tests import EXAMPLE_AMI_ID
 
-import logging
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_allocate_classic():
-    """Allocate/release Classic EIP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as ex:
-        standard = conn.allocate_address(dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the AllocateAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    standard = conn.allocate_address()
-    standard.should.be.a(boto.ec2.address.Address)
-    standard.public_ip.should.be.a(str)
-    standard.instance_id.should.be.none
-    standard.domain.should.be.equal("standard")
-
-    with pytest.raises(EC2ResponseError) as ex:
-        standard.release(dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the ReleaseAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    standard.release()
-    standard.should_not.be.within(conn.get_all_addresses())
-
 
 @mock_ec2
-def test_eip_allocate_classic_boto3():
+def test_eip_allocate_classic():
     """Allocate/release Classic EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -83,27 +47,6 @@ def test_eip_allocate_classic_boto3():
     [a["PublicIp"] for a in all_addresses].shouldnt.contain(public_ip)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_allocate_vpc():
-    """Allocate/release VPC EIP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as ex:
-        vpc = conn.allocate_address(domain="vpc", dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the AllocateAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    vpc = conn.allocate_address(domain="vpc")
-    vpc.should.be.a(boto.ec2.address.Address)
-    vpc.domain.should.be.equal("vpc")
-    logging.debug("vpc alloc_id:".format(vpc.allocation_id))
-    vpc.release()
-
-
 @mock_ec2
 def test_describe_addresses_dryrun():
     client = boto3.client("ec2", region_name="us-east-1")
@@ -118,7 +61,7 @@ def test_describe_addresses_dryrun():
 
 
 @mock_ec2
-def test_eip_allocate_vpc_boto3():
+def test_eip_allocate_vpc():
     """Allocate/release VPC EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -159,88 +102,22 @@ def test_specific_eip_allocate_vpc():
     vpc = client.allocate_address(Domain="vpc", Address="127.38.43.222")
     vpc["Domain"].should.be.equal("vpc")
     vpc["PublicIp"].should.be.equal("127.38.43.222")
-    logging.debug("vpc alloc_id:".format(vpc["AllocationId"]))
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_allocate_invalid_domain():
-    """Allocate EIP invalid domain"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.allocate_address(domain="bogus")
-    cm.value.code.should.equal("InvalidParameterValue")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
 
 
 @mock_ec2
-def test_eip_allocate_invalid_domain_boto3():
+def test_eip_allocate_invalid_domain():
     """Allocate EIP invalid domain"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.allocate_address(Domain="bogus")
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("InvalidParameterValue")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_associate_classic():
-    """Associate/Disassociate EIP to classic instance"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    reservation = conn.run_instances(EXAMPLE_AMI_ID)
-    instance = reservation.instances[0]
-
-    eip = conn.allocate_address()
-    eip.instance_id.should.be.none
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(public_ip=eip.public_ip)
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    with pytest.raises(EC2ResponseError) as ex:
-        conn.associate_address(
-            instance_id=instance.id, public_ip=eip.public_ip, dry_run=True
-        )
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the AssociateAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    conn.associate_address(instance_id=instance.id, public_ip=eip.public_ip)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.instance_id.should.be.equal(instance.id)
-
-    with pytest.raises(EC2ResponseError) as ex:
-        conn.disassociate_address(public_ip=eip.public_ip, dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the DisAssociateAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    conn.disassociate_address(public_ip=eip.public_ip)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.instance_id.should.be.equal("")
-    eip.release()
-    eip.should_not.be.within(conn.get_all_addresses())
-    eip = None
-
-    instance.terminate()
-
-
 @mock_ec2
-def test_eip_associate_classic_boto3():
+def test_eip_associate_classic():
     """Associate/Disassociate EIP to classic instance"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -250,12 +127,12 @@ def test_eip_associate_classic_boto3():
 
     eip = client.allocate_address()
     eip = ec2.ClassicAddress(eip["PublicIp"])
-    eip.instance_id.should.be.empty
+    eip.instance_id.should.equal("")
 
     with pytest.raises(ClientError) as ex:
         client.associate_address(PublicIp=eip.public_ip)
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
     ex.value.response["Error"]["Message"].should.equal(
         "Invalid request, expect InstanceId/NetworkId parameter."
@@ -297,50 +174,8 @@ def test_eip_associate_classic_boto3():
     instance.terminate()
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_associate_vpc():
-    """Associate/Disassociate EIP to VPC instance"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    reservation = conn.run_instances(EXAMPLE_AMI_ID)
-    instance = reservation.instances[0]
-
-    eip = conn.allocate_address(domain="vpc")
-    eip.instance_id.should.be.none
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(allocation_id=eip.allocation_id)
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    conn.associate_address(instance_id=instance.id, allocation_id=eip.allocation_id)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.instance_id.should.be.equal(instance.id)
-    conn.disassociate_address(association_id=eip.association_id)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.instance_id.should.be.equal("")
-    eip.association_id.should.be.none
-
-    with pytest.raises(EC2ResponseError) as ex:
-        eip.release(dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the ReleaseAddress operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    eip.release()
-    eip = None
-
-    instance.terminate()
-
-
 @mock_ec2
-def test_eip_associate_vpc_boto3():
+def test_eip_associate_vpc():
     """Associate/Disassociate EIP to VPC instance"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -355,7 +190,7 @@ def test_eip_associate_vpc_boto3():
     with pytest.raises(ClientError) as ex:
         client.associate_address(AllocationId=eip.allocation_id)
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
     ex.value.response["Error"]["Message"].should.equal(
         "Invalid request, expect InstanceId/NetworkId parameter."
@@ -369,7 +204,7 @@ def test_eip_associate_vpc_boto3():
 
     eip.reload()
     eip.instance_id.should.be.equal("")
-    eip.association_id.should.be.none
+    eip.association_id.should.equal(None)
 
     with pytest.raises(ClientError) as ex:
         eip.release(DryRun=True)
@@ -384,7 +219,7 @@ def test_eip_associate_vpc_boto3():
 
 
 @mock_ec2
-def test_eip_boto3_vpc_association():
+def test_eip_vpc_association():
     """Associate EIP to VPC instance in a new subnet with boto3"""
     service = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
@@ -404,17 +239,17 @@ def test_eip_boto3_vpc_association():
     allocation_id = client.allocate_address(Domain="vpc")["AllocationId"]
     address = service.VpcAddress(allocation_id)
     address.load()
-    address.association_id.should.be.none
-    address.instance_id.should.be.empty
-    address.network_interface_id.should.be.empty
+    address.association_id.should.equal(None)
+    address.instance_id.should.equal("")
+    address.network_interface_id.should.equal("")
     client.associate_address(
         InstanceId=instance.id, AllocationId=allocation_id, AllowReassociation=False
     )
     instance.load()
     address.reload()
-    address.association_id.should_not.be.none
-    instance.public_ip_address.should_not.be.none
-    instance.public_dns_name.should_not.be.none
+    address.association_id.should_not.equal(None)
+    instance.public_ip_address.should_not.equal(None)
+    instance.public_dns_name.should_not.equal(None)
     address.network_interface_id.should.equal(
         instance.network_interfaces_attribute[0].get("NetworkInterfaceId")
     )
@@ -424,46 +259,14 @@ def test_eip_boto3_vpc_association():
     client.disassociate_address(AssociationId=address.association_id)
     instance.reload()
     address.reload()
-    instance.public_ip_address.should.be.none
-    address.network_interface_id.should.be.empty
-    address.association_id.should.be.none
-    address.instance_id.should.be.empty
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_associate_network_interface():
-    """Associate/Disassociate EIP to NIC"""
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    eni = conn.create_network_interface(subnet.id)
-
-    eip = conn.allocate_address(domain="vpc")
-    eip.network_interface_id.should.be.none
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(network_interface_id=eni.id)
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    conn.associate_address(network_interface_id=eni.id, allocation_id=eip.allocation_id)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.network_interface_id.should.be.equal(eni.id)
-
-    conn.disassociate_address(association_id=eip.association_id)
-    # no .update() on address ):
-    eip = conn.get_all_addresses(addresses=[eip.public_ip])[0]
-    eip.network_interface_id.should.be.equal("")
-    eip.association_id.should.be.none
-    eip.release()
-    eip = None
+    instance.public_ip_address.should.equal(None)
+    address.network_interface_id.should.equal("")
+    address.association_id.should.equal(None)
+    address.instance_id.should.equal("")
 
 
 @mock_ec2
-def test_eip_associate_network_interface_boto3():
+def test_eip_associate_network_interface():
     """Associate/Disassociate EIP to NIC"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -473,12 +276,12 @@ def test_eip_associate_network_interface_boto3():
 
     eip = client.allocate_address(Domain="vpc")
     eip = ec2.ClassicAddress(eip["PublicIp"])
-    eip.network_interface_id.should.be.empty
+    eip.network_interface_id.should.equal("")
 
     with pytest.raises(ClientError) as ex:
         client.associate_address(NetworkInterfaceId=eni.id)
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
     ex.value.response["Error"]["Message"].should.equal(
         "Invalid request, expect PublicIp/AllocationId parameter."
@@ -492,47 +295,13 @@ def test_eip_associate_network_interface_boto3():
     client.disassociate_address(AssociationId=eip.association_id)
 
     eip.reload()
-    eip.network_interface_id.should.be.empty
-    eip.association_id.should.be.none
+    eip.network_interface_id.should.equal("")
+    eip.association_id.should.equal(None)
     eip.release()
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_reassociate():
-    """reassociate EIP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    reservation = conn.run_instances(EXAMPLE_AMI_ID, min_count=2)
-    instance1, instance2 = reservation.instances
-
-    eip = conn.allocate_address()
-    conn.associate_address(instance_id=instance1.id, public_ip=eip.public_ip)
-
-    # Same ID is idempotent
-    conn.associate_address(instance_id=instance1.id, public_ip=eip.public_ip)
-
-    # Different ID detects resource association
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(
-            instance_id=instance2.id, public_ip=eip.public_ip, allow_reassociation=False
-        )
-    cm.value.code.should.equal("Resource.AlreadyAssociated")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    conn.associate_address.when.called_with(
-        instance_id=instance2.id, public_ip=eip.public_ip, allow_reassociation=True
-    ).should_not.throw(EC2ResponseError)
-
-    eip.release()
-
-    instance1.terminate()
-    instance2.terminate()
-
-
 @mock_ec2
-def test_eip_reassociate_boto3():
+def test_eip_reassociate():
     """reassociate EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -557,7 +326,7 @@ def test_eip_reassociate_boto3():
             InstanceId=instance2.id, PublicIp=eip.public_ip, AllowReassociation=False
         )
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("Resource.AlreadyAssociated")
 
     client.associate_address(
@@ -572,40 +341,8 @@ def test_eip_reassociate_boto3():
     instance2.terminate()
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_reassociate_nic():
-    """reassociate EIP"""
-    conn = boto.connect_vpc("the_key", "the_secret")
-
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    eni1 = conn.create_network_interface(subnet.id)
-    eni2 = conn.create_network_interface(subnet.id)
-
-    eip = conn.allocate_address()
-    conn.associate_address(network_interface_id=eni1.id, public_ip=eip.public_ip)
-
-    # Same ID is idempotent
-    conn.associate_address(network_interface_id=eni1.id, public_ip=eip.public_ip)
-
-    # Different ID detects resource association
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(network_interface_id=eni2.id, public_ip=eip.public_ip)
-    cm.value.code.should.equal("Resource.AlreadyAssociated")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    conn.associate_address.when.called_with(
-        network_interface_id=eni2.id, public_ip=eip.public_ip, allow_reassociation=True
-    ).should_not.throw(EC2ResponseError)
-
-    eip.release()
-    eip = None
-
-
 @mock_ec2
-def test_eip_reassociate_nic_boto3():
+def test_eip_reassociate_nic():
     """reassociate EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -628,7 +365,7 @@ def test_eip_reassociate_nic_boto3():
     with pytest.raises(ClientError) as ex:
         client.associate_address(NetworkInterfaceId=eni2.id, PublicIp=eip.public_ip)
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("Resource.AlreadyAssociated")
 
     client.associate_address(
@@ -641,29 +378,9 @@ def test_eip_reassociate_nic_boto3():
     eip.release()
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
+@mock_ec2
 def test_eip_associate_invalid_args():
     """Associate EIP, invalid args"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    reservation = conn.run_instances(EXAMPLE_AMI_ID)
-    instance = reservation.instances[0]
-
-    conn.allocate_address()
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_address(instance_id=instance.id)
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    instance.terminate()
-
-
-@mock_ec2
-def test_eip_associate_invalid_args_boto3():
-    """Associate EIP, invalid args """
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -675,155 +392,62 @@ def test_eip_associate_invalid_args_boto3():
     with pytest.raises(ClientError) as ex:
         client.associate_address(InstanceId=instance.id)
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
 
     instance.terminate()
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_disassociate_bogus_association():
-    """Disassociate bogus EIP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.disassociate_address(association_id="bogus")
-    cm.value.code.should.equal("InvalidAssociationID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_eip_disassociate_bogus_association_boto3():
+def test_eip_disassociate_bogus_association():
     """Disassociate bogus EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.disassociate_address(AssociationId="bogus")
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("InvalidAssociationID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_release_bogus_eip():
-    """Release bogus EIP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.release_address(allocation_id="bogus")
-    cm.value.code.should.equal("InvalidAllocationID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_eip_release_bogus_eip_boto3():
+def test_eip_release_bogus_eip():
     """Release bogus EIP"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.release_address(AllocationId="bogus")
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("InvalidAllocationID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_disassociate_arg_error():
-    """Invalid arguments disassociate address"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.disassociate_address()
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_eip_disassociate_arg_error_boto3():
+def test_eip_disassociate_arg_error():
     """Invalid arguments disassociate address"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.disassociate_address()
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_release_arg_error():
-    """Invalid arguments release address"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.release_address()
-    cm.value.code.should.equal("MissingParameter")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_eip_release_arg_error_boto3():
+def test_eip_release_arg_error():
     """Invalid arguments release address"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.release_address()
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("MissingParameter")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_describe():
-    """Listing of allocated Elastic IP Addresses."""
-    conn = boto.connect_ec2("the_key", "the_secret")
-    eips = []
-    number_of_classic_ips = 2
-    number_of_vpc_ips = 2
-
-    # allocate some IPs
-    for _ in range(number_of_classic_ips):
-        eips.append(conn.allocate_address())
-    for _ in range(number_of_vpc_ips):
-        eips.append(conn.allocate_address(domain="vpc"))
-    len(eips).should.be.equal(number_of_classic_ips + number_of_vpc_ips)
-
-    # Can we find each one individually?
-    for eip in eips:
-        if eip.allocation_id:
-            lookup_addresses = conn.get_all_addresses(
-                allocation_ids=[eip.allocation_id]
-            )
-        else:
-            lookup_addresses = conn.get_all_addresses(addresses=[eip.public_ip])
-        len(lookup_addresses).should.be.equal(1)
-        lookup_addresses[0].public_ip.should.be.equal(eip.public_ip)
-
-    # Can we find first two when we search for them?
-    lookup_addresses = conn.get_all_addresses(
-        addresses=[eips[0].public_ip, eips[1].public_ip]
-    )
-    len(lookup_addresses).should.be.equal(2)
-    lookup_addresses[0].public_ip.should.be.equal(eips[0].public_ip)
-    lookup_addresses[1].public_ip.should.be.equal(eips[1].public_ip)
-
-    # Release all IPs
-    for eip in eips:
-        eip.release()
-    len(conn.get_all_addresses()).should.be.equal(0)
-
-
 @mock_ec2
-def test_eip_describe_boto3():
+def test_eip_describe():
     """Listing of allocated Elastic IP Addresses."""
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
@@ -868,28 +492,15 @@ def test_eip_describe_boto3():
     [a["PublicIp"] for a in all_addresses].shouldnt.contain(eips[1].public_ip)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_eip_describe_none():
-    """Error when search for bogus IP"""
-    conn = boto.connect_ec2("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.get_all_addresses(addresses=["256.256.256.256"])
-    cm.value.code.should.equal("InvalidAddress.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_eip_describe_none_boto3():
+def test_eip_describe_none():
     """Error when search for bogus IP"""
     client = boto3.client("ec2", region_name="us-east-1")
 
     with pytest.raises(ClientError) as ex:
         client.describe_addresses(PublicIps=["256.256.256.256"])
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
-    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.be.none
+    ex.value.response["ResponseMetadata"]["RequestId"].shouldnt.equal(None)
     ex.value.response["Error"]["Code"].should.equal("InvalidAddress.NotFound")
 
 
