@@ -3,64 +3,17 @@ import random
 
 import boto3
 from botocore.exceptions import ClientError
-import boto
-import boto.ec2
-from boto.exception import EC2ResponseError
 import sure  # noqa # pylint: disable=unused-import
 
-from moto import mock_ec2, mock_ec2_deprecated, settings
+from moto import mock_ec2, settings
+from moto.core import ACCOUNT_ID
 from moto.ec2.utils import random_private_ip
 from tests import EXAMPLE_AMI_ID
-from tests.helpers import requires_boto_gte
 from uuid import uuid4
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_elastic_network_interfaces():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-
-    with pytest.raises(EC2ResponseError) as ex:
-        eni = conn.create_network_interface(subnet.id, dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the CreateNetworkInterface operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    conn.create_network_interface(subnet.id)
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(1)
-    eni = all_enis[0]
-    eni.groups.should.have.length_of(1)
-    eni.private_ip_addresses.should.have.length_of(1)
-    eni.private_ip_addresses[0].private_ip_address.startswith("10.").should.be.true
-
-    with pytest.raises(EC2ResponseError) as ex:
-        conn.delete_network_interface(eni.id, dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the DeleteNetworkInterface operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    conn.delete_network_interface(eni.id)
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(0)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_network_interface(eni.id)
-    cm.value.error_code.should.equal("InvalidNetworkInterfaceID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_elastic_network_interfaces_boto3():
+def test_elastic_network_interfaces():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", "us-east-1")
 
@@ -116,20 +69,8 @@ def test_elastic_network_interfaces_boto3():
     )
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_elastic_network_interfaces_subnet_validation():
-    conn = boto.connect_vpc("the_key", "the_secret")
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.create_network_interface("subnet-abcd1234")
-    cm.value.error_code.should.equal("InvalidSubnetID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_elastic_network_interfaces_subnet_validation_boto3():
+def test_elastic_network_interfaces_subnet_validation():
     client = boto3.client("ec2", "us-east-1")
 
     with pytest.raises(ClientError) as ex:
@@ -139,27 +80,8 @@ def test_elastic_network_interfaces_subnet_validation_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidSubnetID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_elastic_network_interfaces_with_private_ip():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    private_ip = "54.0.0.1"
-    eni = conn.create_network_interface(subnet.id, private_ip)
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(1)
-
-    eni = all_enis[0]
-    eni.groups.should.have.length_of(1)
-
-    eni.private_ip_addresses.should.have.length_of(1)
-    eni.private_ip_addresses[0].private_ip_address.should.equal(private_ip)
-
-
 @mock_ec2
-def test_elastic_network_interfaces_with_private_ip_boto3():
+def test_elastic_network_interfaces_with_private_ip():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", "us-east-1")
 
@@ -183,34 +105,8 @@ def test_elastic_network_interfaces_with_private_ip_boto3():
     eni["PrivateIpAddresses"][0]["PrivateIpAddress"].should.equal(private_ip)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_elastic_network_interfaces_with_groups():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    security_group1 = conn.create_security_group(
-        "test security group #1", "this is a test security group"
-    )
-    security_group2 = conn.create_security_group(
-        "test security group #2", "this is a test security group"
-    )
-    conn.create_network_interface(
-        subnet.id, groups=[security_group1.id, security_group2.id]
-    )
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(1)
-
-    eni = all_enis[0]
-    eni.groups.should.have.length_of(2)
-    set([group.id for group in eni.groups]).should.equal(
-        set([security_group1.id, security_group2.id])
-    )
-
-
 @mock_ec2
-def test_elastic_network_interfaces_with_groups_boto3():
+def test_elastic_network_interfaces_with_groups():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", "us-east-1")
 
@@ -224,60 +120,45 @@ def test_elastic_network_interfaces_with_groups_boto3():
     all_enis = client.describe_network_interfaces()["NetworkInterfaces"]
     [eni["NetworkInterfaceId"] for eni in all_enis].should.contain(my_eni.id)
 
-    my_eni = [eni for eni in all_enis if eni["NetworkInterfaceId"] == my_eni.id][0]
-    my_eni["Groups"].should.have.length_of(2)
-    set([group["GroupId"] for group in my_eni["Groups"]]).should.equal(
+    my_eni_description = [
+        eni for eni in all_enis if eni["NetworkInterfaceId"] == my_eni.id
+    ][0]
+    my_eni_description["Groups"].should.have.length_of(2)
+    set([group["GroupId"] for group in my_eni_description["Groups"]]).should.equal(
+        set([sec_group1.id, sec_group2.id])
+    )
+
+    eni_groups_attribute = client.describe_network_interface_attribute(
+        NetworkInterfaceId=my_eni.id, Attribute="groupSet"
+    ).get("Groups")
+
+    eni_groups_attribute.should.have.length_of(2)
+    set([group["GroupId"] for group in eni_groups_attribute]).should.equal(
         set([sec_group1.id, sec_group2.id])
     )
 
 
-# Has boto3 equivalent
-@requires_boto_gte("2.12.0")
-@mock_ec2_deprecated
-def test_elastic_network_interfaces_modify_attribute():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    security_group1 = conn.create_security_group(
-        "test security group #1", "this is a test security group"
-    )
-    security_group2 = conn.create_security_group(
-        "test security group #2", "this is a test security group"
-    )
-    conn.create_network_interface(subnet.id, groups=[security_group1.id])
+@mock_ec2
+def test_elastic_network_interfaces_without_group():
+    # ENI should use the default SecurityGroup if not provided
+    ec2 = boto3.resource("ec2", region_name="us-east-1")
+    client = boto3.client("ec2", "us-east-1")
 
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(1)
+    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
+    subnet = ec2.create_subnet(VpcId=vpc.id, CidrBlock="10.0.0.0/18")
 
-    eni = all_enis[0]
-    eni.groups.should.have.length_of(1)
-    eni.groups[0].id.should.equal(security_group1.id)
+    my_eni = subnet.create_network_interface()
 
-    with pytest.raises(EC2ResponseError) as ex:
-        conn.modify_network_interface_attribute(
-            eni.id, "groupset", [security_group1.id, security_group2.id], dry_run=True
-        )
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the ModifyNetworkInterface operation: Request would have succeeded, but DryRun flag is set"
-    )
+    all_enis = client.describe_network_interfaces()["NetworkInterfaces"]
+    [eni["NetworkInterfaceId"] for eni in all_enis].should.contain(my_eni.id)
 
-    conn.modify_network_interface_attribute(
-        eni.id, "groupset", [security_group1.id, security_group2.id]
-    )
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(1)
-
-    eni = all_enis[0]
-    eni.groups.should.have.length_of(2)
-    eni.groups[0].id.should.equal(security_group1.id)
-    eni.groups[1].id.should.equal(security_group2.id)
+    my_eni = [eni for eni in all_enis if eni["NetworkInterfaceId"] == my_eni.id][0]
+    my_eni["Groups"].should.have.length_of(1)
+    my_eni["Groups"][0]["GroupName"].should.equal("default")
 
 
 @mock_ec2
-def test_elastic_network_interfaces_modify_attribute_boto3():
+def test_elastic_network_interfaces_modify_attribute():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", "us-east-1")
 
@@ -315,70 +196,8 @@ def test_elastic_network_interfaces_modify_attribute_boto3():
     my_eni["Groups"][0]["GroupId"].should.equal(sec_group2.id)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_elastic_network_interfaces_filtering():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-
-    security_group1 = conn.create_security_group(
-        "test security group #1", "this is a test security group"
-    )
-    security_group2 = conn.create_security_group(
-        "test security group #2", "this is a test security group"
-    )
-
-    eni1 = conn.create_network_interface(
-        subnet.id, groups=[security_group1.id, security_group2.id]
-    )
-    eni2 = conn.create_network_interface(subnet.id, groups=[security_group1.id])
-    eni3 = conn.create_network_interface(subnet.id, description="test description")
-
-    all_enis = conn.get_all_network_interfaces()
-    all_enis.should.have.length_of(3)
-
-    # Filter by NetworkInterfaceId
-    enis_by_id = conn.get_all_network_interfaces([eni1.id])
-    enis_by_id.should.have.length_of(1)
-    set([eni.id for eni in enis_by_id]).should.equal(set([eni1.id]))
-
-    # Filter by ENI ID
-    enis_by_id = conn.get_all_network_interfaces(
-        filters={"network-interface-id": eni1.id}
-    )
-    enis_by_id.should.have.length_of(1)
-    set([eni.id for eni in enis_by_id]).should.equal(set([eni1.id]))
-
-    # Filter by Security Group
-    enis_by_group = conn.get_all_network_interfaces(
-        filters={"group-id": security_group1.id}
-    )
-    enis_by_group.should.have.length_of(2)
-    set([eni.id for eni in enis_by_group]).should.equal(set([eni1.id, eni2.id]))
-
-    # Filter by ENI ID and Security Group
-    enis_by_group = conn.get_all_network_interfaces(
-        filters={"network-interface-id": eni1.id, "group-id": security_group1.id}
-    )
-    enis_by_group.should.have.length_of(1)
-    set([eni.id for eni in enis_by_group]).should.equal(set([eni1.id]))
-
-    # Filter by Description
-    enis_by_description = conn.get_all_network_interfaces(
-        filters={"description": eni3.description}
-    )
-    enis_by_description.should.have.length_of(1)
-    enis_by_description[0].description.should.equal(eni3.description)
-
-    # Unsupported filter
-    conn.get_all_network_interfaces.when.called_with(
-        filters={"not-implemented-filter": "foobar"}
-    ).should.throw(NotImplementedError)
-
-
 @mock_ec2
-def test_elastic_network_interfaces_filtering_boto3():
+def test_elastic_network_interfaces_filtering():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", "us-east-1")
 
@@ -681,6 +500,38 @@ def test_elastic_network_interfaces_get_by_attachment_instance_id():
     enis.get("NetworkInterfaces").should.have.length_of(0)
 
 
+@mock_ec2
+def test_elastic_network_interfaces_get_by_attachment_instance_owner_id():
+    ec2_resource = boto3.resource("ec2", region_name="us-west-2")
+    ec2_client = boto3.client("ec2", region_name="us-west-2")
+
+    vpc = ec2_resource.create_vpc(CidrBlock="10.0.0.0/16")
+    subnet = ec2_resource.create_subnet(
+        VpcId=vpc.id, CidrBlock="10.0.0.0/24", AvailabilityZone="us-west-2a"
+    )
+
+    security_group1 = ec2_resource.create_security_group(
+        GroupName=str(uuid4()), Description="desc"
+    )
+
+    create_instances_result = ec2_resource.create_instances(
+        ImageId=EXAMPLE_AMI_ID, MinCount=1, MaxCount=1
+    )
+    instance = create_instances_result[0]
+
+    eni1 = ec2_resource.create_network_interface(
+        SubnetId=subnet.id, Groups=[security_group1.id]
+    )
+    ec2_client.attach_network_interface(
+        NetworkInterfaceId=eni1.id, InstanceId=instance.id, DeviceIndex=1
+    )
+
+    filters = [{"Name": "attachment.instance-owner-id", "Values": [ACCOUNT_ID]}]
+    enis = ec2_client.describe_network_interfaces(Filters=filters)["NetworkInterfaces"]
+    eni_ids = [eni["NetworkInterfaceId"] for eni in enis]
+    eni_ids.should.contain(eni1.id)
+
+
 @mock_ec2
 def test_elastic_network_interfaces_describe_network_interfaces_with_filter():
     ec2 = boto3.resource("ec2", region_name="us-west-2")
@@ -1130,3 +981,56 @@ def test_unassign_ipv6_addresses():
     my_eni.should.have.key("Ipv6Addresses").length_of(2)
     my_eni.should.have.key("Ipv6Addresses").should.contain({"Ipv6Address": ipv6_orig})
     my_eni.should.have.key("Ipv6Addresses").should.contain({"Ipv6Address": ipv6_3})
+
+
+@mock_ec2
+def test_elastic_network_interfaces_describe_attachment():
+    ec2 = boto3.resource("ec2", region_name="us-east-1")
+    client = boto3.client("ec2", "us-east-1")
+
+    vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
+    subnet = ec2.create_subnet(VpcId=vpc.id, CidrBlock="10.0.0.0/18")
+    eni_id = subnet.create_network_interface(Description="A network interface").id
+    instance_id = client.run_instances(ImageId="ami-12c6146b", MinCount=1, MaxCount=1)[
+        "Instances"
+    ][0]["InstanceId"]
+
+    client.attach_network_interface(
+        NetworkInterfaceId=eni_id, InstanceId=instance_id, DeviceIndex=1
+    )
+
+    my_eni_attachment = client.describe_network_interface_attribute(
+        NetworkInterfaceId=eni_id, Attribute="attachment"
+    ).get("Attachment")
+    my_eni_attachment["InstanceId"].should.equal(instance_id)
+    my_eni_attachment["DeleteOnTermination"].should.equal(False)
+
+    with pytest.raises(ClientError) as ex:
+        client.describe_network_interface_attribute(
+            NetworkInterfaceId=eni_id, Attribute="attach"
+        )
+    ex.value.response["Error"]["Code"].should.equal("InvalidParameterValue")
+    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    ex.value.response["Error"]["Message"].should.equal(
+        "Value (attach) for parameter attribute is invalid. Unknown attribute."
+    )
+
+    with pytest.raises(ClientError) as ex:
+        client.describe_network_interface_attribute(
+            NetworkInterfaceId=eni_id, Attribute="attachment", DryRun=True
+        )
+    ex.value.response["Error"]["Code"].should.equal("DryRunOperation")
+    ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(412)
+    ex.value.response["Error"]["Message"].should.equal(
+        "An error occurred (DryRunOperation) when calling the DescribeNetworkInterfaceAttribute operation: Request would have succeeded, but DryRun flag is set"
+    )
+
+    my_eni_description = client.describe_network_interface_attribute(
+        NetworkInterfaceId=eni_id, Attribute="description"
+    ).get("Description")
+    my_eni_description["Value"].should.be.equal("A network interface")
+
+    my_eni_source_dest_check = client.describe_network_interface_attribute(
+        NetworkInterfaceId=eni_id, Attribute="sourceDestCheck"
+    ).get("SourceDestCheck")
+    my_eni_source_dest_check["Value"].should.be.equal(True)
