@@ -1,26 +1,16 @@
-import boto
 import boto3
 import sure  # noqa # pylint: disable=unused-import
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_ec2_deprecated, mock_ec2, settings
+from moto import mock_ec2, settings
 from moto.ec2.models import OWNER_ID
 from random import randint
 from unittest import SkipTest
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_default_network_acl_created_with_vpc():
-    conn = boto.connect_vpc("the_key", "the secret")
-    conn.create_vpc("10.0.0.0/16")
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(2)
-
-
 @mock_ec2
-def test_default_network_acl_created_with_vpc_boto3():
+def test_default_network_acl_created_with_vpc():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -31,18 +21,8 @@ def test_default_network_acl_created_with_vpc_boto3():
     our_acl[0].should.have.key("IsDefault").equals(True)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_network_acls():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    conn.create_network_acl(vpc.id)
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(3)
-
-
 @mock_ec2
-def test_network_create_and_list_acls_boto3():
+def test_network_create_and_list_acls():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -58,23 +38,8 @@ def test_network_create_and_list_acls_boto3():
     acl_found["IsDefault"].should.equal(False)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_new_subnet_associates_with_default_network_acl():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.get_all_vpcs()[0]
-
-    subnet = conn.create_subnet(vpc.id, "172.31.112.0/20")
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(1)
-
-    acl = all_network_acls[0]
-    acl.associations.should.have.length_of(7)
-    [a.subnet_id for a in acl.associations].should.contain(subnet.id)
-
-
 @mock_ec2
-def test_new_subnet_associates_with_default_network_acl_boto3():
+def test_new_subnet_associates_with_default_network_acl():
     if settings.TEST_SERVER_MODE:
         raise SkipTest("ServerMode will have conflicting CidrBlocks")
     client = boto3.client("ec2", region_name="us-east-1")
@@ -90,38 +55,8 @@ def test_new_subnet_associates_with_default_network_acl_boto3():
     [a["SubnetId"] for a in acl["Associations"]].should.contain(subnet.id)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_network_acl_entries():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    network_acl = conn.create_network_acl(vpc.id)
-
-    conn.create_network_acl_entry(
-        network_acl.id,
-        110,
-        6,
-        "ALLOW",
-        "0.0.0.0/0",
-        False,
-        port_range_from="443",
-        port_range_to="443",
-    )
-
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(3)
-
-    test_network_acl = next(na for na in all_network_acls if na.id == network_acl.id)
-    entries = test_network_acl.network_acl_entries
-    entries.should.have.length_of(1)
-    entries[0].rule_number.should.equal("110")
-    entries[0].protocol.should.equal("6")
-    entries[0].rule_action.should.equal("ALLOW")
-
-
 @mock_ec2
-def test_network_acl_entries_boto3():
+def test_network_acl_entries():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -155,35 +90,8 @@ def test_network_acl_entries_boto3():
     entries[0]["CidrBlock"].should.equal("0.0.0.0/0")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_delete_network_acl_entry():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    network_acl = conn.create_network_acl(vpc.id)
-
-    conn.create_network_acl_entry(
-        network_acl.id,
-        110,
-        6,
-        "ALLOW",
-        "0.0.0.0/0",
-        False,
-        port_range_from="443",
-        port_range_to="443",
-    )
-    conn.delete_network_acl_entry(network_acl.id, 110, False)
-
-    all_network_acls = conn.get_all_network_acls()
-
-    test_network_acl = next(na for na in all_network_acls if na.id == network_acl.id)
-    entries = test_network_acl.network_acl_entries
-    entries.should.have.length_of(0)
-
-
 @mock_ec2
-def test_delete_network_acl_entry_boto3():
+def test_delete_network_acl_entry():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -211,47 +119,8 @@ def test_delete_network_acl_entry_boto3():
     test_network_acl["Entries"].should.have.length_of(0)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_replace_network_acl_entry():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    network_acl = conn.create_network_acl(vpc.id)
-
-    conn.create_network_acl_entry(
-        network_acl.id,
-        110,
-        6,
-        "ALLOW",
-        "0.0.0.0/0",
-        False,
-        port_range_from="443",
-        port_range_to="443",
-    )
-    conn.replace_network_acl_entry(
-        network_acl.id,
-        110,
-        -1,
-        "DENY",
-        "0.0.0.0/0",
-        False,
-        port_range_from="22",
-        port_range_to="22",
-    )
-
-    all_network_acls = conn.get_all_network_acls()
-
-    test_network_acl = next(na for na in all_network_acls if na.id == network_acl.id)
-    entries = test_network_acl.network_acl_entries
-    entries.should.have.length_of(1)
-    entries[0].rule_number.should.equal("110")
-    entries[0].protocol.should.equal("-1")
-    entries[0].rule_action.should.equal("DENY")
-
-
 @mock_ec2
-def test_replace_network_acl_entry_boto3():
+def test_replace_network_acl_entry():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -290,48 +159,8 @@ def test_replace_network_acl_entry_boto3():
     entries[0]["PortRange"].should.equal({"To": 22, "From": 22})
 
 
-# TODO: How to convert 'associate_network_acl' to boto3?
-@mock_ec2_deprecated
-def test_associate_new_network_acl_with_subnet():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    network_acl = conn.create_network_acl(vpc.id)
-
-    conn.associate_network_acl(network_acl.id, subnet.id)
-
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(3)
-
-    test_network_acl = next(na for na in all_network_acls if na.id == network_acl.id)
-
-    test_network_acl.associations.should.have.length_of(1)
-    test_network_acl.associations[0].subnet_id.should.equal(subnet.id)
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_delete_network_acl():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    conn.create_subnet(vpc.id, "10.0.0.0/18")
-    network_acl = conn.create_network_acl(vpc.id)
-
-    all_network_acls = conn.get_all_network_acls()
-    all_network_acls.should.have.length_of(3)
-
-    any(acl.id == network_acl.id for acl in all_network_acls).should.be.ok
-
-    conn.delete_network_acl(network_acl.id)
-
-    updated_network_acls = conn.get_all_network_acls()
-    updated_network_acls.should.have.length_of(2)
-
-    any(acl.id == network_acl.id for acl in updated_network_acls).shouldnt.be.ok
-
-
 @mock_ec2
-def test_delete_network_acl_boto3():
+def test_delete_network_acl():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -350,27 +179,8 @@ def test_delete_network_acl_boto3():
     ).shouldnt.be.ok
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_network_acl_tagging():
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    network_acl = conn.create_network_acl(vpc.id)
-
-    network_acl.add_tag("a key", "some value")
-
-    tag = conn.get_all_tags()[0]
-    tag.name.should.equal("a key")
-    tag.value.should.equal("some value")
-
-    all_network_acls = conn.get_all_network_acls()
-    test_network_acl = next(na for na in all_network_acls if na.id == network_acl.id)
-    test_network_acl.tags.should.have.length_of(1)
-    test_network_acl.tags["a key"].should.equal("some value")
-
-
 @mock_ec2
-def test_network_acl_tagging_boto3():
+def test_network_acl_tagging():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -416,7 +226,7 @@ def test_default_network_acl_default_entries():
     if not settings.TEST_SERVER_MODE:
         # Can't know whether the first ACL is the default in ServerMode
         default_network_acl = next(iter(ec2.network_acls.all()), None)
-        default_network_acl.is_default.should.be.ok
+        default_network_acl.is_default.should.equal(True)
         default_network_acl.entries.should.have.length_of(4)
 
     vpc = client.create_vpc(CidrBlock="10.0.0.0/16")
@@ -455,7 +265,7 @@ def test_delete_default_network_acl_default_entry():
         )
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     default_network_acl = next(iter(ec2.network_acls.all()), None)
-    default_network_acl.is_default.should.be.ok
+    default_network_acl.is_default.should.equal(True)
 
     default_network_acl.entries.should.have.length_of(4)
     first_default_network_acl_entry = default_network_acl.entries[0]
@@ -472,7 +282,7 @@ def test_delete_default_network_acl_default_entry():
 def test_duplicate_network_acl_entry():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     default_network_acl = next(iter(ec2.network_acls.all()), None)
-    default_network_acl.is_default.should.be.ok
+    default_network_acl.is_default.should.equal(True)
 
     rule_number = randint(0, 9999)
     egress = True
@@ -525,6 +335,84 @@ def test_describe_network_acls():
     )["NetworkAcls"]
     [na["NetworkAclId"] for na in resp3].should.contain(network_acl_id)
 
+    # Assertions for filters
+    network_acl_id = conn.create_network_acl(VpcId=vpc_id)["NetworkAcl"]["NetworkAclId"]
+    cidr_block = "0.0.0.0/24"
+    protocol = "17"  # UDP
+    rule_number = 420
+    rule_action = "allow"
+    conn.create_network_acl_entry(
+        NetworkAclId=network_acl_id,
+        CidrBlock=cidr_block,
+        Protocol=protocol,
+        RuleNumber=rule_number,
+        RuleAction=rule_action,
+        Egress=False,
+    )
+
+    # Ensure filtering by entry CIDR block
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.cidr", "Values": [cidr_block]}]
+    )
+    resp4["NetworkAcls"].should.have.length_of(1)
+    resp4["NetworkAcls"][0]["NetworkAclId"].should.equal(network_acl_id)
+    [entry["CidrBlock"] for entry in resp4["NetworkAcls"][0]["Entries"]].should.contain(
+        cidr_block
+    )
+
+    # Ensure filtering by entry protocol
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.protocol", "Values": [protocol]}]
+    )
+    resp4["NetworkAcls"].should.have.length_of(1)
+    resp4["NetworkAcls"][0]["NetworkAclId"].should.equal(network_acl_id)
+    [entry["Protocol"] for entry in resp4["NetworkAcls"][0]["Entries"]].should.contain(
+        protocol
+    )
+
+    # Ensure filtering by entry rule number
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.rule-number", "Values": [str(rule_number)]}]
+    )
+    resp4["NetworkAcls"].should.have.length_of(1)
+    resp4["NetworkAcls"][0]["NetworkAclId"].should.equal(network_acl_id)
+    [
+        entry["RuleNumber"] for entry in resp4["NetworkAcls"][0]["Entries"]
+    ].should.contain(rule_number)
+
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.rule-number", "Values": [str(rule_number + 1)]}]
+    )
+    resp4["NetworkAcls"].should.have.length_of(0)
+
+    # Ensure filtering by egress flag
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.egress", "Values": ["false"]}]
+    )
+    [entry["NetworkAclId"] for entry in resp4["NetworkAcls"]].should.contain(
+        network_acl_id
+    )
+    # the ACL with network_acl_id contains no entries with Egress=True
+    resp4 = conn.describe_network_acls(
+        Filters=[{"Name": "entry.egress", "Values": ["true"]}]
+    )
+    [entry["NetworkAclId"] for entry in resp4["NetworkAcls"]].shouldnt.contain(
+        network_acl_id
+    )
+
+    # Ensure filtering by rule action
+    resp4 = conn.describe_network_acls(
+        Filters=[
+            {"Name": "entry.rule-action", "Values": [rule_action]},
+            {"Name": "id", "Values": [network_acl_id]},
+        ]
+    )
+    resp4["NetworkAcls"].should.have.length_of(1)
+    resp4["NetworkAcls"][0]["NetworkAclId"].should.equal(network_acl_id)
+    [
+        entry["RuleAction"] for entry in resp4["NetworkAcls"][0]["Entries"]
+    ].should.contain(rule_action)
+
     with pytest.raises(ClientError) as ex:
         conn.describe_network_acls(NetworkAclIds=["1"])
 
