@@ -1,45 +1,16 @@
 import pytest
 
-import boto
 import boto3
-from boto.exception import EC2ResponseError
 from botocore.exceptions import ClientError
 import sure  # noqa # pylint: disable=unused-import
 
-from moto import mock_ec2, mock_ec2_deprecated, settings
+from moto import mock_ec2, settings
 from tests import EXAMPLE_AMI_ID
-from tests.helpers import requires_boto_gte
 from uuid import uuid4
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_tables_defaults():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    all_route_tables = conn.get_all_route_tables(filters={"vpc-id": vpc.id})
-    all_route_tables.should.have.length_of(1)
-
-    main_route_table = all_route_tables[0]
-    main_route_table.vpc_id.should.equal(vpc.id)
-
-    routes = main_route_table.routes
-    routes.should.have.length_of(1)
-
-    local_route = routes[0]
-    local_route.gateway_id.should.equal("local")
-    local_route.state.should.equal("active")
-    local_route.destination_cidr_block.should.equal(vpc.cidr_block)
-
-    vpc.delete()
-
-    all_route_tables = conn.get_all_route_tables(filters={"vpc-id": vpc.id})
-    all_route_tables.should.have.length_of(0)
-
-
 @mock_ec2
-def test_route_tables_defaults_boto3():
+def test_route_tables_defaults():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -68,49 +39,8 @@ def test_route_tables_defaults_boto3():
     all_route_tables.should.have.length_of(0)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_tables_additional():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    route_table = conn.create_route_table(vpc.id)
-
-    all_route_tables = conn.get_all_route_tables(filters={"vpc-id": vpc.id})
-    all_route_tables.should.have.length_of(2)
-    all_route_tables[0].vpc_id.should.equal(vpc.id)
-    all_route_tables[1].vpc_id.should.equal(vpc.id)
-
-    all_route_table_ids = [route_table.id for route_table in all_route_tables]
-    all_route_table_ids.should.contain(route_table.id)
-
-    routes = route_table.routes
-    routes.should.have.length_of(1)
-
-    local_route = routes[0]
-    local_route.gateway_id.should.equal("local")
-    local_route.state.should.equal("active")
-    local_route.destination_cidr_block.should.equal(vpc.cidr_block)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_vpc(vpc.id)
-    cm.value.code.should.equal("DependencyViolation")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    conn.delete_route_table(route_table.id)
-
-    all_route_tables = conn.get_all_route_tables(filters={"vpc-id": vpc.id})
-    all_route_tables.should.have.length_of(1)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_route_table("rtb-1234abcd")
-    cm.value.code.should.equal("InvalidRouteTableID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_route_tables_additional_boto3():
+def test_route_tables_additional():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -154,53 +84,8 @@ def test_route_tables_additional_boto3():
     ex.value.response["ResponseMetadata"].should.have.key("RequestId")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_tables_filters_standard():
-    conn = boto.connect_vpc("the_key", "the_secret")
-
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    route_table1 = conn.create_route_table(vpc1.id)
-
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    route_table2 = conn.create_route_table(vpc2.id)
-
-    all_route_tables = conn.get_all_route_tables()
-    all_route_tables.should.have.length_of(5)
-
-    # Filter by main route table
-    main_route_tables = conn.get_all_route_tables(filters={"association.main": "true"})
-    main_route_tables.should.have.length_of(3)
-    main_route_table_ids = [route_table.id for route_table in main_route_tables]
-    main_route_table_ids.should_not.contain(route_table1.id)
-    main_route_table_ids.should_not.contain(route_table2.id)
-
-    # Filter by VPC
-    vpc1_route_tables = conn.get_all_route_tables(filters={"vpc-id": vpc1.id})
-    vpc1_route_tables.should.have.length_of(2)
-    vpc1_route_table_ids = [route_table.id for route_table in vpc1_route_tables]
-    vpc1_route_table_ids.should.contain(route_table1.id)
-    vpc1_route_table_ids.should_not.contain(route_table2.id)
-
-    # Filter by VPC and main route table
-    vpc2_main_route_tables = conn.get_all_route_tables(
-        filters={"association.main": "true", "vpc-id": vpc2.id}
-    )
-    vpc2_main_route_tables.should.have.length_of(1)
-    vpc2_main_route_table_ids = [
-        route_table.id for route_table in vpc2_main_route_tables
-    ]
-    vpc2_main_route_table_ids.should_not.contain(route_table1.id)
-    vpc2_main_route_table_ids.should_not.contain(route_table2.id)
-
-    # Unsupported filter
-    conn.get_all_route_tables.when.called_with(
-        filters={"not-implemented-filter": "foobar"}
-    ).should.throw(NotImplementedError)
-
-
 @mock_ec2
-def test_route_tables_filters_standard_boto3():
+def test_route_tables_filters_standard():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -209,6 +94,8 @@ def test_route_tables_filters_standard_boto3():
 
     vpc2 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     route_table2 = ec2.create_route_table(VpcId=vpc2.id)
+    igw = ec2.create_internet_gateway()
+    route_table2.create_route(DestinationCidrBlock="10.0.0.4/24", GatewayId=igw.id)
 
     all_route_tables = client.describe_route_tables()["RouteTables"]
     all_ids = [rt["RouteTableId"] for rt in all_route_tables]
@@ -250,6 +137,16 @@ def test_route_tables_filters_standard_boto3():
     vpc2_main_route_table_ids.should_not.contain(route_table1.id)
     vpc2_main_route_table_ids.should_not.contain(route_table2.id)
 
+    # Filter by route gateway id
+    resp = client.describe_route_tables(
+        Filters=[
+            {"Name": "route.gateway-id", "Values": [igw.id]},
+        ]
+    )["RouteTables"]
+    assert any(
+        [route["GatewayId"] == igw.id for table in resp for route in table["Routes"]]
+    )
+
     # Unsupported filter
     if not settings.TEST_SERVER_MODE:
         # ServerMode will just throw a generic 500
@@ -259,52 +156,8 @@ def test_route_tables_filters_standard_boto3():
         )
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_tables_filters_associations():
-    conn = boto.connect_vpc("the_key", "the_secret")
-
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet1 = conn.create_subnet(vpc.id, "10.0.0.0/24")
-    subnet2 = conn.create_subnet(vpc.id, "10.0.1.0/24")
-    subnet3 = conn.create_subnet(vpc.id, "10.0.2.0/24")
-    route_table1 = conn.create_route_table(vpc.id)
-    route_table2 = conn.create_route_table(vpc.id)
-
-    association_id1 = conn.associate_route_table(route_table1.id, subnet1.id)
-    conn.associate_route_table(route_table1.id, subnet2.id)
-    conn.associate_route_table(route_table2.id, subnet3.id)
-
-    all_route_tables = conn.get_all_route_tables()
-    all_route_tables.should.have.length_of(4)
-
-    # Filter by association ID
-    association1_route_tables = conn.get_all_route_tables(
-        filters={"association.route-table-association-id": association_id1}
-    )
-    association1_route_tables.should.have.length_of(1)
-    association1_route_tables[0].id.should.equal(route_table1.id)
-    association1_route_tables[0].associations.should.have.length_of(2)
-
-    # Filter by route table ID
-    route_table2_route_tables = conn.get_all_route_tables(
-        filters={"association.route-table-id": route_table2.id}
-    )
-    route_table2_route_tables.should.have.length_of(1)
-    route_table2_route_tables[0].id.should.equal(route_table2.id)
-    route_table2_route_tables[0].associations.should.have.length_of(1)
-
-    # Filter by subnet ID
-    subnet_route_tables = conn.get_all_route_tables(
-        filters={"association.subnet-id": subnet1.id}
-    )
-    subnet_route_tables.should.have.length_of(1)
-    subnet_route_tables[0].id.should.equal(route_table1.id)
-    association1_route_tables[0].associations.should.have.length_of(2)
-
-
 @mock_ec2
-def test_route_tables_filters_associations_boto3():
+def test_route_tables_filters_associations():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -332,7 +185,7 @@ def test_route_tables_filters_associations_boto3():
     )["RouteTables"]
     association1_route_tables.should.have.length_of(1)
     association1_route_tables[0]["RouteTableId"].should.equal(route_table1.id)
-    association1_route_tables[0]["Associations"].should.have.length_of(2)
+    association1_route_tables[0]["Associations"].should.have.length_of(3)
 
     # Filter by route table ID
     route_table2_route_tables = client.describe_route_tables(
@@ -340,7 +193,7 @@ def test_route_tables_filters_associations_boto3():
     )["RouteTables"]
     route_table2_route_tables.should.have.length_of(1)
     route_table2_route_tables[0]["RouteTableId"].should.equal(route_table2.id)
-    route_table2_route_tables[0]["Associations"].should.have.length_of(1)
+    route_table2_route_tables[0]["Associations"].should.have.length_of(2)
 
     # Filter by subnet ID
     subnet_route_tables = client.describe_route_tables(
@@ -348,78 +201,11 @@ def test_route_tables_filters_associations_boto3():
     )["RouteTables"]
     subnet_route_tables.should.have.length_of(1)
     subnet_route_tables[0]["RouteTableId"].should.equal(route_table1.id)
-    subnet_route_tables[0]["Associations"].should.have.length_of(2)
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_table_associations():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    route_table = conn.create_route_table(vpc.id)
-
-    all_route_tables = conn.get_all_route_tables()
-    all_route_tables.should.have.length_of(3)
-
-    # Refresh
-    route_table = conn.get_all_route_tables(route_table.id)[0]
-    route_table.associations.should.have.length_of(0)
-
-    # Associate
-    association_id = conn.associate_route_table(route_table.id, subnet.id)
-
-    # Refresh
-    route_table = conn.get_all_route_tables(route_table.id)[0]
-    route_table.associations.should.have.length_of(1)
-
-    route_table.associations[0].id.should.equal(association_id)
-    route_table.associations[0].main.should.equal(True)
-    route_table.associations[0].route_table_id.should.equal(route_table.id)
-    route_table.associations[0].subnet_id.should.equal(subnet.id)
-
-    # Associate is idempotent
-    association_id_idempotent = conn.associate_route_table(route_table.id, subnet.id)
-    association_id_idempotent.should.equal(association_id)
-
-    # Error: Attempt delete associated route table.
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_route_table(route_table.id)
-    cm.value.code.should.equal("DependencyViolation")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    # Disassociate
-    conn.disassociate_route_table(association_id)
-
-    # Refresh
-    route_table = conn.get_all_route_tables(route_table.id)[0]
-    route_table.associations.should.have.length_of(0)
-
-    # Error: Disassociate with invalid association ID
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.disassociate_route_table(association_id)
-    cm.value.code.should.equal("InvalidAssociationID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    # Error: Associate with invalid subnet ID
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_route_table(route_table.id, "subnet-1234abcd")
-    cm.value.code.should.equal("InvalidSubnetID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    # Error: Associate with invalid route table ID
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.associate_route_table("rtb-1234abcd", subnet.id)
-    cm.value.code.should.equal("InvalidRouteTableID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
+    subnet_route_tables[0]["Associations"].should.have.length_of(3)
 
 
 @mock_ec2
-def test_route_table_associations_boto3():
+def test_route_table_associations():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -429,7 +215,7 @@ def test_route_table_associations_boto3():
 
     # Refresh
     r = client.describe_route_tables(RouteTableIds=[route_table.id])["RouteTables"][0]
-    r["Associations"].should.have.length_of(0)
+    r["Associations"].should.have.length_of(1)
 
     # Associate
     association_id = client.associate_route_table(
@@ -438,12 +224,12 @@ def test_route_table_associations_boto3():
 
     # Refresh
     r = client.describe_route_tables(RouteTableIds=[route_table.id])["RouteTables"][0]
-    r["Associations"].should.have.length_of(1)
+    r["Associations"].should.have.length_of(2)
 
-    r["Associations"][0]["RouteTableAssociationId"].should.equal(association_id)
-    r["Associations"][0]["Main"].should.equal(True)
-    r["Associations"][0]["RouteTableId"].should.equal(route_table.id)
-    r["Associations"][0]["SubnetId"].should.equal(subnet.id)
+    r["Associations"][1]["RouteTableAssociationId"].should.equal(association_id)
+    r["Associations"][1]["Main"].should.equal(False)
+    r["Associations"][1]["RouteTableId"].should.equal(route_table.id)
+    r["Associations"][1]["SubnetId"].should.equal(subnet.id)
 
     # Associate is idempotent
     association_id_idempotent = client.associate_route_table(
@@ -461,9 +247,16 @@ def test_route_table_associations_boto3():
     # Disassociate
     client.disassociate_route_table(AssociationId=association_id)
 
-    # Refresh
+    # Refresh - The default (main) route should be there
     r = client.describe_route_tables(RouteTableIds=[route_table.id])["RouteTables"][0]
-    r["Associations"].should.have.length_of(0)
+    r["Associations"].should.have.length_of(1)
+    r["Associations"][0].should.have.key("Main").equal(True)
+    r["Associations"][0].should.have.key("RouteTableAssociationId")
+    r["Associations"][0].should.have.key("RouteTableId").equals(route_table.id)
+    r["Associations"][0].should.have.key("AssociationState").equals(
+        {"State": "associated"}
+    )
+    r["Associations"][0].shouldnt.have.key("SubnetId")
 
     # Error: Disassociate with invalid association ID
     with pytest.raises(ClientError) as ex:
@@ -489,86 +282,8 @@ def test_route_table_associations_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidRouteTableID.NotFound")
 
 
-# Has boto3 equivalent
-@requires_boto_gte("2.16.0")
-@mock_ec2_deprecated
-def test_route_table_replace_route_table_association():
-    """
-    Note: Boto has deprecated replace_route_table_association (which returns status)
-      and now uses replace_route_table_association_with_assoc (which returns association ID).
-    """
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    subnet = conn.create_subnet(vpc.id, "10.0.0.0/18")
-    route_table1 = conn.create_route_table(vpc.id)
-    route_table2 = conn.create_route_table(vpc.id)
-
-    all_route_tables = conn.get_all_route_tables()
-    all_route_tables.should.have.length_of(4)
-
-    # Refresh
-    route_table1 = conn.get_all_route_tables(route_table1.id)[0]
-    route_table1.associations.should.have.length_of(0)
-
-    # Associate
-    association_id1 = conn.associate_route_table(route_table1.id, subnet.id)
-
-    # Refresh
-    route_table1 = conn.get_all_route_tables(route_table1.id)[0]
-    route_table2 = conn.get_all_route_tables(route_table2.id)[0]
-
-    # Validate
-    route_table1.associations.should.have.length_of(1)
-    route_table2.associations.should.have.length_of(0)
-
-    route_table1.associations[0].id.should.equal(association_id1)
-    route_table1.associations[0].main.should.equal(True)
-    route_table1.associations[0].route_table_id.should.equal(route_table1.id)
-    route_table1.associations[0].subnet_id.should.equal(subnet.id)
-
-    # Replace Association
-    association_id2 = conn.replace_route_table_association_with_assoc(
-        association_id1, route_table2.id
-    )
-
-    # Refresh
-    route_table1 = conn.get_all_route_tables(route_table1.id)[0]
-    route_table2 = conn.get_all_route_tables(route_table2.id)[0]
-
-    # Validate
-    route_table1.associations.should.have.length_of(0)
-    route_table2.associations.should.have.length_of(1)
-
-    route_table2.associations[0].id.should.equal(association_id2)
-    route_table2.associations[0].main.should.equal(True)
-    route_table2.associations[0].route_table_id.should.equal(route_table2.id)
-    route_table2.associations[0].subnet_id.should.equal(subnet.id)
-
-    # Replace Association is idempotent
-    association_id_idempotent = conn.replace_route_table_association_with_assoc(
-        association_id2, route_table2.id
-    )
-    association_id_idempotent.should.equal(association_id2)
-
-    # Error: Replace association with invalid association ID
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.replace_route_table_association_with_assoc(
-            "rtbassoc-1234abcd", route_table1.id
-        )
-    cm.value.code.should.equal("InvalidAssociationID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-    # Error: Replace association with invalid route table ID
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.replace_route_table_association_with_assoc(association_id2, "rtb-1234abcd")
-    cm.value.code.should.equal("InvalidRouteTableID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_route_table_replace_route_table_association_boto3():
+def test_route_table_replace_route_table_association():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
 
@@ -586,7 +301,7 @@ def test_route_table_replace_route_table_association_boto3():
     route_table1 = client.describe_route_tables(RouteTableIds=[route_table1_id])[
         "RouteTables"
     ][0]
-    route_table1["Associations"].should.have.length_of(0)
+    route_table1["Associations"].should.have.length_of(1)
 
     # Associate
     association_id1 = client.associate_route_table(
@@ -602,15 +317,15 @@ def test_route_table_replace_route_table_association_boto3():
     ][0]
 
     # Validate
-    route_table1["Associations"].should.have.length_of(1)
-    route_table2["Associations"].should.have.length_of(0)
+    route_table1["Associations"].should.have.length_of(2)
+    route_table2["Associations"].should.have.length_of(1)
 
-    route_table1["Associations"][0]["RouteTableAssociationId"].should.equal(
+    route_table1["Associations"][1]["RouteTableAssociationId"].should.equal(
         association_id1
     )
-    route_table1["Associations"][0]["Main"].should.equal(True)
-    route_table1["Associations"][0]["RouteTableId"].should.equal(route_table1_id)
-    route_table1["Associations"][0]["SubnetId"].should.equal(subnet.id)
+    route_table1["Associations"][1]["Main"].should.equal(False)
+    route_table1["Associations"][1]["RouteTableId"].should.equal(route_table1_id)
+    route_table1["Associations"][1]["SubnetId"].should.equal(subnet.id)
 
     # Replace Association
     association_id2 = client.replace_route_table_association(
@@ -626,15 +341,15 @@ def test_route_table_replace_route_table_association_boto3():
     ][0]
 
     # Validate
-    route_table1["Associations"].should.have.length_of(0)
-    route_table2["Associations"].should.have.length_of(1)
+    route_table1["Associations"].should.have.length_of(1)
+    route_table2["Associations"].should.have.length_of(2)
 
-    route_table2["Associations"][0]["RouteTableAssociationId"].should.equal(
+    route_table2["Associations"][1]["RouteTableAssociationId"].should.equal(
         association_id2
     )
-    route_table2["Associations"][0]["Main"].should.equal(True)
-    route_table2["Associations"][0]["RouteTableId"].should.equal(route_table2_id)
-    route_table2["Associations"][0]["SubnetId"].should.equal(subnet.id)
+    route_table2["Associations"][1]["Main"].should.equal(False)
+    route_table2["Associations"][1]["RouteTableId"].should.equal(route_table2_id)
+    route_table2["Associations"][1]["SubnetId"].should.equal(subnet.id)
 
     # Replace Association is idempotent
     association_id_idempotent = client.replace_route_table_association(
@@ -661,27 +376,8 @@ def test_route_table_replace_route_table_association_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidRouteTableID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_route_table_get_by_tag():
-    conn = boto.connect_vpc("the_key", "the_secret")
-
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    route_table = conn.create_route_table(vpc.id)
-    route_table.add_tag("Name", "TestRouteTable")
-
-    route_tables = conn.get_all_route_tables(filters={"tag:Name": "TestRouteTable"})
-
-    route_tables.should.have.length_of(1)
-    route_tables[0].vpc_id.should.equal(vpc.id)
-    route_tables[0].id.should.equal(route_table.id)
-    route_tables[0].tags.should.have.length_of(1)
-    route_tables[0].tags["Name"].should.equal("TestRouteTable")
-
-
 @mock_ec2
-def test_route_table_get_by_tag_boto3():
+def test_route_table_get_by_tag():
     ec2 = boto3.resource("ec2", region_name="eu-central-1")
 
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -700,59 +396,8 @@ def test_route_table_get_by_tag_boto3():
     route_tables[0].tags[0].should.equal({"Key": "Name", "Value": tag_value})
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_routes_additional():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    main_route_table = conn.get_all_route_tables(filters={"vpc-id": vpc.id})[0]
-
-    igw = conn.create_internet_gateway()
-    ROUTE_CIDR = "10.0.0.4/24"
-
-    conn.create_route(main_route_table.id, ROUTE_CIDR, gateway_id=igw.id)
-
-    main_route_table = conn.get_all_route_tables(filters={"vpc-id": vpc.id})[
-        0
-    ]  # Refresh route table
-
-    main_route_table.routes.should.have.length_of(2)
-    new_routes = [
-        route
-        for route in main_route_table.routes
-        if route.destination_cidr_block != vpc.cidr_block
-    ]
-    new_routes.should.have.length_of(1)
-
-    new_route = new_routes[0]
-    new_route.gateway_id.should.equal(igw.id)
-    new_route.instance_id.should.be.none
-    new_route.state.should.equal("active")
-    new_route.destination_cidr_block.should.equal(ROUTE_CIDR)
-
-    conn.delete_route(main_route_table.id, ROUTE_CIDR)
-
-    main_route_table = conn.get_all_route_tables(filters={"vpc-id": vpc.id})[
-        0
-    ]  # Refresh route table
-
-    main_route_table.routes.should.have.length_of(1)
-    new_routes = [
-        route
-        for route in main_route_table.routes
-        if route.destination_cidr_block != vpc.cidr_block
-    ]
-    new_routes.should.have.length_of(0)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_route(main_route_table.id, ROUTE_CIDR)
-    cm.value.code.should.equal("InvalidRoute.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_routes_additional_boto3():
+def test_routes_additional():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -777,7 +422,7 @@ def test_routes_additional_boto3():
 
     new_route = new_routes[0]
     new_route.gateway_id.should.equal(igw.id)
-    new_route.instance_id.should.be.none
+    new_route.instance_id.should.equal(None)
     new_route.state.should.equal("active")
     new_route.destination_cidr_block.should.equal(ROUTE_CIDR)
 
@@ -804,62 +449,8 @@ def test_routes_additional_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidRoute.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_routes_replace():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    main_route_table = conn.get_all_route_tables(
-        filters={"association.main": "true", "vpc-id": vpc.id}
-    )[0]
-
-    ROUTE_CIDR = "10.0.0.4/24"
-
-    # Various route targets
-    igw = conn.create_internet_gateway()
-
-    reservation = conn.run_instances(EXAMPLE_AMI_ID)
-    instance = reservation.instances[0]
-
-    # Create initial route
-    conn.create_route(main_route_table.id, ROUTE_CIDR, gateway_id=igw.id)
-
-    # Replace...
-    def get_target_route():
-        route_table = conn.get_all_route_tables(main_route_table.id)[0]
-        routes = [
-            route
-            for route in route_table.routes
-            if route.destination_cidr_block != vpc.cidr_block
-        ]
-        routes.should.have.length_of(1)
-        return routes[0]
-
-    conn.replace_route(main_route_table.id, ROUTE_CIDR, instance_id=instance.id)
-
-    target_route = get_target_route()
-    target_route.gateway_id.should.be.none
-    target_route.instance_id.should.equal(instance.id)
-    target_route.state.should.equal("active")
-    target_route.destination_cidr_block.should.equal(ROUTE_CIDR)
-
-    conn.replace_route(main_route_table.id, ROUTE_CIDR, gateway_id=igw.id)
-
-    target_route = get_target_route()
-    target_route.gateway_id.should.equal(igw.id)
-    target_route.instance_id.should.be.none
-    target_route.state.should.equal("active")
-    target_route.destination_cidr_block.should.equal(ROUTE_CIDR)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.replace_route("rtb-1234abcd", ROUTE_CIDR, gateway_id=igw.id)
-    cm.value.code.should.equal("InvalidRouteTableID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_routes_replace_boto3():
+def test_routes_replace():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -929,32 +520,8 @@ def test_routes_replace_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidRouteTableID.NotFound")
 
 
-# Has boto3 equivalent
-@requires_boto_gte("2.19.0")
-@mock_ec2_deprecated
-def test_routes_not_supported():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    conn.create_vpc("10.0.0.0/16")
-    main_route_table = conn.get_all_route_tables()[0]
-
-    conn.create_internet_gateway()
-    ROUTE_CIDR = "10.0.0.4/24"
-
-    # Create
-    conn.create_route.when.called_with(
-        main_route_table.id, ROUTE_CIDR, interface_id="eni-1234abcd"
-    ).should.throw("InvalidNetworkInterfaceID.NotFound")
-
-    # Replace
-    igw = conn.create_internet_gateway()
-    conn.create_route(main_route_table.id, ROUTE_CIDR, gateway_id=igw.id)
-    conn.replace_route.when.called_with(
-        main_route_table.id, ROUTE_CIDR, interface_id="eni-1234abcd"
-    ).should.throw(NotImplementedError)
-
-
 @mock_ec2
-def test_routes_not_supported_boto3():
+def test_routes_not_supported():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     main_route_table_id = client.describe_route_tables()["RouteTables"][0][
@@ -994,44 +561,8 @@ def test_routes_not_supported_boto3():
         client.replace_route.when.called_with(**args).should.throw(NotImplementedError)
 
 
-# Has boto3 equivalent
-@requires_boto_gte("2.34.0")
-@mock_ec2_deprecated
-def test_routes_vpc_peering_connection():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    main_route_table = conn.get_all_route_tables(
-        filters={"association.main": "true", "vpc-id": vpc.id}
-    )[0]
-
-    ROUTE_CIDR = "10.0.0.4/24"
-
-    peer_vpc = conn.create_vpc("11.0.0.0/16")
-    vpc_pcx = conn.create_vpc_peering_connection(vpc.id, peer_vpc.id)
-
-    conn.create_route(
-        main_route_table.id, ROUTE_CIDR, vpc_peering_connection_id=vpc_pcx.id
-    )
-
-    # Refresh route table
-    main_route_table = conn.get_all_route_tables(main_route_table.id)[0]
-    new_routes = [
-        route
-        for route in main_route_table.routes
-        if route.destination_cidr_block != vpc.cidr_block
-    ]
-    new_routes.should.have.length_of(1)
-
-    new_route = new_routes[0]
-    new_route.gateway_id.should.be.none
-    new_route.instance_id.should.be.none
-    new_route.vpc_peering_connection_id.should.equal(vpc_pcx.id)
-    new_route.state.should.equal("active")
-    new_route.destination_cidr_block.should.equal(ROUTE_CIDR)
-
-
 @mock_ec2
-def test_routes_vpc_peering_connection_boto3():
+def test_routes_vpc_peering_connection():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -1061,45 +592,15 @@ def test_routes_vpc_peering_connection_boto3():
     new_routes.should.have.length_of(1)
 
     new_route = new_routes[0]
-    new_route.gateway_id.should.be.none
-    new_route.instance_id.should.be.none
+    new_route.gateway_id.should.equal(None)
+    new_route.instance_id.should.equal(None)
     new_route.vpc_peering_connection_id.should.equal(vpc_pcx.id)
     new_route.state.should.equal("active")
     new_route.destination_cidr_block.should.equal(ROUTE_CIDR)
 
 
-# Has boto3 equivalent
-@requires_boto_gte("2.34.0")
-@mock_ec2_deprecated
-def test_routes_vpn_gateway():
-
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    main_route_table = conn.get_all_route_tables(
-        filters={"association.main": "true", "vpc-id": vpc.id}
-    )[0]
-    ROUTE_CIDR = "10.0.0.4/24"
-
-    vpn_gw = conn.create_vpn_gateway(type="ipsec.1")
-
-    conn.create_route(main_route_table.id, ROUTE_CIDR, gateway_id=vpn_gw.id)
-
-    main_route_table = conn.get_all_route_tables(main_route_table.id)[0]
-    new_routes = [
-        route
-        for route in main_route_table.routes
-        if route.destination_cidr_block != vpc.cidr_block
-    ]
-    new_routes.should.have.length_of(1)
-
-    new_route = new_routes[0]
-    new_route.gateway_id.should.equal(vpn_gw.id)
-    new_route.instance_id.should.be.none
-    new_route.vpc_peering_connection_id.should.be.none
-
-
 @mock_ec2
-def test_routes_vpn_gateway_boto3():
+def test_routes_vpn_gateway():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -1127,32 +628,12 @@ def test_routes_vpn_gateway_boto3():
 
     new_route = new_routes[0]
     new_route.gateway_id.should.equal(vpn_gw_id)
-    new_route.instance_id.should.be.none
-    new_route.vpc_peering_connection_id.should.be.none
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_network_acl_tagging():
-
-    conn = boto.connect_vpc("the_key", "the secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    route_table = conn.create_route_table(vpc.id)
-    route_table.add_tag("a key", "some value")
-
-    tag = conn.get_all_tags()[0]
-    tag.name.should.equal("a key")
-    tag.value.should.equal("some value")
-
-    all_route_tables = conn.get_all_route_tables()
-    test_route_table = next(na for na in all_route_tables if na.id == route_table.id)
-    test_route_table.tags.should.have.length_of(1)
-    test_route_table.tags["a key"].should.equal("some value")
+    new_route.instance_id.should.equal(None)
+    new_route.vpc_peering_connection_id.should.equal(None)
 
 
 @mock_ec2
-def test_network_acl_tagging_boto3():
+def test_network_acl_tagging():
     client = boto3.client("ec2", region_name="us-east-1")
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -1180,7 +661,7 @@ def test_create_route_with_invalid_destination_cidr_block_parameter():
 
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.shouldnt.be.ok
+    vpc.is_default.should.equal(False)
 
     route_table = ec2.create_route_table(VpcId=vpc.id)
     route_table.reload()
@@ -1191,7 +672,7 @@ def test_create_route_with_invalid_destination_cidr_block_parameter():
 
     destination_cidr_block = "1000.1.0.0/20"
     with pytest.raises(ClientError) as ex:
-        route = route_table.create_route(
+        route_table.create_route(
             DestinationCidrBlock=destination_cidr_block, GatewayId=internet_gateway.id
         )
     str(ex.value).should.equal(
@@ -1410,15 +891,23 @@ def test_associate_route_table_by_gateway():
     vpc_id = ec2.create_vpc(CidrBlock="10.0.0.0/16")["Vpc"]["VpcId"]
     route_table_id = ec2.create_route_table(VpcId=vpc_id)["RouteTable"]["RouteTableId"]
     igw_id = ec2.create_internet_gateway()["InternetGateway"]["InternetGatewayId"]
-    assoc_id = ec2.associate_route_table(
-        RouteTableId=route_table_id, GatewayId=igw_id,
-    )["AssociationId"]
+    assoc_id = ec2.associate_route_table(RouteTableId=route_table_id, GatewayId=igw_id)[
+        "AssociationId"
+    ]
     verify = ec2.describe_route_tables(
         Filters=[
             {"Name": "association.route-table-association-id", "Values": [assoc_id]}
         ]
     )["RouteTables"]
-    verify[0]["Associations"][0]["RouteTableAssociationId"].should.equal(assoc_id)
+
+    # First assocation is the main
+    verify[0]["Associations"][0]["Main"].should.equal(True)
+
+    # Second is our Gateway
+    verify[0]["Associations"][1]["Main"].should.equal(False)
+    verify[0]["Associations"][1]["GatewayId"].should.equal(igw_id)
+    verify[0]["Associations"][1]["RouteTableAssociationId"].should.equal(assoc_id)
+    verify[0]["Associations"][1].doesnt.have.key("SubnetId")
 
 
 @mock_ec2
@@ -1430,11 +919,19 @@ def test_associate_route_table_by_subnet():
         "SubnetId"
     ]
     assoc_id = ec2.associate_route_table(
-        RouteTableId=route_table_id, SubnetId=subnet_id,
+        RouteTableId=route_table_id, SubnetId=subnet_id
     )["AssociationId"]
     verify = ec2.describe_route_tables(
         Filters=[
             {"Name": "association.route-table-association-id", "Values": [assoc_id]}
         ]
     )["RouteTables"]
-    verify[0]["Associations"][0]["RouteTableAssociationId"].should.equal(assoc_id)
+
+    # First assocation is the main
+    verify[0]["Associations"][0].should.have.key("Main").equals(True)
+
+    # Second is our Gateway
+    verify[0]["Associations"][1]["Main"].should.equal(False)
+    verify[0]["Associations"][1]["SubnetId"].should.equals(subnet_id)
+    verify[0]["Associations"][1]["RouteTableAssociationId"].should.equal(assoc_id)
+    verify[0]["Associations"][1].doesnt.have.key("GatewayId")
