@@ -1,16 +1,12 @@
 import pytest
 import datetime
 
-import boto
-import boto.ec2
 import boto3
-from boto.exception import EC2ResponseError
 from botocore.exceptions import ClientError
 import pytz
 import sure  # noqa # pylint: disable=unused-import
 
-from moto import mock_ec2, mock_ec2_deprecated, settings
-from moto.ec2.models import ec2_backends
+from moto import mock_ec2, settings
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from tests import EXAMPLE_AMI_ID
 from uuid import uuid4
@@ -93,8 +89,8 @@ def test_request_spot_instances():
     requests.should.have.length_of(1)
     request = requests[0]
 
-    request["State"].should.equal("open")
-    request["SpotPrice"].should.equal("0.5")
+    request["State"].should.equal("active")
+    request["SpotPrice"].should.equal("0.500000")
     request["Type"].should.equal("one-time")
     request["ValidFrom"].should.equal(start_dt)
     request["ValidUntil"].should.equal(end_dt)
@@ -132,13 +128,14 @@ def test_request_spot_instances_default_arguments():
     requests.should.have.length_of(1)
     request = requests[0]
 
-    request["State"].should.equal("open")
-    request["SpotPrice"].should.equal("0.5")
+    request["State"].should.equal("active")
+    request["SpotPrice"].should.equal("0.500000")
     request["Type"].should.equal("one-time")
     request.shouldnt.contain("ValidFrom")
     request.shouldnt.contain("ValidUntil")
     request.shouldnt.contain("LaunchGroup")
     request.shouldnt.contain("AvailabilityZoneGroup")
+    request.should.have.key("InstanceInterruptionBehavior").equals("terminate")
 
     launch_spec = request["LaunchSpecification"]
 
@@ -155,32 +152,8 @@ def test_request_spot_instances_default_arguments():
     request.shouldnt.contain("SubnetId")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_cancel_spot_instance_request():
-    conn = boto.connect_ec2()
-
-    conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-
-    requests = conn.get_all_spot_instance_requests()
-    requests.should.have.length_of(1)
-
-    with pytest.raises(EC2ResponseError) as ex:
-        conn.cancel_spot_instance_requests([requests[0].id], dry_run=True)
-    ex.value.error_code.should.equal("DryRunOperation")
-    ex.value.status.should.equal(412)
-    ex.value.message.should.equal(
-        "An error occurred (DryRunOperation) when calling the CancelSpotInstance operation: Request would have succeeded, but DryRun flag is set"
-    )
-
-    conn.cancel_spot_instance_requests([requests[0].id])
-
-    requests = conn.get_all_spot_instance_requests()
-    requests.should.have.length_of(0)
-
-
 @mock_ec2
-def test_cancel_spot_instance_request_boto3():
+def test_cancel_spot_instance_request():
     client = boto3.client("ec2", region_name="us-west-1")
 
     rsi = client.request_spot_instances(
@@ -196,7 +169,7 @@ def test_cancel_spot_instance_request_boto3():
     request.should.have.key("CreateTime")
     request.should.have.key("Type").equal("one-time")
     request.should.have.key("SpotInstanceRequestId")
-    request.should.have.key("SpotPrice").equal("0.5")
+    request.should.have.key("SpotPrice").equal("0.500000")
     request["LaunchSpecification"]["ImageId"].should.equal(EXAMPLE_AMI_ID)
 
     with pytest.raises(ClientError) as ex:
@@ -219,34 +192,8 @@ def test_cancel_spot_instance_request_boto3():
     requests.should.have.length_of(0)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_request_spot_instances_fulfilled():
-    """
-    Test that moto correctly fullfills a spot instance request
-    """
-    conn = boto.ec2.connect_to_region("us-east-1")
-
-    request = conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-
-    requests = conn.get_all_spot_instance_requests()
-    requests.should.have.length_of(1)
-    request = requests[0]
-
-    request.state.should.equal("open")
-
-    if not settings.TEST_SERVER_MODE:
-        ec2_backends["us-east-1"].spot_instance_requests[request.id].state = "active"
-
-        requests = conn.get_all_spot_instance_requests()
-        requests.should.have.length_of(1)
-        request = requests[0]
-
-        request.state.should.equal("active")
-
-
 @mock_ec2
-def test_request_spot_instances_fulfilled_boto3():
+def test_request_spot_instances_fulfilled():
     """
     Test that moto correctly fullfills a spot instance request
     """
@@ -263,42 +210,11 @@ def test_request_spot_instances_fulfilled_boto3():
     requests.should.have.length_of(1)
     request = requests[0]
 
-    request["State"].should.equal("open")
-
-    if not settings.TEST_SERVER_MODE:
-        ec2_backends["us-east-1"].spot_instance_requests[request_id].state = "active"
-
-        requests = client.describe_spot_instance_requests(
-            SpotInstanceRequestIds=[request_id]
-        )["SpotInstanceRequests"]
-        requests.should.have.length_of(1)
-        request = requests[0]
-
-        request["State"].should.equal("active")
-
-
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_tag_spot_instance_request():
-    """
-    Test that moto correctly tags a spot instance request
-    """
-    conn = boto.connect_ec2()
-
-    request = conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-    request[0].add_tag("tag1", "value1")
-    request[0].add_tag("tag2", "value2")
-
-    requests = conn.get_all_spot_instance_requests()
-    requests.should.have.length_of(1)
-    request = requests[0]
-
-    tag_dict = dict(request.tags)
-    tag_dict.should.equal({"tag1": "value1", "tag2": "value2"})
+    request["State"].should.equal("active")
 
 
 @mock_ec2
-def test_tag_spot_instance_request_boto3():
+def test_tag_spot_instance_request():
     """
     Test that moto correctly tags a spot instance request
     """
@@ -324,39 +240,8 @@ def test_tag_spot_instance_request_boto3():
     request["Tags"].should.contain({"Key": "tag2", "Value": "value2"})
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_get_all_spot_instance_requests_filtering():
-    """
-    Test that moto correctly filters spot instance requests
-    """
-    conn = boto.connect_ec2()
-
-    request1 = conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-    request2 = conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-    conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-    request1[0].add_tag("tag1", "value1")
-    request1[0].add_tag("tag2", "value2")
-    request2[0].add_tag("tag1", "value1")
-    request2[0].add_tag("tag2", "wrong")
-
-    requests = conn.get_all_spot_instance_requests(filters={"state": "active"})
-    requests.should.have.length_of(0)
-
-    requests = conn.get_all_spot_instance_requests(filters={"state": "open"})
-    requests.should.have.length_of(3)
-
-    requests = conn.get_all_spot_instance_requests(filters={"tag:tag1": "value1"})
-    requests.should.have.length_of(2)
-
-    requests = conn.get_all_spot_instance_requests(
-        filters={"tag:tag1": "value1", "tag:tag2": "value2"}
-    )
-    requests.should.have.length_of(1)
-
-
 @mock_ec2
-def test_get_all_spot_instance_requests_filtering_boto3():
+def test_get_all_spot_instance_requests_filtering():
     """
     Test that moto correctly filters spot instance requests
     """
@@ -384,14 +269,14 @@ def test_get_all_spot_instance_requests_filtering_boto3():
     )
 
     requests = client.describe_spot_instance_requests(
-        Filters=[{"Name": "state", "Values": ["active"]}]
+        Filters=[{"Name": "state", "Values": ["failed"]}]
     )["SpotInstanceRequests"]
     r_ids = [r["SpotInstanceRequestId"] for r in requests]
     r_ids.shouldnt.contain(request1_id)
     r_ids.shouldnt.contain(request2_id)
 
     requests = client.describe_spot_instance_requests(
-        Filters=[{"Name": "state", "Values": ["open"]}]
+        Filters=[{"Name": "state", "Values": ["active"]}]
     )["SpotInstanceRequests"]
     r_ids = [r["SpotInstanceRequestId"] for r in requests]
     r_ids.should.contain(request1_id)
@@ -411,22 +296,6 @@ def test_get_all_spot_instance_requests_filtering_boto3():
     requests.should.have.length_of(1)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_request_spot_instances_setting_instance_id():
-    conn = boto.ec2.connect_to_region("us-east-1")
-    request = conn.request_spot_instances(price=0.5, image_id=EXAMPLE_AMI_ID)
-
-    if not settings.TEST_SERVER_MODE:
-        req = ec2_backends["us-east-1"].spot_instance_requests[request[0].id]
-        req.state = "active"
-        req.instance_id = "i-12345678"
-
-        request = conn.get_all_spot_instance_requests()[0]
-        assert request.state == "active"
-        assert request.instance_id == "i-12345678"
-
-
 @mock_ec2
 def test_request_spot_instances_instance_lifecycle():
     if settings.TEST_SERVER_MODE:
@@ -442,13 +311,34 @@ def test_request_spot_instances_instance_lifecycle():
     instance["InstanceLifecycle"].should.equal("spot")
 
 
+@mock_ec2
+def test_request_spot_instances_with_tags():
+    client = boto3.client("ec2", region_name="us-east-1")
+    request = client.request_spot_instances(
+        SpotPrice="0.5",
+        TagSpecifications=[
+            {
+                "ResourceType": "spot-instances-request",
+                "Tags": [{"Key": "k", "Value": "v"}],
+            }
+        ],
+    )
+
+    request_id = request["SpotInstanceRequests"][0]["SpotInstanceRequestId"]
+
+    request = client.describe_spot_instance_requests(
+        SpotInstanceRequestIds=[request_id]
+    )["SpotInstanceRequests"][0]
+    request.should.have.key("Tags").equals([{"Key": "k", "Value": "v"}])
+
+
 @mock_ec2
 def test_launch_spot_instance_instance_lifecycle():
     client = boto3.client("ec2", region_name="us-east-1")
 
     kwargs = {
         "KeyName": "foobar",
-        "ImageId": "ami-pytest",
+        "ImageId": EXAMPLE_AMI_ID,
         "MinCount": 1,
         "MaxCount": 1,
         "InstanceType": "c4.2xlarge",
@@ -472,7 +362,7 @@ def test_launch_instance_instance_lifecycle():
 
     kwargs = {
         "KeyName": "foobar",
-        "ImageId": "ami-pytest",
+        "ImageId": EXAMPLE_AMI_ID,
         "MinCount": 1,
         "MaxCount": 1,
         "InstanceType": "c4.2xlarge",
@@ -511,18 +401,20 @@ def test_spot_price_history():
 
 
 @mock_ec2
-def test_request_spot_instances_setting_instance_id_boto3():
+def test_request_spot_instances__instance_should_exist():
     client = boto3.client("ec2", region_name="us-east-1")
     request = client.request_spot_instances(
         SpotPrice="0.5", LaunchSpecification={"ImageId": EXAMPLE_AMI_ID}
     )
     request_id = request["SpotInstanceRequests"][0]["SpotInstanceRequestId"]
 
-    if not settings.TEST_SERVER_MODE:
-        req = ec2_backends["us-east-1"].spot_instance_requests[request_id]
-        req.state = "active"
-        req.instance_id = "i-12345678"
+    request = client.describe_spot_instance_requests(
+        SpotInstanceRequestIds=[request_id]
+    )["SpotInstanceRequests"][0]
+    request.should.have.key("InstanceId")
+    instance_id = request["InstanceId"]
 
-        request = client.describe_spot_instance_requests()["SpotInstanceRequests"][0]
-        assert request["State"] == "active"
-        assert request["InstanceId"] == "i-12345678"
+    response = client.describe_instances(InstanceIds=[instance_id])
+    instance = response["Reservations"][0]["Instances"][0]
+    instance.should.have.key("InstanceId").equals(instance_id)
+    instance.should.have.key("ImageId").equals(EXAMPLE_AMI_ID)
