@@ -1,6 +1,4 @@
-from __future__ import unicode_literals
-import boto
-import sure  # noqa
+import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ec2
 
