@@ -2,13 +2,11 @@ import pytest
 from botocore.exceptions import ClientError
 
 import boto3
-import boto
-from boto.exception import EC2ResponseError
 
 import sure  # noqa # pylint: disable=unused-import
 import random
 
-from moto import mock_ec2, mock_ec2_deprecated
+from moto import mock_ec2
 from uuid import uuid4
 from .test_tags import retrieve_all_tagged
 
@@ -16,28 +14,6 @@ SAMPLE_DOMAIN_NAME = "example.com"
 SAMPLE_NAME_SERVERS = ["10.0.0.6", "10.0.0.7"]
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpcs():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    vpc.cidr_block.should.equal("10.0.0.0/16")
-
-    all_vpcs = conn.get_all_vpcs()
-    all_vpcs.should.have.length_of(2)
-
-    vpc.delete()
-
-    all_vpcs = conn.get_all_vpcs()
-    all_vpcs.should.have.length_of(1)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.delete_vpc("vpc-1234abcd")
-    cm.value.code.should.equal("InvalidVpcID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
 def test_create_and_delete_vpc():
     ec2 = boto3.resource("ec2", region_name="eu-north-1")
@@ -60,25 +36,8 @@ def test_create_and_delete_vpc():
     ex.value.response["Error"]["Code"].should.equal("InvalidVpcID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_defaults():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    conn.get_all_vpcs().should.have.length_of(2)
-    conn.get_all_route_tables().should.have.length_of(2)
-    conn.get_all_security_groups(filters={"vpc-id": [vpc.id]}).should.have.length_of(1)
-
-    vpc.delete()
-
-    conn.get_all_vpcs().should.have.length_of(1)
-    conn.get_all_route_tables().should.have.length_of(1)
-    conn.get_all_security_groups(filters={"vpc-id": [vpc.id]}).should.have.length_of(0)
-
-
 @mock_ec2
-def test_vpc_defaults_boto3():
+def test_vpc_defaults():
     ec2 = boto3.resource("ec2", region_name="eu-north-1")
     client = boto3.client("ec2", region_name="eu-north-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -102,18 +61,8 @@ def test_vpc_defaults_boto3():
     ].should.have.length_of(0)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_isdefault_filter():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    conn.get_all_vpcs(filters={"isDefault": "true"}).should.have.length_of(1)
-    vpc.delete()
-    conn.get_all_vpcs(filters={"isDefault": "true"}).should.have.length_of(1)
-
-
 @mock_ec2
-def test_vpc_isdefault_filter_boto3():
+def test_vpc_isdefault_filter():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -128,21 +77,8 @@ def test_vpc_isdefault_filter_boto3():
     ].should.have.length_of(1)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_multiple_vpcs_default_filter():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    conn.create_vpc("10.8.0.0/16")
-    conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("192.168.0.0/16")
-    conn.get_all_vpcs().should.have.length_of(4)
-    vpc = conn.get_all_vpcs(filters={"isDefault": "true"})
-    vpc.should.have.length_of(1)
-    vpc[0].cidr_block.should.equal("172.31.0.0/16")
-
-
 @mock_ec2
-def test_multiple_vpcs_default_filter_boto3():
+def test_multiple_vpcs_default_filter():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     ec2.create_vpc(CidrBlock="10.8.0.0/16")
@@ -154,19 +90,8 @@ def test_multiple_vpcs_default_filter_boto3():
     [v["CidrBlock"] for v in default_vpcs].should.contain("172.31.0.0/16")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_state_available_filter():
-    conn = boto.connect_vpc("the_key", "the_secret")
-    vpc = conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("10.1.0.0/16")
-    conn.get_all_vpcs(filters={"state": "available"}).should.have.length_of(3)
-    vpc.delete()
-    conn.get_all_vpcs(filters={"state": "available"}).should.have.length_of(2)
-
-
 @mock_ec2
-def test_vpc_state_available_filter_boto3():
+def test_vpc_state_available_filter():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -194,25 +119,8 @@ def retrieve_all_vpcs(client, filters=[]):  # pylint: disable=W0102
     return all_vpcs
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_tagging():
-    conn = boto.connect_vpc()
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    vpc.add_tag("a key", "some value")
-    tag = conn.get_all_tags()[0]
-    tag.name.should.equal("a key")
-    tag.value.should.equal("some value")
-
-    # Refresh the vpc
-    vpc = conn.get_all_vpcs(vpc_ids=[vpc.id])[0]
-    vpc.tags.should.have.length_of(1)
-    vpc.tags["a key"].should.equal("some value")
-
-
 @mock_ec2
-def test_vpc_tagging_boto3():
+def test_vpc_tagging():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -229,29 +137,8 @@ def test_vpc_tagging_boto3():
     vpc["Tags"].should.equal([{"Key": "a key", "Value": "some value"}])
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_id():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("10.0.0.0/16")
-
-    vpcs = conn.get_all_vpcs(vpc_ids=[vpc1.id, vpc2.id])
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-    with pytest.raises(EC2ResponseError) as cm:
-        conn.get_all_vpcs(vpc_ids=["vpc-does_not_exist"])
-    cm.value.code.should.equal("InvalidVpcID.NotFound")
-    cm.value.status.should.equal(400)
-    cm.value.request_id.should_not.be.none
-
-
 @mock_ec2
-def test_vpc_get_by_id_boto3():
+def test_vpc_get_by_id():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -271,23 +158,8 @@ def test_vpc_get_by_id_boto3():
     ex.value.response["Error"]["Code"].should.equal("InvalidVpcID.NotFound")
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_cidr_block():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("10.0.0.0/24")
-
-    vpcs = conn.get_all_vpcs(filters={"cidr": "10.0.0.0/16"})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_cidr_block_boto3():
+def test_vpc_get_by_cidr_block():
     ec2 = boto3.resource("ec2", region_name="eu-west-1")
     client = boto3.client("ec2", region_name="eu-west-1")
     random_ip = ".".join(map(str, (random.randint(0, 99) for _ in range(4))))
@@ -302,27 +174,8 @@ def test_vpc_get_by_cidr_block_boto3():
     set([vpc["VpcId"] for vpc in vpcs]).should.equal(set([vpc1.id, vpc2.id]))
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_dhcp_options_id():
-    conn = boto.connect_vpc()
-    dhcp_options = conn.create_dhcp_options(SAMPLE_DOMAIN_NAME, SAMPLE_NAME_SERVERS)
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("10.0.0.0/24")
-
-    conn.associate_dhcp_options(dhcp_options.id, vpc1.id)
-    conn.associate_dhcp_options(dhcp_options.id, vpc2.id)
-
-    vpcs = conn.get_all_vpcs(filters={"dhcp-options-id": dhcp_options.id})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_dhcp_options_id_boto3():
+def test_vpc_get_by_dhcp_options_id():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     dhcp_options = ec2.create_dhcp_options(
@@ -347,27 +200,8 @@ def test_vpc_get_by_dhcp_options_id_boto3():
     vpc2.id.should.be.within(vpc_ids)
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_tag():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    vpc3 = conn.create_vpc("10.0.0.0/24")
-
-    vpc1.add_tag("Name", "TestVPC")
-    vpc2.add_tag("Name", "TestVPC")
-    vpc3.add_tag("Name", "TestVPC2")
-
-    vpcs = conn.get_all_vpcs(filters={"tag:Name": "TestVPC"})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_tag_boto3():
+def test_vpc_get_by_tag():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -386,29 +220,8 @@ def test_vpc_get_by_tag_boto3():
     set([vpc["VpcId"] for vpc in vpcs]).should.equal(set([vpc1.id, vpc2.id]))
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_tag_key_superset():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    vpc3 = conn.create_vpc("10.0.0.0/24")
-
-    vpc1.add_tag("Name", "TestVPC")
-    vpc1.add_tag("Key", "TestVPC2")
-    vpc2.add_tag("Name", "TestVPC")
-    vpc2.add_tag("Key", "TestVPC2")
-    vpc3.add_tag("Key", "TestVPC2")
-
-    vpcs = conn.get_all_vpcs(filters={"tag-key": "Name"})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_tag_key_superset_boto3():
+def test_vpc_get_by_tag_key_superset():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -429,29 +242,8 @@ def test_vpc_get_by_tag_key_superset_boto3():
     set([vpc["VpcId"] for vpc in vpcs]).should.equal(set([vpc1.id, vpc2.id]))
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_tag_key_subset():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    vpc3 = conn.create_vpc("10.0.0.0/24")
-
-    vpc1.add_tag("Name", "TestVPC")
-    vpc1.add_tag("Key", "TestVPC2")
-    vpc2.add_tag("Name", "TestVPC")
-    vpc2.add_tag("Key", "TestVPC2")
-    vpc3.add_tag("Test", "TestVPC2")
-
-    vpcs = conn.get_all_vpcs(filters={"tag-key": ["Name", "Key"]})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_tag_key_subset_boto3():
+def test_vpc_get_by_tag_key_subset():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -473,29 +265,8 @@ def test_vpc_get_by_tag_key_subset_boto3():
     set([vpc["VpcId"] for vpc in vpcs]).should.equal(set([vpc1.id, vpc2.id]))
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_tag_value_superset():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    vpc3 = conn.create_vpc("10.0.0.0/24")
-
-    vpc1.add_tag("Name", "TestVPC")
-    vpc1.add_tag("Key", "TestVPC2")
-    vpc2.add_tag("Name", "TestVPC")
-    vpc2.add_tag("Key", "TestVPC2")
-    vpc3.add_tag("Key", "TestVPC2")
-
-    vpcs = conn.get_all_vpcs(filters={"tag-value": "TestVPC"})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_tag_value_superset_boto3():
+def test_vpc_get_by_tag_value_superset():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -516,28 +287,8 @@ def test_vpc_get_by_tag_value_superset_boto3():
     set([vpc["VpcId"] for vpc in vpcs]).should.equal(set([vpc1.id, vpc2.id]))
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_get_by_tag_value_subset():
-    conn = boto.connect_vpc()
-    vpc1 = conn.create_vpc("10.0.0.0/16")
-    vpc2 = conn.create_vpc("10.0.0.0/16")
-    conn.create_vpc("10.0.0.0/24")
-
-    vpc1.add_tag("Name", "TestVPC")
-    vpc1.add_tag("Key", "TestVPC2")
-    vpc2.add_tag("Name", "TestVPC")
-    vpc2.add_tag("Key", "TestVPC2")
-
-    vpcs = conn.get_all_vpcs(filters={"tag-value": ["TestVPC", "TestVPC2"]})
-    vpcs.should.have.length_of(2)
-    vpc_ids = tuple(map(lambda v: v.id, vpcs))
-    vpc1.id.should.be.within(vpc_ids)
-    vpc2.id.should.be.within(vpc_ids)
-
-
 @mock_ec2
-def test_vpc_get_by_tag_value_subset_boto3():
+def test_vpc_get_by_tag_value_subset():
     ec2 = boto3.resource("ec2", region_name="us-east-1")
     client = boto3.client("ec2", region_name="us-east-1")
     vpc1 = ec2.create_vpc(CidrBlock="10.0.0.0/16")
@@ -569,16 +320,16 @@ def test_default_vpc():
     default_vpc.cidr_block.should.equal("172.31.0.0/16")
     default_vpc.instance_tenancy.should.equal("default")
     default_vpc.reload()
-    default_vpc.is_default.should.be.ok
+    default_vpc.is_default.should.equal(True)
 
     # Test default values for VPC attributes
     response = default_vpc.describe_attribute(Attribute="enableDnsSupport")
     attr = response.get("EnableDnsSupport")
-    attr.get("Value").should.be.ok
+    attr.get("Value").should.equal(True)
 
     response = default_vpc.describe_attribute(Attribute="enableDnsHostnames")
     attr = response.get("EnableDnsHostnames")
-    attr.get("Value").should.be.ok
+    attr.get("Value").should.equal(True)
 
 
 @mock_ec2
@@ -591,7 +342,7 @@ def test_non_default_vpc():
     # Create the non default VPC
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16")
     vpc.reload()
-    vpc.is_default.shouldnt.be.ok
+    vpc.is_default.should.equal(False)
 
     # Test default instance_tenancy
     vpc.instance_tenancy.should.equal("default")
@@ -599,11 +350,11 @@ def test_non_default_vpc():
     # Test default values for VPC attributes
     response = vpc.describe_attribute(Attribute="enableDnsSupport")
     attr = response.get("EnableDnsSupport")
-    attr.get("Value").should.be.ok
+    attr.get("Value").should.equal(True)
 
     response = vpc.describe_attribute(Attribute="enableDnsHostnames")
     attr = response.get("EnableDnsHostnames")
-    attr.get("Value").shouldnt.be.ok
+    attr.get("Value").should.equal(False)
 
     # Check Primary CIDR Block Associations
     cidr_block_association_set = next(iter(vpc.cidr_block_association_set), None)
@@ -622,7 +373,7 @@ def test_vpc_dedicated_tenancy():
     # Create the non default VPC
     vpc = ec2.create_vpc(CidrBlock="10.0.0.0/16", InstanceTenancy="dedicated")
     vpc.reload()
-    vpc.is_default.shouldnt.be.ok
+    vpc.is_default.should.equal(False)
 
     vpc.instance_tenancy.should.equal("dedicated")
 
@@ -693,21 +444,8 @@ def test_vpc_modify_enable_dns_hostnames():
     attr.get("Value").should.be.ok
 
 
-# Has boto3 equivalent
-@mock_ec2_deprecated
-def test_vpc_associate_dhcp_options():
-    conn = boto.connect_vpc()
-    dhcp_options = conn.create_dhcp_options(SAMPLE_DOMAIN_NAME, SAMPLE_NAME_SERVERS)
-    vpc = conn.create_vpc("10.0.0.0/16")
-
-    conn.associate_dhcp_options(dhcp_options.id, vpc.id)
-
-    vpc.update()
-    dhcp_options.id.should.equal(vpc.dhcp_options_id)
-
-
 @mock_ec2
-def test_vpc_associate_dhcp_options_boto3():
+def test_vpc_associate_dhcp_options():
     ec2 = boto3.resource("ec2", region_name="us-west-1")
     client = boto3.client("ec2", region_name="us-west-1")
     dhcp_options = ec2.create_dhcp_options(
@@ -1060,7 +798,7 @@ def test_enable_vpc_classic_link():
     vpc = ec2.create_vpc(CidrBlock="10.1.0.0/16")
 
     response = ec2.meta.client.enable_vpc_classic_link(VpcId=vpc.id)
-    assert response.get("Return").should.be.true
+    assert response.get("Return").should.equal(True)
 
 
 @mock_ec2
@@ -1095,7 +833,7 @@ def test_describe_classic_link_enabled():
 
     ec2.meta.client.enable_vpc_classic_link(VpcId=vpc.id)
     response = ec2.meta.client.describe_vpc_classic_link(VpcIds=[vpc.id])
-    assert response.get("Vpcs")[0].get("ClassicLinkEnabled").should.be.true
+    assert response.get("Vpcs")[0].get("ClassicLinkEnabled").should.equal(True)
 
 
 @mock_ec2
@@ -1138,7 +876,7 @@ def test_enable_vpc_classic_link_dns_support():
     vpc = ec2.create_vpc(CidrBlock="10.1.0.0/16")
 
     response = ec2.meta.client.enable_vpc_classic_link_dns_support(VpcId=vpc.id)
-    assert response.get("Return").should.be.true
+    assert response.get("Return").should.equal(True)
 
 
 @mock_ec2
@@ -1162,7 +900,7 @@ def test_describe_classic_link_dns_support_enabled():
 
     ec2.meta.client.enable_vpc_classic_link_dns_support(VpcId=vpc.id)
     response = ec2.meta.client.describe_vpc_classic_link_dns_support(VpcIds=[vpc.id])
-    assert response.get("Vpcs")[0].get("ClassicLinkDnsSupported").should.be.true
+    assert response.get("Vpcs")[0].get("ClassicLinkDnsSupported").should.equal(True)
 
 
 @mock_ec2
@@ -1209,20 +947,20 @@ def test_describe_vpc_gateway_end_points():
         VpcId=vpc["VpcId"],
         ServiceName="com.amazonaws.us-east-1.s3",
         RouteTableIds=[route_table["RouteTableId"]],
-        VpcEndpointType="gateway",
+        VpcEndpointType="Gateway",
     )["VpcEndpoint"]
     our_id = vpc_end_point["VpcEndpointId"]
 
     all_endpoints = retrieve_all_endpoints(ec2)
     [e["VpcEndpointId"] for e in all_endpoints].should.contain(our_id)
     our_endpoint = [e for e in all_endpoints if e["VpcEndpointId"] == our_id][0]
-    vpc_end_point["PrivateDnsEnabled"].should.be.true
-    our_endpoint["PrivateDnsEnabled"].should.be.true
+    vpc_end_point["PrivateDnsEnabled"].should.equal(True)
+    our_endpoint["PrivateDnsEnabled"].should.equal(True)
 
     our_endpoint["VpcId"].should.equal(vpc["VpcId"])
     our_endpoint["RouteTableIds"].should.equal([route_table["RouteTableId"]])
 
-    our_endpoint.should.have.key("VpcEndpointType").equal("gateway")
+    our_endpoint.should.have.key("VpcEndpointType").equal("Gateway")
     our_endpoint.should.have.key("ServiceName").equal("com.amazonaws.us-east-1.s3")
     our_endpoint.should.have.key("State").equal("available")
 
@@ -1232,10 +970,15 @@ def test_describe_vpc_gateway_end_points():
     endpoint_by_id["VpcEndpointId"].should.equal(our_id)
     endpoint_by_id["VpcId"].should.equal(vpc["VpcId"])
     endpoint_by_id["RouteTableIds"].should.equal([route_table["RouteTableId"]])
-    endpoint_by_id["VpcEndpointType"].should.equal("gateway")
+    endpoint_by_id["VpcEndpointType"].should.equal("Gateway")
     endpoint_by_id["ServiceName"].should.equal("com.amazonaws.us-east-1.s3")
     endpoint_by_id["State"].should.equal("available")
 
+    gateway_endpoints = ec2.describe_vpc_endpoints(
+        Filters=[{"Name": "vpc-endpoint-type", "Values": ["Gateway"]}]
+    )["VpcEndpoints"]
+    [e["VpcEndpointId"] for e in gateway_endpoints].should.contain(our_id)
+
     with pytest.raises(ClientError) as ex:
         ec2.describe_vpc_endpoints(VpcEndpointIds=[route_table["RouteTableId"]])
     err = ex.value.response["Error"]
@@ -1266,8 +1009,8 @@ def test_describe_vpc_interface_end_points():
     all_endpoints = retrieve_all_endpoints(ec2)
     [e["VpcEndpointId"] for e in all_endpoints].should.contain(our_id)
     our_endpoint = [e for e in all_endpoints if e["VpcEndpointId"] == our_id][0]
-    vpc_end_point["PrivateDnsEnabled"].should.be.true
-    our_endpoint["PrivateDnsEnabled"].should.be.true
+    vpc_end_point["PrivateDnsEnabled"].should.equal(True)
+    our_endpoint["PrivateDnsEnabled"].should.equal(True)
 
     our_endpoint["VpcId"].should.equal(vpc["VpcId"])
     our_endpoint.should_not.have.key("RouteTableIds")
@@ -1359,3 +1102,16 @@ def test_describe_vpcs_dryrun():
     ex.value.response["Error"]["Message"].should.equal(
         "An error occurred (DryRunOperation) when calling the DescribeVpcs operation: Request would have succeeded, but DryRun flag is set"
     )
+
+
+@mock_ec2
+def test_describe_prefix_lists():
+    client = boto3.client("ec2", region_name="us-east-1")
+    result_unfiltered = client.describe_prefix_lists()
+    assert len(result_unfiltered["PrefixLists"]) > 1
+    result_filtered = client.describe_prefix_lists(
+        Filters=[
+            {"Name": "prefix-list-name", "Values": ["com.amazonaws.us-east-1.s3"]},
+        ]
+    )
+    assert len(result_filtered["PrefixLists"]) == 1
