@@ -22,7 +22,7 @@ from moto.core import ACCOUNT_ID
 
 def _create_image_digest(contents=None):
     if not contents:
-        contents = "docker_image{0}".format(int(random() * 10 ** 6))
+        contents = "docker_image{0}".format(int(random() * 10**6))
     return "sha256:%s" % hashlib.sha256(contents.encode("utf-8")).hexdigest()
 
 
@@ -116,6 +116,37 @@ def test_create_repository_with_non_default_config():
     )
 
 
+@mock_ecr
+def test_create_repository_in_different_account():
+    # given
+    client = boto3.client("ecr", region_name="us-east-1")
+    repo_name = "test-repo"
+
+    # when passing in a custom registry ID
+    response = client.create_repository(
+        registryId="222222222222", repositoryName=repo_name
+    )
+
+    # then we should persist this ID
+    repo = response["repository"]
+    repo.should.have.key("registryId").equals("222222222222")
+    repo.should.have.key("repositoryArn").equals(
+        "arn:aws:ecr:us-east-1:222222222222:repository/test-repo"
+    )
+
+    # then this repo should be returned with the correct ID
+    repo = client.describe_repositories()["repositories"][0]
+    repo.should.have.key("registryId").equals("222222222222")
+
+    # then we can search for repos with this ID
+    response = client.describe_repositories(registryId="222222222222")
+    response.should.have.key("repositories").length_of(1)
+
+    # then this repo is not found when searching for a different ID
+    response = client.describe_repositories(registryId=ACCOUNT_ID)
+    response.should.have.key("repositories").length_of(0)
+
+
 @mock_ecr
 def test_create_repository_with_aws_managed_kms():
     # given
@@ -1218,13 +1249,47 @@ def test_batch_delete_image_with_mismatched_digest_and_tag():
     )
 
 
+@mock_ecr
+def test_delete_batch_image_with_multiple_images():
+    client = boto3.client("ecr", region_name="us-east-1")
+    repo_name = "test-repo"
+    client.create_repository(repositoryName=repo_name)
+
+    # Populate mock repo with images
+    for i in range(10):
+        client.put_image(
+            repositoryName=repo_name, imageManifest=f"manifest{i}", imageTag=f"tag{i}"
+        )
+
+    # Pull down image digests for each image in the mock repo
+    repo_images = client.describe_images(repositoryName=repo_name)["imageDetails"]
+    image_digests = [{"imageDigest": image["imageDigest"]} for image in repo_images]
+
+    # Pick a couple of images to delete
+    images_to_delete = image_digests[5:7]
+
+    # Delete the images
+    response = client.batch_delete_image(
+        repositoryName=repo_name, imageIds=images_to_delete
+    )
+    response["imageIds"].should.have.length_of(2)
+    response["failures"].should.equal([])
+
+    # Verify other images still exist
+    repo_images = client.describe_images(repositoryName=repo_name)["imageDetails"]
+    image_tags = [img["imageTags"][0] for img in repo_images]
+    image_tags.should.equal(
+        ["tag0", "tag1", "tag2", "tag3", "tag4", "tag7", "tag8", "tag9"]
+    )
+
+
 @mock_ecr
 def test_list_tags_for_resource():
     # given
     client = boto3.client("ecr", region_name="eu-central-1")
     repo_name = "test-repo"
     arn = client.create_repository(
-        repositoryName=repo_name, tags=[{"Key": "key-1", "Value": "value-1"}],
+        repositoryName=repo_name, tags=[{"Key": "key-1", "Value": "value-1"}]
     )["repository"]["repositoryArn"]
 
     # when
@@ -1266,7 +1331,7 @@ def test_list_tags_for_resource_error_invalid_param():
 
     # when
     with pytest.raises(ClientError) as e:
-        client.list_tags_for_resource(resourceArn="invalid",)
+        client.list_tags_for_resource(resourceArn="invalid")
 
     # then
     ex = e.value
@@ -1285,7 +1350,7 @@ def test_tag_resource():
     client = boto3.client("ecr", region_name="eu-central-1")
     repo_name = "test-repo"
     arn = client.create_repository(
-        repositoryName=repo_name, tags=[{"Key": "key-1", "Value": "value-1"}],
+        repositoryName=repo_name, tags=[{"Key": "key-1", "Value": "value-1"}]
     )["repository"]["repositoryArn"]
 
     # when
@@ -1387,7 +1452,7 @@ def test_put_image_tag_mutability():
 
     # when
     response = client.put_image_tag_mutability(
-        repositoryName=repo_name, imageTagMutability="IMMUTABLE",
+        repositoryName=repo_name, imageTagMutability="IMMUTABLE"
     )
 
     # then
@@ -1409,7 +1474,7 @@ def test_put_image_tag_mutability_error_not_exists():
     # when
     with pytest.raises(ClientError) as e:
         client.put_image_tag_mutability(
-            repositoryName=repo_name, imageTagMutability="IMMUTABLE",
+            repositoryName=repo_name, imageTagMutability="IMMUTABLE"
         )
 
     # then
@@ -1434,7 +1499,7 @@ def test_put_image_tag_mutability_error_invalid_param():
     # when
     with pytest.raises(ClientError) as e:
         client.put_image_tag_mutability(
-            repositoryName=repo_name, imageTagMutability="invalid",
+            repositoryName=repo_name, imageTagMutability="invalid"
         )
 
     # then
@@ -1486,7 +1551,7 @@ def test_put_image_scanning_configuration_error_not_exists():
     # when
     with pytest.raises(ClientError) as e:
         client.put_image_scanning_configuration(
-            repositoryName=repo_name, imageScanningConfiguration={"scanOnPush": True},
+            repositoryName=repo_name, imageScanningConfiguration={"scanOnPush": True}
         )
 
     # then
@@ -1520,7 +1585,7 @@ def test_set_repository_policy():
 
     # when
     response = client.set_repository_policy(
-        repositoryName=repo_name, policyText=json.dumps(policy),
+        repositoryName=repo_name, policyText=json.dumps(policy)
     )
 
     # then
@@ -1550,7 +1615,7 @@ def test_set_repository_policy_error_not_exists():
     # when
     with pytest.raises(ClientError) as e:
         client.set_repository_policy(
-            repositoryName=repo_name, policyText=json.dumps(policy),
+            repositoryName=repo_name, policyText=json.dumps(policy)
         )
 
     # then
@@ -1579,7 +1644,7 @@ def test_set_repository_policy_error_invalid_param():
     # when
     with pytest.raises(ClientError) as e:
         client.set_repository_policy(
-            repositoryName=repo_name, policyText=json.dumps(policy),
+            repositoryName=repo_name, policyText=json.dumps(policy)
         )
 
     # then
@@ -1611,7 +1676,7 @@ def test_get_repository_policy():
         ],
     }
     client.set_repository_policy(
-        repositoryName=repo_name, policyText=json.dumps(policy),
+        repositoryName=repo_name, policyText=json.dumps(policy)
     )
 
     # when
@@ -1687,7 +1752,7 @@ def test_delete_repository_policy():
         ],
     }
     client.set_repository_policy(
-        repositoryName=repo_name, policyText=json.dumps(policy),
+        repositoryName=repo_name, policyText=json.dumps(policy)
     )
 
     # when
@@ -1775,7 +1840,7 @@ def test_put_lifecycle_policy():
 
     # when
     response = client.put_lifecycle_policy(
-        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy),
+        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy)
     )
 
     # then
@@ -1843,7 +1908,7 @@ def test_get_lifecycle_policy():
         ]
     }
     client.put_lifecycle_policy(
-        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy),
+        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy)
     )
 
     # when
@@ -1923,7 +1988,7 @@ def test_delete_lifecycle_policy():
         ]
     }
     client.put_lifecycle_policy(
-        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy),
+        repositoryName=repo_name, lifecyclePolicyText=json.dumps(policy)
     )
 
     # when
@@ -1988,7 +2053,12 @@ def test_delete_lifecycle_policy_error_policy_not_exists():
 
 
 @mock_ecr
-def test_put_registry_policy():
+@pytest.mark.parametrize(
+    "actions",
+    ["ecr:CreateRepository", ["ecr:CreateRepository", "ecr:ReplicateImage"]],
+    ids=["single-action", "multiple-actions"],
+)
+def test_put_registry_policy(actions):
     # given
     client = boto3.client("ecr", region_name="eu-central-1")
     policy = {
@@ -1999,7 +2069,7 @@ def test_put_registry_policy():
                 "Principal": {
                     "AWS": ["arn:aws:iam::111111111111:root", "222222222222"]
                 },
-                "Action": ["ecr:CreateRepository", "ecr:ReplicateImage"],
+                "Action": actions,
                 "Resource": "*",
             }
         ],
@@ -2324,7 +2394,7 @@ def test_describe_image_scan_findings():
                 "attributes": [
                     {"key": "package_version", "value": "9.9.9"},
                     {"key": "package_name", "value": "moto_fake"},
-                    {"key": "CVSS2_VECTOR", "value": "AV:N/AC:L/Au:N/C:P/I:P/A:P",},
+                    {"key": "CVSS2_VECTOR", "value": "AV:N/AC:L/Au:N/C:P/I:P/A:P"},
                     {"key": "CVSS2_SCORE", "value": "7.5"},
                 ],
             }
@@ -2419,9 +2489,7 @@ def test_put_replication_configuration():
     # given
     client = boto3.client("ecr", region_name="eu-central-1")
     config = {
-        "rules": [
-            {"destinations": [{"region": "eu-west-1", "registryId": ACCOUNT_ID},]},
-        ]
+        "rules": [{"destinations": [{"region": "eu-west-1", "registryId": ACCOUNT_ID}]}]
     }
 
     # when
