@@ -32,10 +32,49 @@ def test_create_target_group_with_invalid_healthcheck_protocol():
     err = exc.value.response["Error"]
     err["Code"].should.equal("ValidationError")
     err["Message"].should.equal(
-        "Value /HTTP at 'healthCheckProtocol' failed to satisfy constraint: Member must satisfy enum value set: ['HTTPS', 'HTTP', 'TCP']"
+        "Value /HTTP at 'healthCheckProtocol' failed to satisfy constraint: Member must satisfy enum value set: ['HTTPS', 'HTTP', 'TCP', 'TLS', 'UDP', 'TCP_UDP', 'GENEVE']"
     )
 
 
+@mock_elbv2
+@mock_ec2
+def test_create_target_group_with_tags():
+    response, vpc, _, _, _, conn = create_load_balancer()
+
+    response = conn.create_target_group(
+        Name="a-target",
+        Protocol="HTTP",
+        Port=8080,
+        VpcId=vpc.id,
+        HealthCheckProtocol="HTTP",
+        HealthCheckPort="8080",
+        HealthCheckPath="/",
+        HealthCheckIntervalSeconds=5,
+        HealthCheckTimeoutSeconds=5,
+        HealthyThresholdCount=5,
+        UnhealthyThresholdCount=2,
+        Matcher={"HttpCode": "200"},
+        Tags=[{"Key": "key1", "Value": "val1"}],
+    )
+    target_group = response.get("TargetGroups")[0]
+    target_group_arn = target_group["TargetGroupArn"]
+
+    # Add tags to the target group
+    conn.add_tags(
+        ResourceArns=[target_group_arn],
+        Tags=[{"Key": "key2", "Value": "val2"}],
+    )
+    conn.describe_tags(ResourceArns=[target_group_arn])["TagDescriptions"][0][
+        "Tags"
+    ].should.equal([{"Key": "key1", "Value": "val1"}, {"Key": "key2", "Value": "val2"}])
+
+    # Verify they can be removed
+    conn.remove_tags(ResourceArns=[target_group_arn], TagKeys=["key1"])
+    conn.describe_tags(ResourceArns=[target_group_arn])["TagDescriptions"][0][
+        "Tags"
+    ].should.equal([{"Key": "key2", "Value": "val2"}])
+
+
 @mock_elbv2
 @mock_ec2
 def test_create_target_group_and_listeners():
@@ -58,15 +97,8 @@ def test_create_target_group_and_listeners():
         Matcher={"HttpCode": "200"},
     )
     target_group = response.get("TargetGroups")[0]
-    target_group_arn = target_group["TargetGroupArn"]
-
-    # Add tags to the target group
-    conn.add_tags(
-        ResourceArns=[target_group_arn], Tags=[{"Key": "target", "Value": "group"}]
-    )
-    conn.describe_tags(ResourceArns=[target_group_arn])["TagDescriptions"][0][
-        "Tags"
-    ].should.equal([{"Key": "target", "Value": "group"}])
+    target_group_arn = target_group.get("TargetGroupArn")
+    target_group.get("HealthCheckProtocol").should.equal("HTTP")
 
     # Check it's in the describe_target_groups response
     response = conn.describe_target_groups()
@@ -77,15 +109,13 @@ def test_create_target_group_and_listeners():
         LoadBalancerArn=load_balancer_arn,
         Protocol="HTTP",
         Port=80,
-        DefaultActions=[
-            {"Type": "forward", "TargetGroupArn": target_group.get("TargetGroupArn")}
-        ],
+        DefaultActions=[{"Type": "forward", "TargetGroupArn": target_group_arn}],
     )
     listener = response.get("Listeners")[0]
     listener.get("Port").should.equal(80)
     listener.get("Protocol").should.equal("HTTP")
     listener.get("DefaultActions").should.equal(
-        [{"TargetGroupArn": target_group.get("TargetGroupArn"), "Type": "forward"}]
+        [{"TargetGroupArn": target_group_arn, "Type": "forward"}]
     )
     http_listener_arn = listener.get("ListenerArn")
 
@@ -95,7 +125,7 @@ def test_create_target_group_and_listeners():
     response.get("TargetGroups").should.have.length_of(1)
 
     # And another with SSL
-    actions = {"Type": "forward", "TargetGroupArn": target_group.get("TargetGroupArn")}
+    actions = {"Type": "forward", "TargetGroupArn": target_group_arn}
     response = conn.create_listener(
         LoadBalancerArn=load_balancer_arn,
         Protocol="HTTPS",
@@ -122,7 +152,7 @@ def test_create_target_group_and_listeners():
         ]
     )
     listener.get("DefaultActions").should.equal(
-        [{"TargetGroupArn": target_group.get("TargetGroupArn"), "Type": "forward"}]
+        [{"TargetGroupArn": target_group_arn, "Type": "forward"}]
     )
 
     https_listener_arn = listener.get("ListenerArn")
@@ -142,18 +172,18 @@ def test_create_target_group_and_listeners():
 
     conn.create_rule(
         ListenerArn=http_listener_arn,
-        Conditions=[{"Field": "path-pattern", "Values": ["/*"]},],
+        Conditions=[{"Field": "path-pattern", "Values": ["/*"]}],
         Priority=3,
         Actions=[actions],
     )
     # Try to delete the target group and it fails because there's a
     # listener referencing it
     with pytest.raises(ClientError) as e:
-        conn.delete_target_group(TargetGroupArn=target_group.get("TargetGroupArn"))
+        conn.delete_target_group(TargetGroupArn=target_group_arn)
     e.value.operation_name.should.equal("DeleteTargetGroup")
     e.value.args.should.equal(
         (
-            "An error occurred (ResourceInUse) when calling the DeleteTargetGroup operation: The target group 'arn:aws:elasticloadbalancing:us-east-1:1:targetgroup/a-target/50dc6c495c0c9188' is currently in use by a listener or a rule",
+            f"An error occurred (ResourceInUse) when calling the DeleteTargetGroup operation: The target group 'arn:aws:elasticloadbalancing:us-east-1:{ACCOUNT_ID}:targetgroup/a-target/50dc6c495c0c9188' is currently in use by a listener or a rule",
         )
     )  # NOQA
 
@@ -181,7 +211,7 @@ def test_create_target_group_and_listeners():
     response.get("TargetGroups").should.have.length_of(1)
 
     # Which we'll now delete
-    conn.delete_target_group(TargetGroupArn=target_group.get("TargetGroupArn"))
+    conn.delete_target_group(TargetGroupArn=target_group_arn)
     response = conn.describe_target_groups()
     response.get("TargetGroups").should.have.length_of(0)
 
@@ -357,10 +387,11 @@ def test_target_group_attributes():
 
     # The attributes should start with the two defaults
     response = conn.describe_target_group_attributes(TargetGroupArn=target_group_arn)
-    response["Attributes"].should.have.length_of(2)
+    response["Attributes"].should.have.length_of(5)
     attributes = {attr["Key"]: attr["Value"] for attr in response["Attributes"]}
     attributes["deregistration_delay.timeout_seconds"].should.equal("300")
     attributes["stickiness.enabled"].should.equal("false")
+    attributes["waf.fail_open.enabled"].should.equal("false")
 
     # Add cookie stickiness
     response = conn.modify_target_group_attributes(
@@ -379,7 +410,7 @@ def test_target_group_attributes():
 
     # These new values should be in the full attribute list
     response = conn.describe_target_group_attributes(TargetGroupArn=target_group_arn)
-    response["Attributes"].should.have.length_of(3)
+    response["Attributes"].should.have.length_of(6)
     attributes = {attr["Key"]: attr["Value"] for attr in response["Attributes"]}
     attributes["stickiness.type"].should.equal("lb_cookie")
     attributes["stickiness.enabled"].should.equal("true")
@@ -499,6 +530,8 @@ def test_modify_target_group():
     response["TargetGroups"][0]["HealthCheckProtocol"].should.equal("HTTPS")
     response["TargetGroups"][0]["HealthCheckTimeoutSeconds"].should.equal(10)
     response["TargetGroups"][0]["HealthyThresholdCount"].should.equal(10)
+    response["TargetGroups"][0].should.have.key("Protocol").equals("HTTP")
+    response["TargetGroups"][0].should.have.key("ProtocolVersion").equals("HTTP1")
     response["TargetGroups"][0]["UnhealthyThresholdCount"].should.equal(4)
 
 
@@ -535,12 +568,12 @@ def test_delete_target_group_after_modifying_listener():
     load_balancer_arn = response.get("LoadBalancers")[0].get("LoadBalancerArn")
 
     response = client.create_target_group(
-        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id,
+        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id
     )
     target_group_arn1 = response.get("TargetGroups")[0]["TargetGroupArn"]
 
     response = client.create_target_group(
-        Name="a-target-2", Protocol="HTTPS", Port=8081, VpcId=vpc.id,
+        Name="a-target-2", Protocol="HTTPS", Port=8081, VpcId=vpc.id
     )
     target_group_arn2 = response.get("TargetGroups")[0]["TargetGroupArn"]
 
@@ -554,7 +587,7 @@ def test_delete_target_group_after_modifying_listener():
 
     client.modify_listener(
         ListenerArn=listener_arn,
-        DefaultActions=[{"Type": "forward", "TargetGroupArn": target_group_arn2,}],
+        DefaultActions=[{"Type": "forward", "TargetGroupArn": target_group_arn2}],
     )
 
     response = conn.describe_listeners(LoadBalancerArn=load_balancer_arn)
@@ -584,12 +617,12 @@ def test_create_listener_with_multiple_target_groups():
     load_balancer_arn = response.get("LoadBalancers")[0].get("LoadBalancerArn")
 
     response = client.create_target_group(
-        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id,
+        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id
     )
     target_group_arn1 = response.get("TargetGroups")[0]["TargetGroupArn"]
 
     response = client.create_target_group(
-        Name="a-target-2", Protocol="HTTPS", Port=8081, VpcId=vpc.id,
+        Name="a-target-2", Protocol="HTTPS", Port=8081, VpcId=vpc.id
     )
     target_group_arn2 = response.get("TargetGroups")[0]["TargetGroupArn"]
 
@@ -658,7 +691,7 @@ def test_delete_target_group_while_listener_still_exists():
     load_balancer_arn = response.get("LoadBalancers")[0].get("LoadBalancerArn")
 
     response = client.create_target_group(
-        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id,
+        Name="a-target", Protocol="HTTP", Port=8080, VpcId=vpc.id
     )
     target_group_arn1 = response.get("TargetGroups")[0]["TargetGroupArn"]
 
