@@ -48,7 +48,7 @@ input_instance_groups = [
     {
         "InstanceCount": 6,
         "InstanceRole": "TASK",
-        "InstanceType": "c1.large",
+        "InstanceType": "c3.large",
         "Market": "SPOT",
         "Name": "task-1",
         "BidPrice": "0.07",
@@ -544,8 +544,10 @@ def test_run_job_flow_with_instance_groups_with_autoscaling():
         if "AutoScalingPolicy" in y:
             x["AutoScalingPolicy"]["Status"]["State"].should.equal("ATTACHED")
             returned_policy = deepcopy(x["AutoScalingPolicy"])
-            auto_scaling_policy_with_cluster_id = _patch_cluster_id_placeholder_in_autoscaling_policy(
-                y["AutoScalingPolicy"], cluster_id
+            auto_scaling_policy_with_cluster_id = (
+                _patch_cluster_id_placeholder_in_autoscaling_policy(
+                    y["AutoScalingPolicy"], cluster_id
+                )
             )
             del returned_policy["Status"]
             returned_policy.should.equal(auto_scaling_policy_with_cluster_id)
@@ -571,8 +573,10 @@ def test_put_remove_auto_scaling_policy():
         AutoScalingPolicy=auto_scaling_policy,
     )
 
-    auto_scaling_policy_with_cluster_id = _patch_cluster_id_placeholder_in_autoscaling_policy(
-        auto_scaling_policy, cluster_id
+    auto_scaling_policy_with_cluster_id = (
+        _patch_cluster_id_placeholder_in_autoscaling_policy(
+            auto_scaling_policy, cluster_id
+        )
     )
     del resp["AutoScalingPolicy"]["Status"]
     resp["AutoScalingPolicy"].should.equal(auto_scaling_policy_with_cluster_id)
@@ -713,9 +717,7 @@ def test_terminate_protected_job_flow_raises_error():
         JobFlowIds=[cluster_id], TerminationProtected=True
     )
     with pytest.raises(ClientError) as ex:
-        client.terminate_job_flows(
-            JobFlowIds=[cluster_id,]
-        )
+        client.terminate_job_flows(JobFlowIds=[cluster_id])
     error = ex.value.response["Error"]
     error["Code"].should.equal("ValidationException")
     error["Message"].should.equal(
@@ -1011,6 +1013,10 @@ def test_steps():
 
     steps = client.list_steps(ClusterId=cluster_id)["Steps"]
     steps.should.have.length_of(2)
+    # Steps should be returned in reverse order.
+    sorted(
+        steps, key=lambda o: o["Status"]["Timeline"]["CreationDateTime"], reverse=True
+    ).should.equal(steps)
     for x in steps:
         y = expected[x["Name"]]
         x["ActionOnFailure"].should.equal("TERMINATE_CLUSTER")
@@ -1042,7 +1048,7 @@ def test_steps():
         # x['Status']['Timeline']['EndDateTime'].should.be.a('datetime.datetime')
         # x['Status']['Timeline']['StartDateTime'].should.be.a('datetime.datetime')
 
-    step_id = steps[0]["Id"]
+    step_id = steps[-1]["Id"]  # Last step is first created step.
     steps = client.list_steps(ClusterId=cluster_id, StepIds=[step_id])["Steps"]
     steps.should.have.length_of(1)
     steps[0]["Id"].should.equal(step_id)
