@@ -202,7 +202,9 @@ class TestListVirtualClusters:
     tomorrow = today + timedelta(days=1)
 
     @pytest.fixture(autouse=True)
-    def _setup_environment(self, client, virtual_cluster_factory):
+    def _setup_environment(
+        self, client, virtual_cluster_factory
+    ):  # pylint: disable=unused-argument
         self.client = client
 
     @pytest.mark.parametrize(
@@ -405,7 +407,7 @@ class TestCancelJobRun:
         err = exc.value.response["Error"]
 
         assert err["Code"] == "ResourceNotFoundException"
-        assert err["Message"] == f"Job run 123456789abcdefghij doesn't exist."
+        assert err["Message"] == "Job run 123456789abcdefghij doesn't exist."
 
     def test_wrong_job_state(self):
         with pytest.raises(ClientError) as exc:
@@ -428,7 +430,9 @@ class TestListJobRuns:
     tomorrow = today + timedelta(days=1)
 
     @pytest.fixture(autouse=True)
-    def _setup_environment(self, client, virtual_cluster_factory, job_factory):
+    def _setup_environment(
+        self, client, virtual_cluster_factory, job_factory
+    ):  # pylint: disable=unused-argument
         self.client = client
         self.virtual_cluster_id = virtual_cluster_factory[0]
 
@@ -577,4 +581,4 @@ class TestDescribeJobRun:
         err = exc.value.response["Error"]
 
         assert err["Code"] == "ResourceNotFoundException"
-        assert err["Message"] == f"Job run 123456789abcdefghij doesn't exist."
+        assert err["Message"] == "Job run 123456789abcdefghij doesn't exist."
