@@ -3,7 +3,7 @@ import json
 import boto3
 from botocore.exceptions import ClientError
 import pytest
-import sure  # pylint: disable=unused-import
+import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_iam
 
