@@ -22,7 +22,7 @@ def test_get_hls_streaming_session_url():
         region_name=region_name,
         endpoint_url=data_endpoint,
     )
-    res = client.get_hls_streaming_session_url(StreamName=stream_name,)
+    res = client.get_hls_streaming_session_url(StreamName=stream_name)
     reg_exp = r"^{}/hls/v1/getHLSMasterPlaylist.m3u8\?SessionToken\=.+$".format(
         data_endpoint
     )
@@ -46,7 +46,7 @@ def test_get_dash_streaming_session_url():
         region_name=region_name,
         endpoint_url=data_endpoint,
     )
-    res = client.get_dash_streaming_session_url(StreamName=stream_name,)
+    res = client.get_dash_streaming_session_url(StreamName=stream_name)
     reg_exp = r"^{}/dash/v1/getDASHManifest.mpd\?SessionToken\=.+$".format(
         data_endpoint
     )
