@@ -62,7 +62,6 @@ def test_create_key():
         KeyUsage="ENCRYPT_DECRYPT",
         Tags=[{"TagKey": "project", "TagValue": "moto"}],
     )
-    print(key["KeyMetadata"])
 
     key["KeyMetadata"]["Arn"].should.equal(
         "arn:aws:kms:us-east-1:{}:key/{}".format(
@@ -73,23 +72,23 @@ def test_create_key():
     key["KeyMetadata"]["CreationDate"].should.be.a(datetime)
     key["KeyMetadata"]["CustomerMasterKeySpec"].should.equal("SYMMETRIC_DEFAULT")
     key["KeyMetadata"]["Description"].should.equal("my key")
-    key["KeyMetadata"]["Enabled"].should.be.ok
+    key["KeyMetadata"]["Enabled"].should.equal(True)
     key["KeyMetadata"]["EncryptionAlgorithms"].should.equal(["SYMMETRIC_DEFAULT"])
-    key["KeyMetadata"]["KeyId"].should_not.be.empty
+    key["KeyMetadata"]["KeyId"].should.match("[-a-zA-Z0-9]+")
     key["KeyMetadata"]["KeyManager"].should.equal("CUSTOMER")
     key["KeyMetadata"]["KeyState"].should.equal("Enabled")
     key["KeyMetadata"]["KeyUsage"].should.equal("ENCRYPT_DECRYPT")
     key["KeyMetadata"]["Origin"].should.equal("AWS_KMS")
     key["KeyMetadata"].should_not.have.key("SigningAlgorithms")
 
-    key = conn.create_key(KeyUsage="ENCRYPT_DECRYPT", CustomerMasterKeySpec="RSA_2048",)
+    key = conn.create_key(KeyUsage="ENCRYPT_DECRYPT", CustomerMasterKeySpec="RSA_2048")
 
     sorted(key["KeyMetadata"]["EncryptionAlgorithms"]).should.equal(
         ["RSAES_OAEP_SHA_1", "RSAES_OAEP_SHA_256"]
     )
     key["KeyMetadata"].should_not.have.key("SigningAlgorithms")
 
-    key = conn.create_key(KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="RSA_2048",)
+    key = conn.create_key(KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="RSA_2048")
 
     key["KeyMetadata"].should_not.have.key("EncryptionAlgorithms")
     sorted(key["KeyMetadata"]["SigningAlgorithms"]).should.equal(
@@ -104,22 +103,18 @@ def test_create_key():
     )
 
     key = conn.create_key(
-        KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_SECG_P256K1",
+        KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_SECG_P256K1"
     )
 
     key["KeyMetadata"].should_not.have.key("EncryptionAlgorithms")
     key["KeyMetadata"]["SigningAlgorithms"].should.equal(["ECDSA_SHA_256"])
 
-    key = conn.create_key(
-        KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_NIST_P384",
-    )
+    key = conn.create_key(KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_NIST_P384")
 
     key["KeyMetadata"].should_not.have.key("EncryptionAlgorithms")
     key["KeyMetadata"]["SigningAlgorithms"].should.equal(["ECDSA_SHA_384"])
 
-    key = conn.create_key(
-        KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_NIST_P521",
-    )
+    key = conn.create_key(KeyUsage="SIGN_VERIFY", CustomerMasterKeySpec="ECC_NIST_P521")
 
     key["KeyMetadata"].should_not.have.key("EncryptionAlgorithms")
     key["KeyMetadata"]["SigningAlgorithms"].should.equal(["ECDSA_SHA_512"])
@@ -129,7 +124,7 @@ def test_create_key():
 @mock_kms
 def test_describe_key(id_or_arn):
     client = boto3.client("kms", region_name="us-east-1")
-    response = client.create_key(Description="my key", KeyUsage="ENCRYPT_DECRYPT",)
+    response = client.create_key(Description="my key", KeyUsage="ENCRYPT_DECRYPT")
     key_id = response["KeyMetadata"][id_or_arn]
 
     response = client.describe_key(KeyId=key_id)
@@ -138,9 +133,9 @@ def test_describe_key(id_or_arn):
     response["KeyMetadata"]["CreationDate"].should.be.a(datetime)
     response["KeyMetadata"]["CustomerMasterKeySpec"].should.equal("SYMMETRIC_DEFAULT")
     response["KeyMetadata"]["Description"].should.equal("my key")
-    response["KeyMetadata"]["Enabled"].should.be.ok
+    response["KeyMetadata"]["Enabled"].should.equal(True)
     response["KeyMetadata"]["EncryptionAlgorithms"].should.equal(["SYMMETRIC_DEFAULT"])
-    response["KeyMetadata"]["KeyId"].should_not.be.empty
+    response["KeyMetadata"]["KeyId"].should.match("[-a-zA-Z0-9]+")
     response["KeyMetadata"]["KeyManager"].should.equal("CUSTOMER")
     response["KeyMetadata"]["KeyState"].should.equal("Enabled")
     response["KeyMetadata"]["KeyUsage"].should.equal("ENCRYPT_DECRYPT")
@@ -387,7 +382,7 @@ def test_disable_key():
     client.disable_key(KeyId=key["KeyMetadata"]["KeyId"])
 
     result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
-    assert result["KeyMetadata"]["Enabled"] == False
+    assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "Disabled"
 
 
@@ -399,7 +394,7 @@ def test_enable_key():
     client.enable_key(KeyId=key["KeyMetadata"]["KeyId"])
 
     result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
-    assert result["KeyMetadata"]["Enabled"] == True
+    assert result["KeyMetadata"]["Enabled"] is True
     assert result["KeyMetadata"]["KeyState"] == "Enabled"
 
 
@@ -420,7 +415,7 @@ def test_schedule_key_deletion():
         assert response["KeyId"] == key["KeyMetadata"]["KeyId"]
 
     result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
-    assert result["KeyMetadata"]["Enabled"] == False
+    assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "PendingDeletion"
     assert "DeletionDate" in result["KeyMetadata"]
 
@@ -446,7 +441,7 @@ def test_schedule_key_deletion_custom():
         assert response["KeyId"] == key["KeyMetadata"]["KeyId"]
 
     result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
-    assert result["KeyMetadata"]["Enabled"] == False
+    assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "PendingDeletion"
     assert "DeletionDate" in result["KeyMetadata"]
 
@@ -460,7 +455,7 @@ def test_cancel_key_deletion():
     assert response["KeyId"] == key["KeyMetadata"]["KeyId"]
 
     result = client.describe_key(KeyId=key["KeyMetadata"]["KeyId"])
-    assert result["KeyMetadata"]["Enabled"] == False
+    assert result["KeyMetadata"]["Enabled"] is False
     assert result["KeyMetadata"]["KeyState"] == "Disabled"
     assert "DeletionDate" not in result["KeyMetadata"]
 
@@ -743,7 +738,7 @@ def test_generate_random(number_of_bytes):
 
 @pytest.mark.parametrize(
     "number_of_bytes,error_type",
-    [(2048, botocore.exceptions.ClientError), (1025, botocore.exceptions.ClientError),],
+    [(2048, botocore.exceptions.ClientError), (1025, botocore.exceptions.ClientError)],
 )
 @mock_kms
 def test_generate_random_invalid_number_of_bytes(number_of_bytes, error_type):
@@ -897,7 +892,7 @@ def test_list_key_policies():
 
 @pytest.mark.parametrize(
     "reserved_alias",
-    ["alias/aws/ebs", "alias/aws/s3", "alias/aws/redshift", "alias/aws/rds",],
+    ["alias/aws/ebs", "alias/aws/s3", "alias/aws/redshift", "alias/aws/rds"],
 )
 @mock_kms
 def test__create_alias__raises_if_reserved_alias(reserved_alias):
@@ -913,7 +908,7 @@ def test__create_alias__raises_if_reserved_alias(reserved_alias):
 
 
 @pytest.mark.parametrize(
-    "name", ["alias/my-alias!", "alias/my-alias$", "alias/my-alias@",]
+    "name", ["alias/my-alias!", "alias/my-alias$", "alias/my-alias@"]
 )
 @mock_kms
 def test__create_alias__raises_if_alias_has_restricted_characters(name):
@@ -1043,3 +1038,71 @@ def test__delete_alias__raises_if_alias_is_not_found():
     err["Message"].should.equal(
         f"Alias arn:aws:kms:us-east-1:{ACCOUNT_ID}:alias/unknown-alias is not found."
     )
+
+
+def sort(lst):
+    return sorted(lst, key=lambda d: d.keys())
+
+
+def _check_tags(key_id, created_tags, client):
+    result = client.list_resource_tags(KeyId=key_id)
+    actual = result.get("Tags", [])
+    assert sort(created_tags) == sort(actual)
+
+    client.untag_resource(KeyId=key_id, TagKeys=["key1"])
+
+    actual = client.list_resource_tags(KeyId=key_id).get("Tags", [])
+    expected = [{"TagKey": "key2", "TagValue": "value2"}]
+    assert sort(expected) == sort(actual)
+
+
+@mock_kms
+def test_key_tag_on_create_key_happy():
+    client = boto3.client("kms", region_name="us-east-1")
+
+    tags = [
+        {"TagKey": "key1", "TagValue": "value1"},
+        {"TagKey": "key2", "TagValue": "value2"},
+    ]
+    key = client.create_key(Description="test-key-tagging", Tags=tags)
+    _check_tags(key["KeyMetadata"]["KeyId"], tags, client)
+
+
+@mock_kms
+def test_key_tag_on_create_key_on_arn_happy():
+    client = boto3.client("kms", region_name="us-east-1")
+
+    tags = [
+        {"TagKey": "key1", "TagValue": "value1"},
+        {"TagKey": "key2", "TagValue": "value2"},
+    ]
+    key = client.create_key(Description="test-key-tagging", Tags=tags)
+    _check_tags(key["KeyMetadata"]["Arn"], tags, client)
+
+
+@mock_kms
+def test_key_tag_added_happy():
+    client = boto3.client("kms", region_name="us-east-1")
+
+    key = client.create_key(Description="test-key-tagging")
+    key_id = key["KeyMetadata"]["KeyId"]
+    tags = [
+        {"TagKey": "key1", "TagValue": "value1"},
+        {"TagKey": "key2", "TagValue": "value2"},
+    ]
+    client.tag_resource(KeyId=key_id, Tags=tags)
+    _check_tags(key_id, tags, client)
+
+
+@mock_kms
+def test_key_tag_added_arn_based_happy():
+    client = boto3.client("kms", region_name="us-east-1")
+
+    key = client.create_key(Description="test-key-tagging")
+    key_id = key["KeyMetadata"]["Arn"]
+    tags = [
+        {"TagKey": "key1", "TagValue": "value1"},
+        {"TagKey": "key2", "TagValue": "value2"},
+    ]
+    client.tag_resource(KeyId=key_id, Tags=tags)
+    _check_tags(key_id, tags, client)
