@@ -11,7 +11,7 @@ def test_log_group_to_describe_dict():
     kms_key_id = (
         "arn:aws:kms:us-east-1:000000000000:key/51d81fab-b138-4bd2-8a09-07fd6d37224d"
     )
-    kwargs = dict(kmsKeyId=kms_key_id,)
+    kwargs = dict(kmsKeyId=kms_key_id)
 
     # When
     log_group = LogGroup(region, name, tags, **kwargs)
