@@ -143,6 +143,25 @@ def test_list_organizational_units_for_parent():
         validate_organizational_unit(org, dict(OrganizationalUnit=ou))
 
 
+@mock_organizations
+def test_list_organizational_units_pagination():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    root_id = client.list_roots()["Roots"][0]["Id"]
+    for i in range(20):
+        name = "ou" + str(i)
+        client.create_organizational_unit(ParentId=root_id, Name=name)
+    response = client.list_organizational_units_for_parent(ParentId=root_id)
+    response.should_not.have.key("NextToken")
+    len(response["OrganizationalUnits"]).should.be.greater_than_or_equal_to(i)
+
+    paginator = client.get_paginator("list_organizational_units_for_parent")
+    page_iterator = paginator.paginate(MaxResults=5, ParentId=root_id)
+    for page in page_iterator:
+        len(page["OrganizationalUnits"]).should.be.lower_than_or_equal_to(5)
+    page["OrganizationalUnits"][-1]["Name"].should.contain("19")
+
+
 @mock_organizations
 def test_list_organizational_units_for_parent_exception():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -173,6 +192,54 @@ def test_create_account():
     create_status["AccountName"].should.equal(mockname)
 
 
+@mock_organizations
+def test_close_account_returns_nothing():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    create_status = client.create_account(AccountName=mockname, Email=mockemail)[
+        "CreateAccountStatus"
+    ]
+    created_account_id = create_status["AccountId"]
+
+    resp = client.close_account(AccountId=created_account_id)
+
+    del resp["ResponseMetadata"]
+
+    assert resp == {}
+
+
+@mock_organizations
+def test_close_account_puts_account_in_suspended_status():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    create_status = client.create_account(AccountName=mockname, Email=mockemail)[
+        "CreateAccountStatus"
+    ]
+    created_account_id = create_status["AccountId"]
+
+    client.close_account(AccountId=created_account_id)
+
+    account = client.describe_account(AccountId=created_account_id)["Account"]
+    account["Status"].should.equal("SUSPENDED")
+
+
+@mock_organizations
+def test_close_account_id_not_in_org_raises_exception():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    uncreated_fake_account_id = "123456789101"
+
+    with pytest.raises(ClientError) as e:
+        client.close_account(AccountId=uncreated_fake_account_id)
+    ex = e.value
+    ex.operation_name.should.equal("CloseAccount")
+    ex.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
+    ex.response["Error"]["Code"].should.contain("AccountNotFoundException")
+    ex.response["Error"]["Message"].should.equal(
+        "You specified an account that doesn't exist."
+    )
+
+
 @mock_organizations
 def test_describe_create_account_status():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -229,6 +296,25 @@ def test_list_accounts():
     accounts[3]["Email"].should.equal(mockname + "2" + "@" + mockdomain)
 
 
+@mock_organizations
+def test_list_accounts_pagination():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    for i in range(25):
+        name = mockname + str(i)
+        email = name + "@" + mockdomain
+        client.create_account(AccountName=name, Email=email)
+    response = client.list_accounts()
+    response.should_not.have.key("NextToken")
+    len(response["Accounts"]).should.be.greater_than_or_equal_to(i)
+
+    paginator = client.get_paginator("list_accounts")
+    page_iterator = paginator.paginate(MaxResults=5)
+    for page in page_iterator:
+        len(page["Accounts"]).should.be.lower_than_or_equal_to(5)
+    page["Accounts"][-1]["Name"].should.contain("24")
+
+
 @mock_organizations
 def test_list_accounts_for_parent():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -241,6 +327,28 @@ def test_list_accounts_for_parent():
     account_id.should.be.within([account["Id"] for account in response["Accounts"]])
 
 
+@mock_organizations
+def test_list_accounts_for_parent_pagination():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    root_id = client.list_roots()["Roots"][0]["Id"]
+    response = client.list_accounts_for_parent(ParentId=root_id)
+    response.should_not.have.key("NextToken")
+    num_existing_accounts = len(response["Accounts"])
+    for i in range(num_existing_accounts, 21):
+        name = mockname + str(i)
+        email = name + "@" + mockdomain
+        client.create_account(AccountName=name, Email=email)
+    response = client.list_accounts_for_parent(ParentId=root_id)
+    len(response["Accounts"]).should.be.greater_than_or_equal_to(i)
+
+    paginator = client.get_paginator("list_accounts_for_parent")
+    page_iterator = paginator.paginate(MaxResults=5, ParentId=root_id)
+    for page in page_iterator:
+        len(page["Accounts"]).should.be.lower_than_or_equal_to(5)
+    page["Accounts"][-1]["Name"].should.contain("20")
+
+
 @mock_organizations
 def test_move_account():
     client = boto3.client("organizations", region_name="us-east-1")
@@ -411,7 +519,7 @@ def test_get_paginated_list_create_account_status():
     for createAccountStatus in createAccountStatuses:
         validate_create_account_status(createAccountStatus)
     next_token = response["NextToken"]
-    next_token.should_not.be.none
+    next_token.should_not.equal(None)
     response2 = client.list_create_account_status(NextToken=next_token)
     createAccountStatuses.extend(response2["CreateAccountStatuses"])
     createAccountStatuses.should.have.length_of(6)
@@ -420,6 +528,49 @@ def test_get_paginated_list_create_account_status():
         validate_create_account_status(createAccountStatus)
 
 
+@mock_organizations
+def test_remove_account_from_organization():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")["Organization"]
+    create_account_status = client.create_account(
+        AccountName=mockname, Email=mockemail
+    )["CreateAccountStatus"]
+    account_id = create_account_status["AccountId"]
+
+    def created_account_exists(accounts):
+        return any(
+            account
+            for account in accounts
+            if account["Name"] == mockname and account["Email"] == mockemail
+        )
+
+    accounts = client.list_accounts()["Accounts"]
+    assert len(accounts) == 2
+    assert created_account_exists(accounts)
+    client.remove_account_from_organization(AccountId=account_id)
+    accounts = client.list_accounts()["Accounts"]
+    assert len(accounts) == 1
+    assert not created_account_exists(accounts)
+
+
+@mock_organizations
+def test_delete_organization_with_existing_account():
+    client = boto3.client("organizations", region_name="us-east-1")
+    client.create_organization(FeatureSet="ALL")
+    create_account_status = client.create_account(
+        Email=mockemail, AccountName=mockname
+    )["CreateAccountStatus"]
+    account_id = create_account_status["AccountId"]
+    with pytest.raises(ClientError) as e:
+        client.delete_organization()
+    e.match("OrganizationNotEmptyException")
+    client.remove_account_from_organization(AccountId=account_id)
+    client.delete_organization()
+    with pytest.raises(ClientError) as e:
+        client.describe_organization()
+    e.match("AWSOrganizationsNotInUseException")
+
+
 # Service Control Policies
 policy_doc01 = dict(
     Version="2012-10-17",
@@ -1066,7 +1217,7 @@ def test_tag_resource_errors():
 
     with pytest.raises(ClientError) as e:
         client.tag_resource(
-            ResourceId="0A000000X000", Tags=[{"Key": "key", "Value": "value"},],
+            ResourceId="0A000000X000", Tags=[{"Key": "key", "Value": "value"}]
         )
     ex = e.value
     ex.operation_name.should.equal("TagResource")
@@ -1092,14 +1243,14 @@ def test__get_resource_for_tagging_existing_root():
     org = FakeOrganization("ALL")
     root = FakeRoot(org)
 
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     org_backend.ou.append(root)
     response = org_backend._get_resource_for_tagging(root.id)
     response.id.should.equal(root.id)
 
 
 def test__get_resource_for_tagging_existing_non_root():
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     with pytest.raises(TargetNotFoundException) as e:
         org_backend._get_resource_for_tagging("r-abcd")
     ex = e.value
@@ -1111,7 +1262,7 @@ def test__get_resource_for_tagging_existing_non_root():
 def test__get_resource_for_tagging_existing_ou():
     org = FakeOrganization("ALL")
     ou = FakeOrganizationalUnit(org)
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
 
     org_backend.ou.append(ou)
     response = org_backend._get_resource_for_tagging(ou.id)
@@ -1119,7 +1270,7 @@ def test__get_resource_for_tagging_existing_ou():
 
 
 def test__get_resource_for_tagging_non_existing_ou():
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     with pytest.raises(TargetNotFoundException) as e:
         org_backend._get_resource_for_tagging("ou-9oyc-lv2q36ln")
     ex = e.value
@@ -1130,7 +1281,7 @@ def test__get_resource_for_tagging_non_existing_ou():
 
 def test__get_resource_for_tagging_existing_account():
     org = FakeOrganization("ALL")
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     account = FakeAccount(org, AccountName="test", Email="test@test.test")
 
     org_backend.accounts.append(account)
@@ -1139,7 +1290,7 @@ def test__get_resource_for_tagging_existing_account():
 
 
 def test__get_resource_for_tagging_non_existing_account():
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     with pytest.raises(TargetNotFoundException) as e:
         org_backend._get_resource_for_tagging("100326223992")
     ex = e.value
@@ -1150,7 +1301,7 @@ def test__get_resource_for_tagging_non_existing_account():
 
 def test__get_resource_for_tagging_existing_policy():
     org = FakeOrganization("ALL")
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     policy = FakePolicy(org, Type="SERVICE_CONTROL_POLICY")
 
     org_backend.policies.append(policy)
@@ -1159,7 +1310,7 @@ def test__get_resource_for_tagging_existing_policy():
 
 
 def test__get_resource_for_tagging_non_existing_policy():
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     with pytest.raises(TargetNotFoundException) as e:
         org_backend._get_resource_for_tagging("p-y1vas4da")
     ex = e.value
@@ -1169,7 +1320,7 @@ def test__get_resource_for_tagging_non_existing_policy():
 
 
 def test__get_resource_to_tag_incorrect_resource():
-    org_backend = OrganizationsBackend()
+    org_backend = OrganizationsBackend(region_name="N/A", account_id="N/A")
     with pytest.raises(InvalidInputException) as e:
         org_backend._get_resource_for_tagging("10032622399200")
     ex = e.value
@@ -1769,10 +1920,7 @@ def test_enable_policy_type():
     )
     root["Name"].should.equal("Root")
     sorted(root["PolicyTypes"], key=lambda x: x["Type"]).should.equal(
-        [
-            {"Type": "AISERVICES_OPT_OUT_POLICY", "Status": "ENABLED"},
-            {"Type": "SERVICE_CONTROL_POLICY", "Status": "ENABLED"},
-        ]
+        [{"Type": "AISERVICES_OPT_OUT_POLICY", "Status": "ENABLED"}]
     )
 
 
@@ -1799,7 +1947,10 @@ def test_enable_policy_type_errors():
         "You specified a root that doesn't exist."
     )
 
-    # enable policy again ('SERVICE_CONTROL_POLICY' is enabled by default)
+    # enable policy again
+    # given
+    client.enable_policy_type(RootId=root_id, PolicyType="SERVICE_CONTROL_POLICY")
+
     # when
     with pytest.raises(ClientError) as e:
         client.enable_policy_type(RootId=root_id, PolicyType="SERVICE_CONTROL_POLICY")
@@ -1846,9 +1997,7 @@ def test_disable_policy_type():
         utils.ROOT_ARN_FORMAT.format(org["MasterAccountId"], org["Id"], root_id)
     )
     root["Name"].should.equal("Root")
-    root["PolicyTypes"].should.equal(
-        [{"Type": "SERVICE_CONTROL_POLICY", "Status": "ENABLED"}]
-    )
+    root["PolicyTypes"].should.equal([])
 
 
 @mock_organizations
@@ -1943,7 +2092,7 @@ def test_aiservices_opt_out_policy():
     summary["Name"].should.equal("ai-opt-out")
     summary["Description"].should.equal("Opt out of all AI services")
     summary["Type"].should.equal("AISERVICES_OPT_OUT_POLICY")
-    summary["AwsManaged"].should_not.be.ok
+    summary["AwsManaged"].should.equal(False)
     json.loads(response["Policy"]["Content"]).should.equal(ai_policy)
 
     # when
