@@ -1,23 +1,13 @@
 import time
 import datetime
 
-import boto
 import boto3
-from boto.redshift.exceptions import (
-    ClusterNotFound,
-    ClusterParameterGroupNotFound,
-    ClusterSecurityGroupNotFound,
-    ClusterSubnetGroupNotFound,
-    InvalidSubnet,
-)
 from botocore.exceptions import ClientError
 import pytest
 import sure  # noqa # pylint: disable=unused-import
 
 from moto import mock_ec2
-from moto import mock_ec2_deprecated
 from moto import mock_redshift
-from moto import mock_redshift_deprecated
 from moto.core import ACCOUNT_ID
 
 
@@ -148,57 +138,6 @@ def test_no_snapshot_copy_grants():
     len(response["SnapshotCopyGrants"]).should.equal(0)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_cluster():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    cluster_identifier = "my_cluster"
-
-    cluster_response = conn.create_cluster(
-        cluster_identifier,
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-        db_name="my_db",
-        cluster_type="multi-node",
-        availability_zone="us-east-1d",
-        preferred_maintenance_window="Mon:03:00-Mon:11:00",
-        automated_snapshot_retention_period=10,
-        port=1234,
-        cluster_version="1.0",
-        allow_version_upgrade=True,
-        number_of_nodes=3,
-    )
-    cluster_response["CreateClusterResponse"]["CreateClusterResult"]["Cluster"][
-        "ClusterStatus"
-    ].should.equal("creating")
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-
-    cluster["ClusterIdentifier"].should.equal(cluster_identifier)
-    cluster["NodeType"].should.equal("dw.hs1.xlarge")
-    cluster["MasterUsername"].should.equal("username")
-    cluster["DBName"].should.equal("my_db")
-    cluster["ClusterSecurityGroups"][0]["ClusterSecurityGroupName"].should.equal(
-        "Default"
-    )
-    cluster["VpcSecurityGroups"].should.equal([])
-    cluster["ClusterSubnetGroupName"].should.equal(None)
-    cluster["AvailabilityZone"].should.equal("us-east-1d")
-    cluster["PreferredMaintenanceWindow"].should.equal("Mon:03:00-Mon:11:00")
-    cluster["ClusterParameterGroups"][0]["ParameterGroupName"].should.equal(
-        "default.redshift-1.0"
-    )
-    cluster["AutomatedSnapshotRetentionPeriod"].should.equal(10)
-    cluster["Port"].should.equal(1234)
-    cluster["ClusterVersion"].should.equal("1.0")
-    cluster["AllowVersionUpgrade"].should.equal(True)
-    cluster["NumberOfNodes"].should.equal(3)
-
-
 @mock_redshift
 def test_create_cluster_all_attributes():
     """
@@ -285,33 +224,6 @@ def test_create_cluster_all_attributes():
     cluster["NumberOfNodes"].should.equal(3)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_single_node_cluster():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    cluster_identifier = "my_cluster"
-
-    conn.create_cluster(
-        cluster_identifier,
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-        db_name="my_db",
-        cluster_type="single-node",
-    )
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-
-    cluster["ClusterIdentifier"].should.equal(cluster_identifier)
-    cluster["NodeType"].should.equal("dw.hs1.xlarge")
-    cluster["MasterUsername"].should.equal("username")
-    cluster["DBName"].should.equal("my_db")
-    cluster["NumberOfNodes"].should.equal(1)
-
-
 @mock_redshift
 def test_create_single_node_cluster_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -338,38 +250,6 @@ def test_create_single_node_cluster_boto3():
     cluster["NumberOfNodes"].should.equal(1)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_default_cluster_attributes():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    cluster_identifier = "my_cluster"
-
-    conn.create_cluster(
-        cluster_identifier,
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-    )
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-
-    cluster["DBName"].should.equal("dev")
-    cluster["ClusterSubnetGroupName"].should.equal(None)
-    assert "us-east-" in cluster["AvailabilityZone"]
-    cluster["PreferredMaintenanceWindow"].should.equal("Mon:03:00-Mon:03:30")
-    cluster["ClusterParameterGroups"][0]["ParameterGroupName"].should.equal(
-        "default.redshift-1.0"
-    )
-    cluster["AutomatedSnapshotRetentionPeriod"].should.equal(1)
-    cluster["Port"].should.equal(5439)
-    cluster["ClusterVersion"].should.equal("1.0")
-    cluster["AllowVersionUpgrade"].should.equal(True)
-    cluster["NumberOfNodes"].should.equal(1)
-
-
 @mock_redshift
 @mock_ec2
 def test_create_cluster_in_subnet_group():
@@ -422,32 +302,6 @@ def test_create_cluster_in_subnet_group_boto3():
     cluster["ClusterSubnetGroupName"].should.equal("my_subnet_group")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_cluster_with_security_group():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    conn.create_cluster_security_group("security_group1", "This is my security group")
-    conn.create_cluster_security_group("security_group2", "This is my security group")
-
-    cluster_identifier = "my_cluster"
-    conn.create_cluster(
-        cluster_identifier,
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-        cluster_security_groups=["security_group1", "security_group2"],
-    )
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-    group_names = [
-        group["ClusterSecurityGroupName"] for group in cluster["ClusterSecurityGroups"]
-    ]
-    set(group_names).should.equal(set(["security_group1", "security_group2"]))
-
-
 @mock_redshift
 def test_create_cluster_with_security_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -476,34 +330,6 @@ def test_create_cluster_with_security_group_boto3():
     set(group_names).should.equal({"security_group1", "security_group2"})
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-@mock_ec2_deprecated
-def test_create_cluster_with_vpc_security_groups():
-    vpc_conn = boto.connect_vpc()
-    ec2_conn = boto.connect_ec2()
-    redshift_conn = boto.connect_redshift()
-    vpc = vpc_conn.create_vpc("10.0.0.0/16")
-    security_group = ec2_conn.create_security_group(
-        "vpc_security_group", "a group", vpc_id=vpc.id
-    )
-
-    redshift_conn.create_cluster(
-        "my_cluster",
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-        vpc_security_group_ids=[security_group.id],
-    )
-
-    cluster_response = redshift_conn.describe_clusters("my_cluster")
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-    group_ids = [group["VpcSecurityGroupId"] for group in cluster["VpcSecurityGroups"]]
-    list(group_ids).should.equal([security_group.id])
-
-
 @mock_redshift
 @mock_ec2
 def test_create_cluster_with_vpc_security_groups_boto3():
@@ -545,31 +371,6 @@ def test_create_cluster_with_iam_roles():
     iam_roles_arn.should.equal(iam_roles)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_cluster_with_parameter_group():
-    conn = boto.connect_redshift()
-    conn.create_cluster_parameter_group(
-        "my_parameter_group", "redshift-1.0", "This is my parameter group"
-    )
-
-    conn.create_cluster(
-        "my_cluster",
-        node_type="dw.hs1.xlarge",
-        master_username="username",
-        master_user_password="password",
-        cluster_parameter_group_name="my_parameter_group",
-    )
-
-    cluster_response = conn.describe_clusters("my_cluster")
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-    cluster["ClusterParameterGroups"][0]["ParameterGroupName"].should.equal(
-        "my_parameter_group"
-    )
-
-
 @mock_redshift
 def test_create_cluster_with_parameter_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -607,15 +408,6 @@ def test_create_cluster_with_parameter_group_boto3():
     cluster["ClusterParameterGroups"][0]["ParameterApplyStatus"].should.equal("in-sync")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_describe_non_existent_cluster():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    conn.describe_clusters.when.called_with("not-a-cluster").should.throw(
-        ClusterNotFound
-    )
-
-
 @mock_redshift
 def test_describe_non_existent_cluster_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -626,51 +418,6 @@ def test_describe_non_existent_cluster_boto3():
     err["Message"].should.equal("Cluster not-a-cluster not found.")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_delete_cluster():
-    conn = boto.connect_redshift()
-    cluster_identifier = "my_cluster"
-    snapshot_identifier = "my_snapshot"
-
-    conn.create_cluster(
-        cluster_identifier,
-        node_type="single-node",
-        master_username="username",
-        master_user_password="password",
-    )
-
-    conn.delete_cluster.when.called_with(cluster_identifier, False).should.throw(
-        boto.exception.JSONResponseError
-    )
-
-    clusters = conn.describe_clusters()["DescribeClustersResponse"][
-        "DescribeClustersResult"
-    ]["Clusters"]
-    list(clusters).should.have.length_of(1)
-
-    conn.delete_cluster(
-        cluster_identifier=cluster_identifier,
-        skip_final_cluster_snapshot=False,
-        final_cluster_snapshot_identifier=snapshot_identifier,
-    )
-
-    clusters = conn.describe_clusters()["DescribeClustersResponse"][
-        "DescribeClustersResult"
-    ]["Clusters"]
-    list(clusters).should.have.length_of(0)
-
-    snapshots = conn.describe_cluster_snapshots()["DescribeClusterSnapshotsResponse"][
-        "DescribeClusterSnapshotsResult"
-    ]["Snapshots"]
-    list(snapshots).should.have.length_of(1)
-
-    assert snapshot_identifier in snapshots[0]["SnapshotIdentifier"]
-
-    # Delete invalid id
-    conn.delete_cluster.when.called_with("not-a-cluster").should.throw(ClusterNotFound)
-
-
 @mock_redshift
 def test_modify_cluster_vpc_routing():
     iam_roles_arn = ["arn:aws:iam:::role/my-iam-role"]
@@ -781,61 +528,6 @@ def test_modify_cluster_boto3():
     cluster["NumberOfNodes"].should.equal(4)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_modify_cluster():
-    conn = boto.connect_redshift()
-    cluster_identifier = "my_cluster"
-    conn.create_cluster_security_group("security_group", "This is my security group")
-    conn.create_cluster_parameter_group(
-        "my_parameter_group", "redshift-1.0", "This is my parameter group"
-    )
-
-    conn.create_cluster(
-        cluster_identifier,
-        node_type="single-node",
-        master_username="username",
-        master_user_password="password",
-    )
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-    cluster["EnhancedVpcRouting"].should.equal(False)
-
-    conn.modify_cluster(
-        cluster_identifier,
-        cluster_type="multi-node",
-        number_of_nodes=4,
-        node_type="dw.hs1.xlarge",
-        cluster_security_groups="security_group",
-        master_user_password="new_password",
-        cluster_parameter_group_name="my_parameter_group",
-        automated_snapshot_retention_period=7,
-        preferred_maintenance_window="Tue:03:00-Tue:11:00",
-        allow_version_upgrade=False,
-        new_cluster_identifier=cluster_identifier,
-    )
-
-    cluster_response = conn.describe_clusters(cluster_identifier)
-    cluster = cluster_response["DescribeClustersResponse"]["DescribeClustersResult"][
-        "Clusters"
-    ][0]
-    cluster["ClusterIdentifier"].should.equal(cluster_identifier)
-    cluster["NodeType"].should.equal("dw.hs1.xlarge")
-    cluster["ClusterSecurityGroups"][0]["ClusterSecurityGroupName"].should.equal(
-        "security_group"
-    )
-    cluster["PreferredMaintenanceWindow"].should.equal("Tue:03:00-Tue:11:00")
-    cluster["ClusterParameterGroups"][0]["ParameterGroupName"].should.equal(
-        "my_parameter_group"
-    )
-    cluster["AutomatedSnapshotRetentionPeriod"].should.equal(7)
-    cluster["AllowVersionUpgrade"].should.equal(False)
-    cluster["NumberOfNodes"].should.equal(4)
-
-
 @mock_redshift
 @mock_ec2
 def test_create_cluster_subnet_group():
@@ -914,16 +606,6 @@ def test_authorize_security_group_ingress():
     )
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-@mock_ec2_deprecated
-def test_create_invalid_cluster_subnet_group():
-    redshift_conn = boto.connect_redshift()
-    redshift_conn.create_cluster_subnet_group.when.called_with(
-        "my_subnet", "This is my subnet group", subnet_ids=["subnet-1234"]
-    ).should.throw(InvalidSubnet)
-
-
 @mock_redshift
 @mock_ec2
 def test_create_invalid_cluster_subnet_group_boto3():
@@ -939,15 +621,6 @@ def test_create_invalid_cluster_subnet_group_boto3():
     err["Message"].should.match(r"Subnet \[[a-z0-9-']+\] not found.")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_describe_non_existent_subnet_group():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    conn.describe_cluster_subnet_groups.when.called_with(
-        "not-a-subnet-group"
-    ).should.throw(ClusterSubnetGroupNotFound)
-
-
 @mock_redshift
 @mock_ec2
 def test_describe_non_existent_subnet_group_boto3():
@@ -989,22 +662,6 @@ def test_delete_cluster_subnet_group():
     ).should.throw(ClientError)
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_cluster_security_group():
-    conn = boto.connect_redshift()
-    conn.create_cluster_security_group("my_security_group", "This is my security group")
-
-    groups_response = conn.describe_cluster_security_groups("my_security_group")
-    my_group = groups_response["DescribeClusterSecurityGroupsResponse"][
-        "DescribeClusterSecurityGroupsResult"
-    ]["ClusterSecurityGroups"][0]
-
-    my_group["ClusterSecurityGroupName"].should.equal("my_security_group")
-    my_group["Description"].should.equal("This is my security group")
-    list(my_group["IPRanges"]).should.equal([])
-
-
 @mock_redshift
 def test_create_cluster_security_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1031,15 +688,6 @@ def test_create_cluster_security_group_boto3():
     my_group["Tags"].should.equal([{"Key": "tag_key", "Value": "tag_value"}])
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_describe_non_existent_security_group():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    conn.describe_cluster_security_groups.when.called_with(
-        "not-a-security-group"
-    ).should.throw(ClusterSecurityGroupNotFound)
-
-
 @mock_redshift
 def test_describe_non_existent_security_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1051,32 +699,6 @@ def test_describe_non_existent_security_group_boto3():
     err["Message"].should.equal("Security group non-existent not found.")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_delete_cluster_security_group():
-    conn = boto.connect_redshift()
-    conn.create_cluster_security_group("my_security_group", "This is my security group")
-
-    groups_response = conn.describe_cluster_security_groups()
-    groups = groups_response["DescribeClusterSecurityGroupsResponse"][
-        "DescribeClusterSecurityGroupsResult"
-    ]["ClusterSecurityGroups"]
-    groups.should.have.length_of(2)  # The default group already exists
-
-    conn.delete_cluster_security_group("my_security_group")
-
-    groups_response = conn.describe_cluster_security_groups()
-    groups = groups_response["DescribeClusterSecurityGroupsResponse"][
-        "DescribeClusterSecurityGroupsResult"
-    ]["ClusterSecurityGroups"]
-    groups.should.have.length_of(1)
-
-    # Delete invalid id
-    conn.delete_cluster_security_group.when.called_with(
-        "not-a-security-group"
-    ).should.throw(ClusterSecurityGroupNotFound)
-
-
 @mock_redshift
 def test_delete_cluster_security_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1103,24 +725,6 @@ def test_delete_cluster_security_group_boto3():
     err["Message"].should.equal("Security group not-a-security-group not found.")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_create_cluster_parameter_group():
-    conn = boto.connect_redshift()
-    conn.create_cluster_parameter_group(
-        "my_parameter_group", "redshift-1.0", "This is my parameter group"
-    )
-
-    groups_response = conn.describe_cluster_parameter_groups("my_parameter_group")
-    my_group = groups_response["DescribeClusterParameterGroupsResponse"][
-        "DescribeClusterParameterGroupsResult"
-    ]["ParameterGroups"][0]
-
-    my_group["ParameterGroupName"].should.equal("my_parameter_group")
-    my_group["ParameterGroupFamily"].should.equal("redshift-1.0")
-    my_group["Description"].should.equal("This is my parameter group")
-
-
 @mock_redshift
 def test_create_cluster_parameter_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1144,15 +748,6 @@ def test_create_cluster_parameter_group_boto3():
     my_group["Description"].should.equal("This is my group")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_describe_non_existent_parameter_group():
-    conn = boto.redshift.connect_to_region("us-east-1")
-    conn.describe_cluster_parameter_groups.when.called_with(
-        "not-a-parameter-group"
-    ).should.throw(ClusterParameterGroupNotFound)
-
-
 @mock_redshift
 def test_describe_non_existent_parameter_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1165,34 +760,6 @@ def test_describe_non_existent_parameter_group_boto3():
     err["Message"].should.equal("Parameter group not-a-parameter-group not found.")
 
 
-# Has boto3 equivalent
-@mock_redshift_deprecated
-def test_delete_cluster_parameter_group():
-    conn = boto.connect_redshift()
-    conn.create_cluster_parameter_group(
-        "my_parameter_group", "redshift-1.0", "This is my parameter group"
-    )
-
-    groups_response = conn.describe_cluster_parameter_groups()
-    groups = groups_response["DescribeClusterParameterGroupsResponse"][
-        "DescribeClusterParameterGroupsResult"
-    ]["ParameterGroups"]
-    groups.should.have.length_of(2)  # The default group already exists
-
-    conn.delete_cluster_parameter_group("my_parameter_group")
-
-    groups_response = conn.describe_cluster_parameter_groups()
-    groups = groups_response["DescribeClusterParameterGroupsResponse"][
-        "DescribeClusterParameterGroupsResult"
-    ]["ParameterGroups"]
-    groups.should.have.length_of(1)
-
-    # Delete invalid id
-    conn.delete_cluster_parameter_group.when.called_with(
-        "not-a-parameter-group"
-    ).should.throw(ClusterParameterGroupNotFound)
-
-
 @mock_redshift
 def test_delete_parameter_group_boto3():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1231,6 +798,191 @@ def test_create_cluster_snapshot_of_non_existent_cluster():
     ).should.throw(ClientError, "Cluster {} not found.".format(cluster_identifier))
 
 
+@mock_redshift
+def test_automated_snapshot_on_cluster_creation():
+    client = boto3.client("redshift", region_name="us-east-1")
+    cluster_identifier = "my_cluster"
+
+    cluster_response = client.create_cluster(
+        DBName="test-db",
+        ClusterIdentifier=cluster_identifier,
+        ClusterType="single-node",
+        NodeType="ds2.xlarge",
+        MasterUsername="username",
+        MasterUserPassword="password",
+        EnhancedVpcRouting=True,
+        Tags=[{"Key": "tag_key", "Value": "tag_value"}],
+    )
+
+    cluster_response["Cluster"]["Tags"].should.equal(
+        [{"Key": "tag_key", "Value": "tag_value"}]
+    )
+    resp_auto_snap = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier
+    )
+    resp_auto_snap["Snapshots"][0]["SnapshotType"].should.equal("automated")
+    # Tags from cluster are not copied over to automated snapshot
+    resp_auto_snap["Snapshots"][0]["Tags"].should.equal([])
+
+
+@mock_redshift
+def test_delete_automated_snapshot():
+    client = boto3.client("redshift", region_name="us-east-1")
+    cluster_identifier = "my_cluster"
+
+    cluster_response = client.create_cluster(
+        DBName="test-db",
+        ClusterIdentifier=cluster_identifier,
+        ClusterType="single-node",
+        NodeType="ds2.xlarge",
+        MasterUsername="username",
+        MasterUserPassword="password",
+        EnhancedVpcRouting=True,
+    )
+    cluster_response["Cluster"]["NodeType"].should.equal("ds2.xlarge")
+    resp_auto_snap = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier
+    )
+    snapshot_identifier = resp_auto_snap["Snapshots"][0]["SnapshotIdentifier"]
+    # Delete automated snapshot should result in error
+    client.delete_cluster_snapshot.when.called_with(
+        SnapshotIdentifier=snapshot_identifier
+    ).should.throw(
+        ClientError,
+        "Cannot delete the snapshot {0} because only manual snapshots may be deleted".format(
+            snapshot_identifier
+        ),
+    )
+
+
+@mock_redshift
+def test_presence_automated_snapshot_on_cluster_delete():
+    client = boto3.client("redshift", region_name="us-east-1")
+    cluster_identifier = "my_cluster"
+
+    client.create_cluster(
+        ClusterIdentifier=cluster_identifier,
+        ClusterType="single-node",
+        NodeType="ds2.xlarge",
+        MasterUsername="username",
+        MasterUserPassword="password",
+    )
+    # Ensure automated snapshot is available
+    resp = client.describe_cluster_snapshots(ClusterIdentifier=cluster_identifier)
+    resp["Snapshots"].should.have.length_of(1)
+
+    # Delete the cluster
+    cluster_response = client.delete_cluster(
+        ClusterIdentifier=cluster_identifier, SkipFinalClusterSnapshot=True
+    )
+    cluster = cluster_response["Cluster"]
+    cluster["ClusterIdentifier"].should.equal(cluster_identifier)
+
+    # Ensure Automated snapshot is deleted
+    resp = client.describe_cluster_snapshots(ClusterIdentifier=cluster_identifier)
+    resp["Snapshots"].should.have.length_of(0)
+
+
+@mock_redshift
+def test_describe_snapshot_with_filter():
+    client = boto3.client("redshift", region_name="us-east-1")
+    cluster_identifier = "my_cluster"
+    snapshot_identifier = "my_snapshot"
+
+    cluster_response = client.create_cluster(
+        DBName="test-db",
+        ClusterIdentifier=cluster_identifier,
+        ClusterType="single-node",
+        NodeType="ds2.xlarge",
+        MasterUsername="username",
+        MasterUserPassword="password",
+        EnhancedVpcRouting=True,
+    )
+    cluster_response["Cluster"]["NodeType"].should.equal("ds2.xlarge")
+    resp_auto_snap = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier, SnapshotType="automated"
+    )
+    auto_snapshot_identifier = resp_auto_snap["Snapshots"][0]["SnapshotIdentifier"]
+    client.create_cluster_snapshot(
+        SnapshotIdentifier=snapshot_identifier, ClusterIdentifier=cluster_identifier
+    )
+
+    resp = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier, SnapshotType="automated"
+    )
+    resp["Snapshots"].should.have.length_of(1)
+
+    resp = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier, SnapshotType="manual"
+    )
+    resp["Snapshots"].should.have.length_of(1)
+
+    resp = client.describe_cluster_snapshots(
+        SnapshotIdentifier=snapshot_identifier, SnapshotType="manual"
+    )
+    resp["Snapshots"].should.have.length_of(1)
+
+    resp = client.describe_cluster_snapshots(
+        SnapshotIdentifier=auto_snapshot_identifier, SnapshotType="automated"
+    )
+    resp["Snapshots"].should.have.length_of(1)
+
+    client.describe_cluster_snapshots.when.called_with(
+        SnapshotIdentifier=snapshot_identifier, SnapshotType="automated"
+    ).should.throw(ClientError, "Snapshot {0} not found.".format(snapshot_identifier))
+
+    client.describe_cluster_snapshots.when.called_with(
+        SnapshotIdentifier=auto_snapshot_identifier, SnapshotType="manual"
+    ).should.throw(
+        ClientError, "Snapshot {0} not found.".format(auto_snapshot_identifier)
+    )
+
+
+@mock_redshift
+def test_create_cluster_from_automated_snapshot():
+    client = boto3.client("redshift", region_name="us-east-1")
+    original_cluster_identifier = "original-cluster"
+    new_cluster_identifier = "new-cluster"
+
+    client.create_cluster(
+        ClusterIdentifier=original_cluster_identifier,
+        ClusterType="single-node",
+        NodeType="ds2.xlarge",
+        MasterUsername="username",
+        MasterUserPassword="password",
+        EnhancedVpcRouting=True,
+    )
+
+    resp_auto_snap = client.describe_cluster_snapshots(
+        ClusterIdentifier=original_cluster_identifier, SnapshotType="automated"
+    )
+    auto_snapshot_identifier = resp_auto_snap["Snapshots"][0]["SnapshotIdentifier"]
+    client.restore_from_cluster_snapshot.when.called_with(
+        ClusterIdentifier=original_cluster_identifier,
+        SnapshotIdentifier=auto_snapshot_identifier,
+    ).should.throw(ClientError, "ClusterAlreadyExists")
+
+    response = client.restore_from_cluster_snapshot(
+        ClusterIdentifier=new_cluster_identifier,
+        SnapshotIdentifier=auto_snapshot_identifier,
+        Port=1234,
+    )
+    response["Cluster"]["ClusterStatus"].should.equal("creating")
+
+    response = client.describe_clusters(ClusterIdentifier=new_cluster_identifier)
+    new_cluster = response["Clusters"][0]
+    new_cluster["NodeType"].should.equal("ds2.xlarge")
+    new_cluster["MasterUsername"].should.equal("username")
+    new_cluster["Endpoint"]["Port"].should.equal(1234)
+    new_cluster["EnhancedVpcRouting"].should.equal(True)
+
+    # Make sure the new cluster has automated snapshot on cluster creation
+    resp_auto_snap = client.describe_cluster_snapshots(
+        ClusterIdentifier=new_cluster_identifier, SnapshotType="automated"
+    )
+    resp_auto_snap["Snapshots"].should.have.length_of(1)
+
+
 @mock_redshift
 def test_create_cluster_snapshot():
     client = boto3.client("redshift", region_name="us-east-1")
@@ -1304,7 +1056,9 @@ def test_describe_cluster_snapshots():
     snapshot_2["NodeType"].should.equal("ds2.xlarge")
     snapshot_2["MasterUsername"].should.equal("username")
 
-    resp_clust = client.describe_cluster_snapshots(ClusterIdentifier=cluster_identifier)
+    resp_clust = client.describe_cluster_snapshots(
+        ClusterIdentifier=cluster_identifier, SnapshotType="manual"
+    )
     resp_clust["Snapshots"][0].should.equal(resp_snap_1["Snapshots"][0])
     resp_clust["Snapshots"][1].should.equal(resp_snap_2["Snapshots"][0])
 
@@ -1341,14 +1095,14 @@ def test_delete_cluster_snapshot():
     )
 
     snapshots = client.describe_cluster_snapshots()["Snapshots"]
-    list(snapshots).should.have.length_of(1)
+    list(snapshots).should.have.length_of(2)
 
     client.delete_cluster_snapshot(SnapshotIdentifier=snapshot_identifier)["Snapshot"][
         "Status"
     ].should.equal("deleted")
 
     snapshots = client.describe_cluster_snapshots()["Snapshots"]
-    list(snapshots).should.have.length_of(0)
+    list(snapshots).should.have.length_of(1)
 
     # Delete invalid id
     client.delete_cluster_snapshot.when.called_with(
@@ -1791,7 +1545,7 @@ def test_enable_snapshot_copy():
     )
     with pytest.raises(ClientError) as ex:
         client.enable_snapshot_copy(
-            ClusterIdentifier="test", DestinationRegion="us-west-2", RetentionPeriod=3,
+            ClusterIdentifier="test", DestinationRegion="us-west-2", RetentionPeriod=3
         )
     ex.value.response["Error"]["Code"].should.equal("InvalidParameterValue")
     ex.value.response["Error"]["Message"].should.contain(
@@ -2015,20 +1769,18 @@ def test_resize_cluster():
     resp["Cluster"]["NumberOfNodes"].should.equal(1)
 
     client.modify_cluster(
-        ClusterIdentifier="test", ClusterType="multi-node", NumberOfNodes=2,
+        ClusterIdentifier="test", ClusterType="multi-node", NumberOfNodes=2
     )
     resp = client.describe_clusters(ClusterIdentifier="test")
     resp["Clusters"][0]["NumberOfNodes"].should.equal(2)
 
-    client.modify_cluster(
-        ClusterIdentifier="test", ClusterType="single-node",
-    )
+    client.modify_cluster(ClusterIdentifier="test", ClusterType="single-node")
     resp = client.describe_clusters(ClusterIdentifier="test")
     resp["Clusters"][0]["NumberOfNodes"].should.equal(1)
 
     with pytest.raises(ClientError) as ex:
         client.modify_cluster(
-            ClusterIdentifier="test", ClusterType="multi-node", NumberOfNodes=1,
+            ClusterIdentifier="test", ClusterType="multi-node", NumberOfNodes=1
         )
     ex.value.response["Error"]["Code"].should.equal("InvalidParameterCombination")
     ex.value.response["Error"]["Message"].should.contain(
@@ -2110,7 +1862,7 @@ def test_get_cluster_credentials():
     )
     db_user = "some_user"
     response = client.get_cluster_credentials(
-        ClusterIdentifier=cluster_identifier, DbUser=db_user,
+        ClusterIdentifier=cluster_identifier, DbUser=db_user
     )
     response["DbUser"].should.equal("IAM:%s" % db_user)
     assert time.mktime((response["Expiration"]).timetuple()) == pytest.approx(
@@ -2132,7 +1884,7 @@ def test_get_cluster_credentials():
         (datetime.datetime.now() + datetime.timedelta(0, 3000)).timetuple()
     )
     response = client.get_cluster_credentials(
-        ClusterIdentifier=cluster_identifier, DbUser=db_user, DurationSeconds=3000,
+        ClusterIdentifier=cluster_identifier, DbUser=db_user, DurationSeconds=3000
     )
     assert time.mktime(response["Expiration"].timetuple()) == pytest.approx(
         expected_expiration
