@@ -1,7 +1,4 @@
-import boto
 import boto3
-from boto.route53.healthcheck import HealthCheck
-from boto.route53.record import ResourceRecordSets
 from botocore.exceptions import ClientError
 
 import sure  # noqa # pylint: disable=unused-import
@@ -9,36 +6,11 @@ import sure  # noqa # pylint: disable=unused-import
 import botocore
 import pytest
 
-from moto import mock_route53, mock_route53_deprecated
-
-
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_hosted_zone():
-    conn = boto.connect_route53("the_key", "the_secret")
-    firstzone = conn.create_hosted_zone("testdns.aws.com")
-    zones = conn.get_all_hosted_zones()
-    len(zones["ListHostedZonesResponse"]["HostedZones"]).should.equal(1)
-
-    conn.create_hosted_zone("testdns1.aws.com")
-    zones = conn.get_all_hosted_zones()
-    len(zones["ListHostedZonesResponse"]["HostedZones"]).should.equal(2)
-
-    id1 = firstzone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-    zone = conn.get_hosted_zone(id1)
-    zone["GetHostedZoneResponse"]["HostedZone"]["Name"].should.equal("testdns.aws.com.")
-
-    conn.delete_hosted_zone(id1)
-    zones = conn.get_all_hosted_zones()
-    len(zones["ListHostedZonesResponse"]["HostedZones"]).should.equal(1)
-
-    conn.get_hosted_zone.when.called_with("abcd").should.throw(
-        boto.route53.exception.DNSServerError, "404 Not Found"
-    )
+from moto import mock_ec2, mock_route53
 
 
 @mock_route53
-def test_create_hosted_zone_boto3():
+def test_create_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
     response = conn.create_hosted_zone(
         Name="testdns.aws.com.", CallerReference=str(hash("foo"))
@@ -50,7 +22,11 @@ def test_create_hosted_zone_boto3():
     firstzone.should.have.key("ResourceRecordSetCount").equal(0)
 
     delegation = response["DelegationSet"]
-    delegation.should.equal({"NameServers": ["moto.test.com"]})
+    delegation.should.have.key("NameServers").length_of(4)
+    delegation["NameServers"].should.contain("ns-2048.awsdns-64.com")
+    delegation["NameServers"].should.contain("ns-2049.awsdns-65.net")
+    delegation["NameServers"].should.contain("ns-2050.awsdns-66.org")
+    delegation["NameServers"].should.contain("ns-2051.awsdns-67.co.uk")
 
 
 @mock_route53
@@ -89,6 +65,57 @@ def test_delete_hosted_zone():
     res.should.have.length_of(1)
 
 
+@mock_route53
+def test_get_hosted_zone_count_no_zones():
+    conn = boto3.client("route53", region_name="us-east-1")
+    zone_count = conn.get_hosted_zone_count()
+    zone_count.should.have.key("HostedZoneCount")
+    isinstance(zone_count["HostedZoneCount"], int).should.be.true
+    zone_count["HostedZoneCount"].should.be.equal(0)
+
+
+@mock_route53
+def test_get_hosted_zone_count_one_zone():
+    conn = boto3.client("route53", region_name="us-east-1")
+    zone = "a"
+    zone_name = f"test.{zone}.com."
+    conn.create_hosted_zone(
+        Name=zone_name,
+        CallerReference=str(hash("foo")),
+        HostedZoneConfig=dict(PrivateZone=False, Comment=f"test {zone} com"),
+    )
+    zone_count = conn.get_hosted_zone_count()
+    zone_count.should.have.key("HostedZoneCount")
+    isinstance(zone_count["HostedZoneCount"], int).should.be.true
+    zone_count["HostedZoneCount"].should.be.equal(1)
+
+
+@mock_route53
+def test_get_hosted_zone_count_many_zones():
+    conn = boto3.client("route53", region_name="us-east-1")
+    zones = {}
+    zone_indexes = []
+    for char in range(ord("a"), ord("d") + 1):
+        for char2 in range(ord("a"), ord("z") + 1):
+            zone_indexes.append(f"{chr(char)}{chr(char2)}")
+
+    # Create 100-ish zones and make sure we get 100 back.  This works
+    # for 702 zones {a..zz}, but seemed a needless waste of
+    # time/resources.
+    for zone in zone_indexes:
+        zone_name = f"test.{zone}.com."
+        zones[zone] = conn.create_hosted_zone(
+            Name=zone_name,
+            CallerReference=str(hash("foo")),
+            HostedZoneConfig=dict(PrivateZone=False, Comment=f"test {zone} com"),
+        )
+    zone_count = conn.get_hosted_zone_count()
+    zone_count.should.have.key("HostedZoneCount")
+    isinstance(zone_count["HostedZoneCount"], int).should.be.true
+    zone_count["HostedZoneCount"].shouldnt.be.equal(0)
+    zone_count["HostedZoneCount"].should.be.equal(len(zone_indexes))
+
+
 @mock_route53
 def test_get_unknown_hosted_zone():
     conn = boto3.client("route53", region_name="us-east-1")
@@ -101,120 +128,6 @@ def test_get_unknown_hosted_zone():
     err["Message"].should.equal("No hosted zone found with ID: unknown")
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_rrset():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    conn.get_all_rrsets.when.called_with("abcd").should.throw(
-        boto.route53.exception.DNSServerError, "404 Not Found"
-    )
-
-    zone = conn.create_hosted_zone("testdns.aws.com")
-    zoneid = zone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    conn.get_all_rrsets.when.called_with(zoneid, type="A").should.throw(
-        boto.route53.exception.DNSServerError, "400 Bad Request"
-    )
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("CREATE", "foo.bar.testdns.aws.com", "A")
-    change.add_value("1.2.3.4")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(1)
-    rrsets[0].resource_records[0].should.equal("1.2.3.4")
-
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.bar.testdns.aws.com.", type="CNAME")
-    rrsets.should.have.length_of(0)
-
-    changes = ResourceRecordSets(conn, zoneid)
-    changes.add_change("DELETE", "foo.bar.testdns.aws.com", "A")
-    change = changes.add_change("CREATE", "foo.bar.testdns.aws.com", "A")
-    change.add_value("5.6.7.8")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(1)
-    rrsets[0].resource_records[0].should.equal("5.6.7.8")
-
-    changes = ResourceRecordSets(conn, zoneid)
-    changes.add_change("DELETE", "foo.bar.testdns.aws.com", "A")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(0)
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("UPSERT", "foo.bar.testdns.aws.com", "A")
-    change.add_value("1.2.3.4")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(1)
-    rrsets[0].resource_records[0].should.equal("1.2.3.4")
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("UPSERT", "foo.bar.testdns.aws.com", "A")
-    change.add_value("5.6.7.8")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(1)
-    rrsets[0].resource_records[0].should.equal("5.6.7.8")
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("UPSERT", "foo.bar.testdns.aws.com", "TXT")
-    change.add_value("foo")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(2)
-    rrsets[0].resource_records[0].should.equal("5.6.7.8")
-    rrsets[1].resource_records[0].should.equal("foo")
-
-    changes = ResourceRecordSets(conn, zoneid)
-    changes.add_change("DELETE", "foo.bar.testdns.aws.com", "A")
-    changes.add_change("DELETE", "foo.bar.testdns.aws.com", "TXT")
-    changes.commit()
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("CREATE", "bar.foo.testdns.aws.com", "TXT")
-    change.add_value("bar")
-    change = changes.add_change("CREATE", "foo.bar.testdns.aws.com", "A")
-    change.add_value("1.2.3.4")
-    change = changes.add_change("CREATE", "bar.foo.testdns.aws.com", "A")
-    change.add_value("5.6.7.8")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(3)
-    rrsets[0].resource_records[0].should.equal("1.2.3.4")
-    rrsets[1].resource_records[0].should.equal("5.6.7.8")
-    rrsets[2].resource_records[0].should.equal("bar")
-
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.bar.testdns.aws.com", type="A")
-    rrsets.should.have.length_of(3)
-    resource_records = [rr for rr_set in rrsets for rr in rr_set.resource_records]
-    resource_records.should.contain("1.2.3.4")
-    resource_records.should.contain("5.6.7.8")
-    resource_records.should.contain("bar")
-
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.testdns.aws.com", type="A")
-    rrsets.should.have.length_of(2)
-    rrsets[0].resource_records[0].should.equal("5.6.7.8")
-    rrsets[1].resource_records[0].should.equal("bar")
-
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.bar.testdns.aws.com", type="TXT")
-    rrsets.should.have.length_of(2)
-    rrsets[0].resource_records[0].should.equal("5.6.7.8")
-    rrsets[1].resource_records[0].should.equal("bar")
-
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.foo.testdns.aws.com", type="A")
-    rrsets.should.have.length_of(0)
-
-
 @mock_route53
 def test_list_resource_record_set_unknown_zone():
     conn = boto3.client("route53", region_name="us-east-1")
@@ -242,94 +155,8 @@ def test_list_resource_record_set_unknown_type():
     err["Message"].should.equal("Bad Request")
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_rrset_with_multiple_values():
-    conn = boto.connect_route53("the_key", "the_secret")
-    zone = conn.create_hosted_zone("testdns.aws.com")
-    zoneid = zone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    changes = ResourceRecordSets(conn, zoneid)
-    change = changes.add_change("CREATE", "foo.bar.testdns.aws.com", "A")
-    change.add_value("1.2.3.4")
-    change.add_value("5.6.7.8")
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid)
-    rrsets.should.have.length_of(1)
-    set(rrsets[0].resource_records).should.equal(set(["1.2.3.4", "5.6.7.8"]))
-
-
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_alias_rrset():
-    conn = boto.connect_route53("the_key", "the_secret")
-    zone = conn.create_hosted_zone("testdns.aws.com")
-    zoneid = zone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    changes = ResourceRecordSets(conn, zoneid)
-    changes.add_change(
-        "CREATE",
-        "foo.alias.testdns.aws.com",
-        "A",
-        alias_hosted_zone_id="Z3DG6IL3SJCGPX",
-        alias_dns_name="foo.testdns.aws.com",
-    )
-    changes.add_change(
-        "CREATE",
-        "bar.alias.testdns.aws.com",
-        "CNAME",
-        alias_hosted_zone_id="Z3DG6IL3SJCGPX",
-        alias_dns_name="bar.testdns.aws.com",
-    )
-    changes.commit()
-
-    rrsets = conn.get_all_rrsets(zoneid, name="alias.testdns.aws.com")
-    alias_targets = [rr_set.alias_dns_name for rr_set in rrsets]
-    alias_targets.should.have.length_of(2)
-    alias_targets.should.contain("foo.testdns.aws.com")
-    alias_targets.should.contain("bar.testdns.aws.com")
-    rrsets[0].alias_dns_name.should.equal("bar.testdns.aws.com")
-    rrsets[0].resource_records.should.have.length_of(0)
-    rrsets = conn.get_all_rrsets(zoneid, name="foo.alias.testdns.aws.com", type="A")
-    rrsets.should.have.length_of(1)
-    rrsets[0].alias_dns_name.should.equal("foo.testdns.aws.com")
-    rrsets[0].resource_records.should.have.length_of(0)
-
-
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_create_health_check():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    check = HealthCheck(
-        ip_addr="10.0.0.25",
-        port=80,
-        hc_type="HTTP",
-        resource_path="/",
-        fqdn="example.com",
-        string_match="a good response",
-        request_interval=10,
-        failure_threshold=2,
-    )
-    conn.create_health_check(check)
-
-    checks = conn.get_list_health_checks()["ListHealthChecksResponse"]["HealthChecks"]
-    list(checks).should.have.length_of(1)
-    check = checks[0]
-    config = check["HealthCheckConfig"]
-    config["IPAddress"].should.equal("10.0.0.25")
-    config["Port"].should.equal("80")
-    config["Type"].should.equal("HTTP")
-    config["ResourcePath"].should.equal("/")
-    config["FullyQualifiedDomainName"].should.equal("example.com")
-    config["SearchString"].should.equal("a good response")
-    config["RequestInterval"].should.equal("10")
-    config["FailureThreshold"].should.equal("2")
-
-
 @mock_route53
-def test_create_health_check_boto3():
+def test_create_health_check():
     conn = boto3.client("route53", region_name="us-east-1")
 
     check = conn.create_health_check(
@@ -362,7 +189,7 @@ def test_create_health_check_boto3():
 
 
 @mock_route53
-def test_list_health_checks_boto3():
+def test_list_health_checks():
     conn = boto3.client("route53", region_name="us-east-1")
 
     conn.list_health_checks()["HealthChecks"].should.have.length_of(0)
@@ -386,25 +213,8 @@ def test_list_health_checks_boto3():
     checks.should.contain(check)
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_delete_health_check():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    check = HealthCheck(ip_addr="10.0.0.25", port=80, hc_type="HTTP", resource_path="/")
-    conn.create_health_check(check)
-
-    checks = conn.get_list_health_checks()["ListHealthChecksResponse"]["HealthChecks"]
-    list(checks).should.have.length_of(1)
-    health_check_id = checks[0]["Id"]
-
-    conn.delete_health_check(health_check_id)
-    checks = conn.get_list_health_checks()["ListHealthChecksResponse"]["HealthChecks"]
-    list(checks).should.have.length_of(0)
-
-
 @mock_route53
-def test_delete_health_checks_boto3():
+def test_delete_health_checks():
     conn = boto3.client("route53", region_name="us-east-1")
 
     conn.list_health_checks()["HealthChecks"].should.have.length_of(0)
@@ -429,31 +239,8 @@ def test_delete_health_checks_boto3():
     checks.should.have.length_of(0)
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_use_health_check_in_resource_record_set():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    check = HealthCheck(ip_addr="10.0.0.25", port=80, hc_type="HTTP", resource_path="/")
-    check = conn.create_health_check(check)["CreateHealthCheckResponse"]["HealthCheck"]
-    check_id = check["Id"]
-
-    zone = conn.create_hosted_zone("testdns.aws.com")
-    zone_id = zone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    changes = ResourceRecordSets(conn, zone_id)
-    change = changes.add_change(
-        "CREATE", "foo.bar.testdns.aws.com", "A", health_check=check_id
-    )
-    change.add_value("1.2.3.4")
-    changes.commit()
-
-    record_sets = conn.get_all_rrsets(zone_id)
-    record_sets[0].health_check.should.equal(check_id)
-
-
 @mock_route53
-def test_use_health_check_in_resource_record_set_boto3():
+def test_use_health_check_in_resource_record_set():
     conn = boto3.client("route53", region_name="us-east-1")
 
     check = conn.create_health_check(
@@ -498,30 +285,8 @@ def test_use_health_check_in_resource_record_set_boto3():
     record_sets[0]["HealthCheckId"].should.equal(check_id)
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_hosted_zone_comment_preserved():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    firstzone = conn.create_hosted_zone("testdns.aws.com.", comment="test comment")
-    zone_id = firstzone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    hosted_zone = conn.get_hosted_zone(zone_id)
-    hosted_zone["GetHostedZoneResponse"]["HostedZone"]["Config"][
-        "Comment"
-    ].should.equal("test comment")
-
-    hosted_zones = conn.get_all_hosted_zones()
-    hosted_zones["ListHostedZonesResponse"]["HostedZones"][0]["Config"][
-        "Comment"
-    ].should.equal("test comment")
-
-    zone = conn.get_zone("testdns.aws.com.")
-    zone.config["Comment"].should.equal("test comment")
-
-
 @mock_route53
-def test_hosted_zone_comment_preserved_boto3():
+def test_hosted_zone_comment_preserved():
     conn = boto3.client("route53", region_name="us-east-1")
 
     firstzone = conn.create_hosted_zone(
@@ -538,34 +303,8 @@ def test_hosted_zone_comment_preserved_boto3():
     hosted_zones["HostedZones"][0]["Config"]["Comment"].should.equal("test comment")
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_deleting_weighted_route():
-    conn = boto.connect_route53()
-
-    conn.create_hosted_zone("testdns.aws.com.")
-    zone = conn.get_zone("testdns.aws.com.")
-
-    zone.add_cname(
-        "cname.testdns.aws.com", "example.com", identifier=("success-test-foo", "50")
-    )
-    zone.add_cname(
-        "cname.testdns.aws.com", "example.com", identifier=("success-test-bar", "50")
-    )
-
-    cnames = zone.get_cname("cname.testdns.aws.com.", all=True)
-    cnames.should.have.length_of(2)
-    foo_cname = [cname for cname in cnames if cname.identifier == "success-test-foo"][0]
-
-    zone.delete_record(foo_cname)
-    cname = zone.get_cname("cname.testdns.aws.com.", all=True)
-    # When get_cname only had one result, it returns just that result instead
-    # of a list.
-    cname.identifier.should.equal("success-test-bar")
-
-
 @mock_route53
-def test_deleting_weighted_route_boto3():
+def test_deleting_weighted_route():
     conn = boto3.client("route53", region_name="us-east-1")
 
     zone = conn.create_hosted_zone(
@@ -620,40 +359,8 @@ def test_deleting_weighted_route_boto3():
     cnames[0]["SetIdentifier"].should.equal("success-test-bar")
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_deleting_latency_route():
-    conn = boto.connect_route53()
-
-    conn.create_hosted_zone("testdns.aws.com.")
-    zone = conn.get_zone("testdns.aws.com.")
-
-    zone.add_cname(
-        "cname.testdns.aws.com",
-        "example.com",
-        identifier=("success-test-foo", "us-west-2"),
-    )
-    zone.add_cname(
-        "cname.testdns.aws.com",
-        "example.com",
-        identifier=("success-test-bar", "us-west-1"),
-    )
-
-    cnames = zone.get_cname("cname.testdns.aws.com.", all=True)
-    cnames.should.have.length_of(2)
-    foo_cname = [cname for cname in cnames if cname.identifier == "success-test-foo"][0]
-    foo_cname.region.should.equal("us-west-2")
-
-    zone.delete_record(foo_cname)
-    cname = zone.get_cname("cname.testdns.aws.com.", all=True)
-    # When get_cname only had one result, it returns just that result instead
-    # of a list.
-    cname.identifier.should.equal("success-test-bar")
-    cname.region.should.equal("us-west-1")
-
-
 @mock_route53
-def test_deleting_latency_route_boto3():
+def test_deleting_latency_route():
     conn = boto3.client("route53", region_name="us-east-1")
 
     zone = conn.create_hosted_zone(
@@ -715,54 +422,73 @@ def test_deleting_latency_route_boto3():
     cnames[0]["Region"].should.equal("us-west-1")
 
 
-# Has boto3 equivalent
-@mock_route53_deprecated
-def test_hosted_zone_private_zone_preserved():
-    conn = boto.connect_route53("the_key", "the_secret")
-
-    firstzone = conn.create_hosted_zone(
-        "testdns.aws.com.", private_zone=True, vpc_id="vpc-fake", vpc_region="us-east-1"
-    )
-    zone_id = firstzone["CreateHostedZoneResponse"]["HostedZone"]["Id"].split("/")[-1]
-
-    hosted_zone = conn.get_hosted_zone(zone_id)
-    # in (original) boto, these bools returned as strings.
-    hosted_zone["GetHostedZoneResponse"]["HostedZone"]["Config"][
-        "PrivateZone"
-    ].should.equal("True")
-
-    hosted_zones = conn.get_all_hosted_zones()
-    hosted_zones["ListHostedZonesResponse"]["HostedZones"][0]["Config"][
-        "PrivateZone"
-    ].should.equal("True")
-
-    zone = conn.get_zone("testdns.aws.com.")
-    zone.config["PrivateZone"].should.equal("True")
-
-
+@mock_ec2
 @mock_route53
-def test_hosted_zone_private_zone_preserved_boto3():
-    conn = boto3.client("route53", region_name="us-east-1")
-    # TODO: actually create_hosted_zone statements with PrivateZone=True, but without
-    # a _valid_ vpc-id should fail.
-    firstzone = conn.create_hosted_zone(
+def test_hosted_zone_private_zone_preserved():
+    # Create mock VPC so we can get a VPC ID
+    region = "us-east-1"
+    ec2c = boto3.client("ec2", region_name=region)
+    vpc_id = ec2c.create_vpc(CidrBlock="10.1.0.0/16").get("Vpc").get("VpcId")
+
+    # Create hosted_zone as a Private VPC Hosted Zone
+    conn = boto3.client("route53", region_name=region)
+    new_zone = conn.create_hosted_zone(
         Name="testdns.aws.com.",
         CallerReference=str(hash("foo")),
         HostedZoneConfig=dict(PrivateZone=True, Comment="Test"),
+        VPC={"VPCRegion": region, "VPCId": vpc_id},
     )
 
-    zone_id = firstzone["HostedZone"]["Id"].split("/")[-1]
-
+    zone_id = new_zone["HostedZone"]["Id"].split("/")[-1]
     hosted_zone = conn.get_hosted_zone(Id=zone_id)
     hosted_zone["HostedZone"]["Config"]["PrivateZone"].should.equal(True)
+    hosted_zone.should.have.key("VPCs")
+    hosted_zone["VPCs"].should.have.length_of(1)
+    hosted_zone["VPCs"][0].should.have.key("VPCId")
+    hosted_zone["VPCs"][0].should.have.key("VPCRegion")
+    hosted_zone["VPCs"][0]["VPCId"].should_not.equal(None)
+    hosted_zone["VPCs"][0]["VPCRegion"].should_not.equal(None)
+    hosted_zone["VPCs"][0]["VPCId"].should.be.equal(vpc_id)
+    hosted_zone["VPCs"][0]["VPCRegion"].should.be.equal(region)
 
     hosted_zones = conn.list_hosted_zones()
     hosted_zones["HostedZones"][0]["Config"]["PrivateZone"].should.equal(True)
 
     hosted_zones = conn.list_hosted_zones_by_name(DNSName="testdns.aws.com.")
-    len(hosted_zones["HostedZones"]).should.equal(1)
+    hosted_zones["HostedZones"].should.have.length_of(1)
     hosted_zones["HostedZones"][0]["Config"]["PrivateZone"].should.equal(True)
 
+    # create_hosted_zone statements with  PrivateZone=True,
+    # but without a _valid_ vpc-id should NOT fail.
+    zone2_name = "testdns2.aws.com."
+    no_vpc_zone = conn.create_hosted_zone(
+        Name=zone2_name,
+        CallerReference=str(hash("foo")),
+        HostedZoneConfig=dict(PrivateZone=True, Comment="Test without VPC"),
+    )
+
+    zone_id = no_vpc_zone["HostedZone"]["Id"].split("/")[-1]
+    hosted_zone = conn.get_hosted_zone(Id=zone_id)
+    hosted_zone["HostedZone"]["Config"]["PrivateZone"].should.equal(True)
+    hosted_zone.should.have.key("VPCs")
+    hosted_zone["VPCs"].should.have.length_of(1)
+    hosted_zone["VPCs"][0].should.have.key("VPCId")
+    hosted_zone["VPCs"][0].should.have.key("VPCRegion")
+    hosted_zone["VPCs"][0]["VPCId"].should.equal("")
+    hosted_zone["VPCs"][0]["VPCRegion"].should.equal("")
+
+    hosted_zones = conn.list_hosted_zones()
+    hosted_zones["HostedZones"].should.have.length_of(2)
+    hosted_zones["HostedZones"][0]["Config"]["PrivateZone"].should.equal(True)
+    hosted_zones["HostedZones"][1]["Config"]["PrivateZone"].should.equal(True)
+
+    hosted_zones = conn.list_hosted_zones_by_name(DNSName=zone2_name)
+    hosted_zones["HostedZones"].should.have.length_of(1)
+    hosted_zones["HostedZones"][0]["Config"]["PrivateZone"].should.equal(True)
+    hosted_zones["HostedZones"][0]["Name"].should.equal(zone2_name)
+
+    return
+
 
 @mock_route53
 def test_list_or_change_tags_for_resource_request():
@@ -785,7 +511,7 @@ def test_list_or_change_tags_for_resource_request():
     response = conn.list_tags_for_resource(
         ResourceType="healthcheck", ResourceId=healthcheck_id
     )
-    response["ResourceTagSet"]["Tags"].should.be.empty
+    response["ResourceTagSet"]["Tags"].should.equal([])
 
     tag1 = {"Key": "Deploy", "Value": "True"}
     tag2 = {"Key": "Name", "Value": "UnitTest"}
@@ -849,36 +575,80 @@ def test_list_or_change_tags_for_resource_request():
     response = conn.list_tags_for_resource(
         ResourceType="healthcheck", ResourceId=healthcheck_id
     )
-    response["ResourceTagSet"]["Tags"].should.be.empty
+    response["ResourceTagSet"]["Tags"].should.equal([])
 
 
+@mock_ec2
 @mock_route53
 def test_list_hosted_zones_by_name():
-    conn = boto3.client("route53", region_name="us-east-1")
-    conn.create_hosted_zone(
+
+    # Create mock VPC so we can get a VPC ID
+    ec2c = boto3.client("ec2", region_name="us-east-1")
+    vpc_id = ec2c.create_vpc(CidrBlock="10.1.0.0/16").get("Vpc").get("VpcId")
+    region = "us-east-1"
+
+    conn = boto3.client("route53", region_name=region)
+    zone_b = conn.create_hosted_zone(
         Name="test.b.com.",
         CallerReference=str(hash("foo")),
         HostedZoneConfig=dict(PrivateZone=True, Comment="test com"),
-    )
-    conn.create_hosted_zone(
-        Name="test.a.org.",
-        CallerReference=str(hash("bar")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="test org"),
-    )
-    conn.create_hosted_zone(
-        Name="test.a.org.",
-        CallerReference=str(hash("bar")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="test org 2"),
+        VPC={"VPCRegion": region, "VPCId": vpc_id},
     )
 
-    # test lookup
-    zones = conn.list_hosted_zones_by_name(DNSName="test.b.com.")
-    len(zones["HostedZones"]).should.equal(1)
-    zones["HostedZones"][0]["Name"].should.equal("test.b.com.")
+    zone_b = conn.list_hosted_zones_by_name(DNSName="test.b.com.")
+    len(zone_b["HostedZones"]).should.equal(1)
+    zone_b["HostedZones"][0]["Name"].should.equal("test.b.com.")
+    zone_b["HostedZones"][0].should.have.key("Config")
+    zone_b["HostedZones"][0]["Config"].should.have.key("PrivateZone")
+    zone_b["HostedZones"][0]["Config"]["PrivateZone"].should.be.equal(True)
+
+    # We declared this a a private hosted zone above, so let's make
+    # sure it really is!
+    zone_b_id = zone_b["HostedZones"][0]["Id"].split("/")[-1]
+    b_hosted_zone = conn.get_hosted_zone(Id=zone_b_id)
+
+    # Pull the HostedZone block out and test it.
+    b_hosted_zone.should.have.key("HostedZone")
+    b_hz = b_hosted_zone["HostedZone"]
+    b_hz.should.have.key("Config")
+    b_hz["Config"].should.have.key("PrivateZone")
+    b_hz["Config"]["PrivateZone"].should.be.equal(True)
+
+    # Check for the VPCs block since this *should* be a VPC-Private Zone
+    b_hosted_zone.should.have.key("VPCs")
+    b_hosted_zone["VPCs"].should.have.length_of(1)
+    b_hz_vpcs = b_hosted_zone["VPCs"][0]
+    b_hz_vpcs.should.have.key("VPCId")
+    b_hz_vpcs.should.have.key("VPCRegion")
+    b_hz_vpcs["VPCId"].should_not.equal("")
+    b_hz_vpcs["VPCRegion"].should_not.equal("")
+    b_hz_vpcs["VPCId"].should.be.equal(vpc_id)
+    b_hz_vpcs["VPCRegion"].should.be.equal(region)
+
+    # Now create other zones and test them.
+    conn.create_hosted_zone(
+        Name="test.a.org.",
+        CallerReference=str(hash("bar")),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="test org"),
+    )
+    conn.create_hosted_zone(
+        Name="test.a.org.",
+        CallerReference=str(hash("bar")),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="test org 2"),
+    )
+
+    # Now makes sure the other zones we created above are NOT private...
     zones = conn.list_hosted_zones_by_name(DNSName="test.a.org.")
     len(zones["HostedZones"]).should.equal(2)
     zones["HostedZones"][0]["Name"].should.equal("test.a.org.")
+    zones["HostedZones"][0].should.have.key("Config")
+    zones["HostedZones"][0]["Config"].should.have.key("PrivateZone")
+    zones["HostedZones"][0]["Config"]["PrivateZone"].should.be.equal(False)
+
     zones["HostedZones"][1]["Name"].should.equal("test.a.org.")
+    zones["HostedZones"][1].should.have.key("Config")
+    zones["HostedZones"][1]["Config"].should.have.key("PrivateZone")
+    zones["HostedZones"][1]["Config"]["PrivateZone"].should.be.equal(False)
 
     # test sort order
     zones = conn.list_hosted_zones_by_name()
@@ -894,17 +664,17 @@ def test_list_hosted_zones_by_dns_name():
     conn.create_hosted_zone(
         Name="test.b.com.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="test com"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="test com"),
     )
     conn.create_hosted_zone(
         Name="test.a.org.",
         CallerReference=str(hash("bar")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="test org"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="test org"),
     )
     conn.create_hosted_zone(
         Name="test.a.org.",
         CallerReference=str(hash("bar")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="test org 2"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="test org 2"),
     )
     conn.create_hosted_zone(
         Name="my.test.net.",
@@ -936,13 +706,74 @@ def test_list_hosted_zones_by_dns_name():
     zones["HostedZones"][3]["Name"].should.equal("test.a.org.")
 
 
+@mock_ec2
+@mock_route53
+def test_list_hosted_zones_by_vpc():
+    # Create mock VPC so we can get a VPC ID
+    ec2c = boto3.client("ec2", region_name="us-east-1")
+    vpc_id = ec2c.create_vpc(CidrBlock="10.1.0.0/16").get("Vpc").get("VpcId")
+    region = "us-east-1"
+
+    conn = boto3.client("route53", region_name=region)
+    zone_b = conn.create_hosted_zone(
+        Name="test.b.com.",
+        CallerReference=str(hash("foo")),
+        HostedZoneConfig=dict(PrivateZone=True, Comment="test com"),
+        VPC={"VPCRegion": region, "VPCId": vpc_id},
+    )
+    response = conn.list_hosted_zones_by_vpc(VPCId=vpc_id, VPCRegion=region)
+    response.should.have.key("ResponseMetadata")
+    response.should.have.key("HostedZoneSummaries")
+    response["HostedZoneSummaries"].should.have.length_of(1)
+    response["HostedZoneSummaries"][0].should.have.key("HostedZoneId")
+    retured_zone = response["HostedZoneSummaries"][0]
+    retured_zone["HostedZoneId"].should.equal(zone_b["HostedZone"]["Id"])
+    retured_zone["Name"].should.equal(zone_b["HostedZone"]["Name"])
+
+
+@mock_ec2
+@mock_route53
+def test_list_hosted_zones_by_vpc_with_multiple_vpcs():
+    # Create mock VPC so we can get a VPC ID
+    ec2c = boto3.client("ec2", region_name="us-east-1")
+    vpc_id = ec2c.create_vpc(CidrBlock="10.1.0.0/16").get("Vpc").get("VpcId")
+    region = "us-east-1"
+
+    # Create 3 Zones associate with the VPC.
+    zones = {}
+    conn = boto3.client("route53", region_name=region)
+    for zone in ["a", "b", "c"]:
+        zone_name = f"test.{zone}.com."
+        zones[zone] = conn.create_hosted_zone(
+            Name=zone_name,
+            CallerReference=str(hash("foo")),
+            HostedZoneConfig=dict(PrivateZone=True, Comment=f"test {zone} com"),
+            VPC={"VPCRegion": region, "VPCId": vpc_id},
+        )
+
+    # List the zones associated with this vpc
+    response = conn.list_hosted_zones_by_vpc(VPCId=vpc_id, VPCRegion=region)
+    response.should.have.key("ResponseMetadata")
+    response.should.have.key("HostedZoneSummaries")
+    response["HostedZoneSummaries"].should.have.length_of(3)
+
+    # Loop through all zone summaries and verify they match what was created
+    for summary in response["HostedZoneSummaries"]:
+        # use the zone name as the index
+        index = summary["Name"].split(".")[1]
+        summary.should.have.key("HostedZoneId")
+        summary["HostedZoneId"].should.equal(zones[index]["HostedZone"]["Id"])
+        summary.should.have.key("Name")
+        summary["Name"].should.equal(zones[index]["HostedZone"]["Name"])
+
+
 @mock_route53
 def test_change_resource_record_sets_crud_valid():
     conn = boto3.client("route53", region_name="us-east-1")
     conn.create_hosted_zone(
         Name="db.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="db"),
     )
 
     zones = conn.list_hosted_zones_by_name(DNSName="db.")
@@ -1080,7 +911,7 @@ def test_change_resource_record_sets_crud_valid_with_special_xml_chars():
     conn.create_hosted_zone(
         Name="db.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="db"),
     )
 
     zones = conn.list_hosted_zones_by_name(DNSName="db.")
@@ -1350,7 +1181,7 @@ def test_change_resource_record_invalid():
     conn.create_hosted_zone(
         Name="db.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="db"),
     )
 
     zones = conn.list_hosted_zones_by_name(DNSName="db.")
@@ -1411,7 +1242,7 @@ def test_list_resource_record_sets_name_type_filters():
     create_hosted_zone_response = conn.create_hosted_zone(
         Name="db.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="db"),
     )
     hosted_zone_id = create_hosted_zone_response["HostedZone"]["Id"]
 
@@ -1480,7 +1311,7 @@ def test_change_resource_record_sets_records_limit():
     conn.create_hosted_zone(
         Name="db.",
         CallerReference=str(hash("foo")),
-        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+        HostedZoneConfig=dict(PrivateZone=False, Comment="db"),
     )
 
     zones = conn.list_hosted_zones_by_name(DNSName="db.")
@@ -1532,7 +1363,6 @@ def test_change_resource_record_sets_records_limit():
         "Comment": "Create four records with 250 resource records each, plus one more",
         "Changes": too_many_changes,
     }
-
     with pytest.raises(ClientError) as exc:
         conn.change_resource_record_sets(
             HostedZoneId=hosted_zone_id,
@@ -1593,3 +1423,69 @@ def test_change_resource_record_sets_records_limit():
     err = exc.value.response["Error"]
     err["Code"].should.equal("InvalidChangeBatch")
     err["Message"].should.equal("Number of records limit of 1000 exceeded.")
+
+
+@mock_route53
+def test_list_resource_recordset_pagination():
+    conn = boto3.client("route53", region_name="us-east-1")
+    conn.create_hosted_zone(
+        Name="db.",
+        CallerReference=str(hash("foo")),
+        HostedZoneConfig=dict(PrivateZone=True, Comment="db"),
+    )
+
+    zones = conn.list_hosted_zones_by_name(DNSName="db.")
+    len(zones["HostedZones"]).should.equal(1)
+    zones["HostedZones"][0]["Name"].should.equal("db.")
+    hosted_zone_id = zones["HostedZones"][0]["Id"]
+
+    # Create A Record.
+    a_record_endpoint_payload = {
+        "Comment": "Create 500 A records",
+        "Changes": [
+            {
+                "Action": "CREATE",
+                "ResourceRecordSet": {
+                    "Name": f"env{idx}.redis.db.",
+                    "Type": "A",
+                    "TTL": 10,
+                    "ResourceRecords": [{"Value": "127.0.0.1"}],
+                },
+            }
+            for idx in range(500)
+        ],
+    }
+    conn.change_resource_record_sets(
+        HostedZoneId=hosted_zone_id, ChangeBatch=a_record_endpoint_payload
+    )
+
+    response = conn.list_resource_record_sets(
+        HostedZoneId=hosted_zone_id, MaxItems="100"
+    )
+    response.should.have.key("ResourceRecordSets").length_of(100)
+    response.should.have.key("IsTruncated").equals(True)
+    response.should.have.key("MaxItems").equals("100")
+    response.should.have.key("NextRecordName").equals("env189.redis.db.")
+    response.should.have.key("NextRecordType").equals("A")
+
+    response = conn.list_resource_record_sets(
+        HostedZoneId=hosted_zone_id,
+        StartRecordName=response["NextRecordName"],
+        StartRecordType=response["NextRecordType"],
+    )
+    response.should.have.key("ResourceRecordSets").length_of(300)
+    response.should.have.key("IsTruncated").equals(True)
+    response.should.have.key("MaxItems").equals("300")
+    response.should.have.key("NextRecordName").equals("env459.redis.db.")
+    response.should.have.key("NextRecordType").equals("A")
+
+    response = conn.list_resource_record_sets(
+        HostedZoneId=hosted_zone_id,
+        StartRecordName=response["NextRecordName"],
+        StartRecordType=response["NextRecordType"],
+    )
+    response.should.have.key("ResourceRecordSets").length_of(100)
+    response.should.have.key("IsTruncated").equals(False)
+    response.should.have.key("MaxItems").equals("300")
+    response.shouldnt.have.key("NextRecordName")
+    response.shouldnt.have.key("NextRecordType")
