@@ -1,11 +1,15 @@
+import os
+
 import boto3
+from dateutil.tz import tzlocal
 
 from moto import mock_secretsmanager, mock_lambda, settings
 from moto.core import ACCOUNT_ID
 from botocore.exceptions import ClientError, ParamValidationError
 import string
 import pytz
-from datetime import datetime
+from freezegun import freeze_time
+from datetime import timedelta, datetime
 import sure  # noqa # pylint: disable=unused-import
 from uuid import uuid4
 import pytest
@@ -22,6 +26,20 @@ def test_get_secret_value():
     assert result["SecretString"] == "foosecret"
 
 
+@mock_secretsmanager
+def test_create_secret_with_client_request_token():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    create_dict = conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="secret_string",
+        ClientRequestToken=version_id,
+    )
+    assert create_dict
+    assert create_dict["VersionId"] == version_id
+
+
 @mock_secretsmanager
 def test_get_secret_value_by_arn():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -208,6 +226,25 @@ def test_delete_secret():
     assert secret_details["DeletedDate"] > datetime.fromtimestamp(1, pytz.utc)
 
 
+@mock_secretsmanager
+def test_delete_secret_by_arn():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    secret = conn.create_secret(Name="test-secret", SecretString="foosecret")
+
+    deleted_secret = conn.delete_secret(SecretId=secret["ARN"])
+
+    assert deleted_secret["ARN"] == secret["ARN"]
+    assert deleted_secret["Name"] == "test-secret"
+    assert deleted_secret["DeletionDate"] > datetime.fromtimestamp(1, pytz.utc)
+
+    secret_details = conn.describe_secret(SecretId="test-secret")
+
+    assert secret_details["ARN"] == secret["ARN"]
+    assert secret_details["Name"] == "test-secret"
+    assert secret_details["DeletedDate"] > datetime.fromtimestamp(1, pytz.utc)
+
+
 @mock_secretsmanager
 def test_delete_secret_force():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -224,6 +261,17 @@ def test_delete_secret_force():
         result = conn.get_secret_value(SecretId="test-secret")
 
 
+@mock_secretsmanager
+def test_delete_secret_force_no_such_secret():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    deleted_secret = conn.delete_secret(
+        SecretId=DEFAULT_SECRET_NAME, ForceDeleteWithoutRecovery=True
+    )
+    assert deleted_secret
+    assert deleted_secret["Name"] == DEFAULT_SECRET_NAME
+
+
 @mock_secretsmanager
 def test_delete_secret_force_with_arn():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -247,7 +295,7 @@ def test_delete_secret_that_does_not_exist():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
 
     with pytest.raises(ClientError):
-        conn.delete_secret(SecretId="i-dont-exist", ForceDeleteWithoutRecovery=True)
+        conn.delete_secret(SecretId="i-dont-exist")
 
 
 @mock_secretsmanager
@@ -284,6 +332,18 @@ def test_delete_secret_recovery_window_too_long():
         conn.delete_secret(SecretId="test-secret", RecoveryWindowInDays=31)
 
 
+@mock_secretsmanager
+def test_delete_secret_force_no_such_secret_with_invalid_recovery_window():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    with pytest.raises(ClientError):
+        conn.delete_secret(
+            SecretId=DEFAULT_SECRET_NAME,
+            ForceDeleteWithoutRecovery=True,
+            RecoveryWindowInDays=4,
+        )
+
+
 @mock_secretsmanager
 def test_delete_secret_that_is_marked_deleted():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -430,6 +490,14 @@ def test_describe_secret():
     assert secret_description["ARN"] != ""  # Test arn not empty
     assert secret_description_2["Name"] == ("test-secret-2")
     assert secret_description_2["ARN"] != ""  # Test arn not empty
+    assert secret_description["CreatedDate"] <= datetime.now(tz=tzlocal())
+    assert secret_description["CreatedDate"] > datetime.fromtimestamp(1, pytz.utc)
+    assert secret_description_2["CreatedDate"] <= datetime.now(tz=tzlocal())
+    assert secret_description_2["CreatedDate"] > datetime.fromtimestamp(1, pytz.utc)
+    assert secret_description["LastChangedDate"] <= datetime.now(tz=tzlocal())
+    assert secret_description["LastChangedDate"] > datetime.fromtimestamp(1, pytz.utc)
+    assert secret_description_2["LastChangedDate"] <= datetime.now(tz=tzlocal())
+    assert secret_description_2["LastChangedDate"] > datetime.fromtimestamp(1, pytz.utc)
 
 
 @mock_secretsmanager
@@ -681,7 +749,7 @@ def lambda_handler(event, context):
             SecretId=arn,
             ClientRequestToken=token,
             SecretString='UpdatedValue',
-            VersionStages=["AWSPENDING"],
+            VersionStages=["AWSPENDING"]
         )
 
     elif step == 'finishSecret':
@@ -695,12 +763,12 @@ def lambda_handler(event, context):
             SecretId=arn,
             VersionStage='AWSCURRENT',
             MoveToVersionId=token,
-            RemoveFromVersionId=current_version,
+            RemoveFromVersionId=current_version
         )
         client.update_secret_version_stage(
             SecretId=arn,
             VersionStage='AWSPENDING',
-            RemoveFromVersionId=token,
+            RemoveFromVersionId=token
         )
     """
     return _process_lambda(func_str)
@@ -715,7 +783,7 @@ if settings.TEST_SERVER_MODE:
 
         # Passing a `RotationLambdaARN` value to `rotate_secret` should invoke lambda
         lambda_conn = boto3.client(
-            "lambda", region_name="us-west-2", endpoint_url="http://localhost:5000",
+            "lambda", region_name="us-west-2", endpoint_url="http://localhost:5000"
         )
         func = lambda_conn.create_function(
             FunctionName="testFunction",
@@ -735,21 +803,21 @@ if settings.TEST_SERVER_MODE:
             endpoint_url="http://localhost:5000",
         )
         secret = secrets_conn.create_secret(
-            Name=DEFAULT_SECRET_NAME, SecretString="InitialValue",
+            Name=DEFAULT_SECRET_NAME, SecretString="InitialValue"
         )
         initial_version = secret["VersionId"]
 
         rotated_secret = secrets_conn.rotate_secret(
             SecretId=DEFAULT_SECRET_NAME,
             RotationLambdaARN=func["FunctionArn"],
-            RotationRules=dict(AutomaticallyAfterDays=30,),
+            RotationRules=dict(AutomaticallyAfterDays=30),
         )
 
         # Ensure we received an updated VersionId from `rotate_secret`
         assert rotated_secret["VersionId"] != initial_version
 
         updated_secret = secrets_conn.get_secret_value(
-            SecretId=DEFAULT_SECRET_NAME, VersionStage="AWSCURRENT",
+            SecretId=DEFAULT_SECRET_NAME, VersionStage="AWSCURRENT"
         )
         rotated_version = updated_secret["VersionId"]
 
@@ -940,6 +1008,166 @@ def test_can_list_secret_version_ids():
     assert [first_version_id, second_version_id].sort() == returned_version_ids.sort()
 
 
+@mock_secretsmanager
+def test_put_secret_value_version_stages_response():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # Creation.
+    first_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=first_version_id,
+    )
+
+    # Use PutSecretValue to push a new version with new version stages.
+    second_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce72"
+    second_version_stages = ["SAMPLESTAGE1", "SAMPLESTAGE0"]
+    second_put_res_dict = conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="second_secret_string",
+        VersionStages=second_version_stages,
+        ClientRequestToken=second_version_id,
+    )
+    assert second_put_res_dict
+    assert second_put_res_dict["VersionId"] == second_version_id
+    assert second_put_res_dict["VersionStages"] == second_version_stages
+
+
+@mock_secretsmanager
+def test_put_secret_value_version_stages_pending_response():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # Creation.
+    first_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString="first_secret_string",
+        ClientRequestToken=first_version_id,
+    )
+
+    # Use PutSecretValue to push a new version with new version stages.
+    second_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce72"
+    second_version_stages = ["AWSPENDING"]
+    second_put_res_dict = conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="second_secret_string",
+        VersionStages=second_version_stages,
+        ClientRequestToken=second_version_id,
+    )
+    assert second_put_res_dict
+    assert second_put_res_dict["VersionId"] == second_version_id
+    assert second_put_res_dict["VersionStages"] == second_version_stages
+
+
+@mock_secretsmanager
+def test_after_put_secret_value_version_stages_can_get_current():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # Creation.
+    first_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    first_secret_string = "first_secret_string"
+    conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString=first_secret_string,
+        ClientRequestToken=first_version_id,
+    )
+
+    # Use PutSecretValue to push a new version with new version stages.
+    second_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce72"
+    conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="second_secret_string",
+        VersionStages=["SAMPLESTAGE1", "SAMPLESTAGE0"],
+        ClientRequestToken=second_version_id,
+    )
+
+    # Get current.
+    get_dict = conn.get_secret_value(SecretId=DEFAULT_SECRET_NAME)
+    assert get_dict
+    assert get_dict["VersionId"] == first_version_id
+    assert get_dict["SecretString"] == first_secret_string
+    assert get_dict["VersionStages"] == ["AWSCURRENT"]
+
+
+@mock_secretsmanager
+def test_after_put_secret_value_version_stages_can_get_current_with_custom_version_stage():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # Creation.
+    first_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    first_secret_string = "first_secret_string"
+    conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString=first_secret_string,
+        ClientRequestToken=first_version_id,
+    )
+
+    # Use PutSecretValue to push a new version with new version stages.
+    second_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce72"
+    conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="second_secret_string",
+        VersionStages=["SAMPLESTAGE1", "SAMPLESTAGE0"],
+        ClientRequestToken=second_version_id,
+    )
+    # Create a third version with one of the old stages
+    third_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce73"
+    third_secret_string = "third_secret_string"
+    conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString=third_secret_string,
+        VersionStages=["SAMPLESTAGE1"],
+        ClientRequestToken=third_version_id,
+    )
+
+    # Get current with the stage label of the third version.
+    get_dict = conn.get_secret_value(
+        SecretId=DEFAULT_SECRET_NAME, VersionStage="SAMPLESTAGE1"
+    )
+    versions = conn.list_secret_version_ids(SecretId=DEFAULT_SECRET_NAME)["Versions"]
+    versions_by_key = {version["VersionId"]: version for version in versions}
+    # Check if indeed the third version is returned
+    assert get_dict
+    assert get_dict["VersionId"] == third_version_id
+    assert get_dict["SecretString"] == third_secret_string
+    assert get_dict["VersionStages"] == ["SAMPLESTAGE1"]
+    # Check if all the versions have the proper labels
+    assert versions_by_key[first_version_id]["VersionStages"] == ["AWSCURRENT"]
+    assert versions_by_key[second_version_id]["VersionStages"] == ["SAMPLESTAGE0"]
+    assert versions_by_key[third_version_id]["VersionStages"] == ["SAMPLESTAGE1"]
+
+
+@mock_secretsmanager
+def test_after_put_secret_value_version_stages_pending_can_get_current():
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # Creation.
+    first_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce71"
+    first_secret_string = "first_secret_string"
+    conn.create_secret(
+        Name=DEFAULT_SECRET_NAME,
+        SecretString=first_secret_string,
+        ClientRequestToken=first_version_id,
+    )
+
+    # Use PutSecretValue to push a new version with new version stages.
+    pending_version_id = "eb41453f-25bb-4025-b7f4-850cfca0ce72"
+    conn.put_secret_value(
+        SecretId=DEFAULT_SECRET_NAME,
+        SecretString="second_secret_string",
+        VersionStages=["AWSPENDING"],
+        ClientRequestToken=pending_version_id,
+    )
+
+    # Get current.
+    get_dict = conn.get_secret_value(SecretId=DEFAULT_SECRET_NAME)
+    assert get_dict
+    assert get_dict["VersionId"] == first_version_id
+    assert get_dict["SecretString"] == first_secret_string
+    assert get_dict["VersionStages"] == ["AWSCURRENT"]
+
+
 @mock_secretsmanager
 @pytest.mark.parametrize("pass_arn", [True, False])
 def test_update_secret(pass_arn):
@@ -967,6 +1195,35 @@ def test_update_secret(pass_arn):
     assert created_secret["VersionId"] != updated_secret["VersionId"]
 
 
+@mock_secretsmanager
+@pytest.mark.parametrize("pass_arn", [True, False])
+def test_update_secret_updates_last_changed_dates(pass_arn):
+    conn = boto3.client("secretsmanager", region_name="us-west-2")
+
+    # create a secret
+    created_secret = conn.create_secret(Name="test-secret", SecretString="foosecret")
+    secret_id = created_secret["ARN"] if pass_arn else "test-secret"
+
+    # save details for secret before modification
+    secret_details_1 = conn.describe_secret(SecretId=secret_id)
+    # check if only LastChangedDate changed, CreatedDate should stay the same
+    with freeze_time(timedelta(minutes=1)):
+        conn.update_secret(SecretId="test-secret", Description="new-desc")
+        secret_details_2 = conn.describe_secret(SecretId=secret_id)
+        assert secret_details_1["CreatedDate"] == secret_details_2["CreatedDate"]
+        if os.environ.get("TEST_SERVER_MODE", "false").lower() == "false":
+            assert (
+                secret_details_1["LastChangedDate"]
+                < secret_details_2["LastChangedDate"]
+            )
+        else:
+            # Can't manipulate time in server mode, so use weaker constraints here
+            assert (
+                secret_details_1["LastChangedDate"]
+                <= secret_details_2["LastChangedDate"]
+            )
+
+
 @mock_secretsmanager
 def test_update_secret_with_tags_and_description():
     conn = boto3.client("secretsmanager", region_name="us-west-2")
@@ -1090,23 +1347,25 @@ def test_tag_resource(pass_arn):
     created_secret = conn.create_secret(Name="test-secret", SecretString="foosecret")
     secret_id = created_secret["ARN"] if pass_arn else "test-secret"
     conn.tag_resource(
-        SecretId=secret_id, Tags=[{"Key": "FirstTag", "Value": "SomeValue"},],
+        SecretId=secret_id, Tags=[{"Key": "FirstTag", "Value": "SomeValue"}]
     )
-
     conn.tag_resource(
-        SecretId=secret_id, Tags=[{"Key": "SecondTag", "Value": "AnotherValue"},],
+        SecretId="test-secret", Tags=[{"Key": "FirstTag", "Value": "SomeOtherValue"}]
+    )
+    conn.tag_resource(
+        SecretId=secret_id, Tags=[{"Key": "SecondTag", "Value": "AnotherValue"}]
     )
 
     secrets = conn.list_secrets()
     assert secrets["SecretList"][0].get("Tags") == [
-        {"Key": "FirstTag", "Value": "SomeValue"},
+        {"Key": "FirstTag", "Value": "SomeOtherValue"},
         {"Key": "SecondTag", "Value": "AnotherValue"},
     ]
 
     with pytest.raises(ClientError) as cm:
         conn.tag_resource(
             SecretId="dummy-test-secret",
-            Tags=[{"Key": "FirstTag", "Value": "SomeValue"},],
+            Tags=[{"Key": "FirstTag", "Value": "SomeValue"}],
         )
 
     assert (
@@ -1136,9 +1395,7 @@ def test_untag_resource(pass_arn):
     ]
 
     with pytest.raises(ClientError) as cm:
-        conn.untag_resource(
-            SecretId="dummy-test-secret", TagKeys=["FirstTag"],
-        )
+        conn.untag_resource(SecretId="dummy-test-secret", TagKeys=["FirstTag"])
 
     assert (
         "Secrets Manager can't find the specified secret."
@@ -1189,7 +1446,7 @@ def test_update_secret_with_client_request_token():
     )
     assert client_request_token == updated_secret["VersionId"]
     updated_secret = client.update_secret(
-        SecretId=secret_name, SecretString="third-secret",
+        SecretId=secret_name, SecretString="third-secret"
     )
     assert client_request_token != updated_secret["VersionId"]
     invalid_request_token = "test-token"
