@@ -55,14 +55,14 @@ def test_describe_stack_subresources():
     template_body = simple_queue.substitute(q_name=q_name)
     cf.create_stack(StackName=stack_name, TemplateBody=template_body)
 
-    queue_urls = client.list_queues()["QueueUrls"]
+    queue_urls = client.list_queues(QueueNamePrefix=q_name)["QueueUrls"]
     assert any(["{}/{}".format(ACCOUNT_ID, q_name) in url for url in queue_urls])
 
     stack = res.Stack(stack_name)
     for s in stack.resource_summaries.all():
         s.resource_type.should.equal("AWS::SQS::Queue")
         s.logical_id.should.equal("QueueGroup")
-        s.physical_resource_id.should.equal(q_name)
+        s.physical_resource_id.should.contain(f"/{q_name}")
 
 
 @mock_sqs
@@ -76,14 +76,15 @@ def test_list_stack_resources():
     template_body = simple_queue.substitute(q_name=q_name)
     cf.create_stack(StackName=stack_name, TemplateBody=template_body)
 
-    queue_urls = client.list_queues()["QueueUrls"]
+    queue_urls = client.list_queues(QueueNamePrefix=q_name)["QueueUrls"]
     assert any(["{}/{}".format(ACCOUNT_ID, q_name) in url for url in queue_urls])
 
     queue = cf.list_stack_resources(StackName=stack_name)["StackResourceSummaries"][0]
 
     queue.should.have.key("ResourceType").equal("AWS::SQS::Queue")
     queue.should.have.key("LogicalResourceId").should.equal("QueueGroup")
-    queue.should.have.key("PhysicalResourceId").should.equal(q_name)
+    expected_url = f"https://sqs.us-east-1.amazonaws.com/{ACCOUNT_ID}/{q_name}"
+    queue.should.have.key("PhysicalResourceId").should.equal(expected_url)
 
 
 @mock_sqs
@@ -96,9 +97,9 @@ def test_create_from_cloudformation_json_with_tags():
     cf.create_stack(StackName=stack_name, TemplateBody=sqs_template_with_tags)
 
     response = cf.describe_stack_resources(StackName=stack_name)
-    q_name = response["StackResources"][0]["PhysicalResourceId"]
+    q_name = response["StackResources"][0]["PhysicalResourceId"].split("/")[-1]
 
-    all_urls = client.list_queues()["QueueUrls"]
+    all_urls = client.list_queues(QueueNamePrefix=q_name)["QueueUrls"]
     queue_url = [url for url in all_urls if url.endswith(q_name)][0]
 
     queue_tags = client.list_queue_tags(QueueUrl=queue_url)["Tags"]
