@@ -188,7 +188,7 @@ def test_state_machine_list_returns_empty_list_by_default():
     client = boto3.client("stepfunctions", region_name=region)
     #
     sm_list = client.list_state_machines()
-    sm_list["stateMachines"].should.be.empty
+    sm_list["stateMachines"].should.equal([])
 
 
 @mock_stepfunctions
@@ -358,9 +358,7 @@ def test_state_machine_can_deleted_nonexisting_machine():
 @mock_stepfunctions
 def test_state_machine_tagging_non_existent_resource_fails():
     client = boto3.client("stepfunctions", region_name=region)
-    non_existent_arn = "arn:aws:states:{region}:{account}:stateMachine:non-existent".format(
-        region=region, account=ACCOUNT_ID
-    )
+    non_existent_arn = f"arn:aws:states:{region}:{ACCOUNT_ID}:stateMachine:non-existent"
     with pytest.raises(ClientError) as ex:
         client.tag_resource(resourceArn=non_existent_arn, tags=[])
     ex.value.response["Error"]["Code"].should.equal("ResourceNotFound")
@@ -370,9 +368,7 @@ def test_state_machine_tagging_non_existent_resource_fails():
 @mock_stepfunctions
 def test_state_machine_untagging_non_existent_resource_fails():
     client = boto3.client("stepfunctions", region_name=region)
-    non_existent_arn = "arn:aws:states:{region}:{account}:stateMachine:non-existent".format(
-        region=region, account=ACCOUNT_ID
-    )
+    non_existent_arn = f"arn:aws:states:{region}:{ACCOUNT_ID}:stateMachine:non-existent"
     with pytest.raises(ClientError) as ex:
         client.untag_resource(resourceArn=non_existent_arn, tagKeys=[])
     ex.value.response["Error"]["Code"].should.equal("ResourceNotFound")
@@ -388,7 +384,7 @@ def test_state_machine_tagging():
         {"key": "tag_key2", "value": "tag_value2"},
     ]
     machine = client.create_state_machine(
-        name="test", definition=str(simple_definition), roleArn=_get_default_role(),
+        name="test", definition=str(simple_definition), roleArn=_get_default_role()
     )
     client.tag_resource(resourceArn=machine["stateMachineArn"], tags=tags)
     resp = client.list_tags_for_resource(resourceArn=machine["stateMachineArn"])
@@ -710,7 +706,7 @@ def test_state_machine_describe_execution_with_no_input():
     description["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     description["executionArn"].should.equal(execution["executionArn"])
     description["input"].should.equal("{}")
-    description["name"].shouldnt.be.empty
+    description["name"].should.match("[-0-9a-z]+")
     description["startDate"].should.equal(execution["startDate"])
     description["stateMachineArn"].should.equal(sm["stateMachineArn"])
     description["status"].should.equal("RUNNING")
@@ -734,7 +730,7 @@ def test_state_machine_describe_execution_with_custom_input():
     description["ResponseMetadata"]["HTTPStatusCode"].should.equal(200)
     description["executionArn"].should.equal(execution["executionArn"])
     description["input"].should.equal(execution_input)
-    description["name"].shouldnt.be.empty
+    description["name"].should.match("[-a-z0-9]+")
     description["startDate"].should.equal(execution["startDate"])
     description["stateMachineArn"].should.equal(sm["stateMachineArn"])
     description["status"].should.equal("RUNNING")
