@@ -1,7 +1,6 @@
 from base64 import b64encode
 import json
 
-import boto
 import boto3
 from botocore.client import ClientError
 from datetime import datetime
@@ -9,26 +8,11 @@ from freezegun import freeze_time
 import pytest
 import sure  # noqa # pylint: disable=unused-import
 
-from moto import mock_sts, mock_sts_deprecated, mock_iam, settings
+from moto import mock_sts, mock_iam, settings
 from moto.core import ACCOUNT_ID
 from moto.sts.responses import MAX_FEDERATION_TOKEN_POLICY_LENGTH
 
 
-# Has boto3 equivalent
-@freeze_time("2012-01-01 12:00:00")
-@mock_sts_deprecated
-def test_get_session_token():
-    conn = boto.connect_sts()
-    token = conn.get_session_token(duration=123)
-
-    token.expiration.should.equal("2012-01-01T12:02:03.000Z")
-    token.session_token.should.equal(
-        "AQoEXAMPLEH4aoAH0gNCAPyJxz4BlCFFxWNE1OPTgk5TthT+FvwqnKwRcOIfrRh3c/LTo6UDdyJwOOvEVPvLXCrrrUtdnniCEXAMPLE/IvU1dYUg2RVAJBanLiHb4IgRmpRV3zrkuWJOgQs8IZZaIv2BXIa2R4OlgkBN9bkUDNCJiBeb/AXlzBBko7b15fjrBs2+cTQtpZ3CYWFXG8C5zqx37wnOE49mRl/+OtkIKGO7fAE"
-    )
-    token.access_key.should.equal("AKIAIOSFODNN7EXAMPLE")
-    token.secret_key.should.equal("wJalrXUtnFEMI/K7MDENG/bPxRfiCYzEXAMPLEKEY")
-
-
 @freeze_time("2012-01-01 12:00:00")
 @mock_sts
 def test_get_session_token_boto3():
@@ -47,30 +31,6 @@ def test_get_session_token_boto3():
     creds["SecretAccessKey"].should.equal("wJalrXUtnFEMI/K7MDENG/bPxRfiCYzEXAMPLEKEY")
 
 
-# Has boto3 equivalent
-@freeze_time("2012-01-01 12:00:00")
-@mock_sts_deprecated
-def test_get_federation_token():
-    conn = boto.connect_sts()
-    token_name = "Bob"
-    token = conn.get_federation_token(duration=123, name=token_name)
-
-    token.credentials.expiration.should.equal("2012-01-01T12:02:03.000Z")
-    token.credentials.session_token.should.equal(
-        "AQoDYXdzEPT//////////wEXAMPLEtc764bNrC9SAPBSM22wDOk4x4HIZ8j4FZTwdQWLWsKWHGBuFqwAeMicRXmxfpSPfIeoIYRqTflfKD8YUuwthAx7mSEI/qkPpKPi/kMcGdQrmGdeehM4IC1NtBmUpp2wUE8phUZampKsburEDy0KPkyQDYwT7WZ0wq5VSXDvp75YU9HFvlRd8Tx6q6fE8YQcHNVXAkiY9q6d+xo0rKwT38xVqr7ZD0u0iPPkUL64lIZbqBAz+scqKmlzm8FDrypNC9Yjc8fPOLn9FX9KSYvKTr4rvx3iSIlTJabIQwj2ICCR/oLxBA=="
-    )
-    token.credentials.access_key.should.equal("AKIAIOSFODNN7EXAMPLE")
-    token.credentials.secret_key.should.equal(
-        "wJalrXUtnFEMI/K7MDENG/bPxRfiCYzEXAMPLEKEY"
-    )
-    token.federated_user_arn.should.equal(
-        "arn:aws:sts::{account_id}:federated-user/{token_name}".format(
-            account_id=ACCOUNT_ID, token_name=token_name
-        )
-    )
-    token.federated_user_id.should.equal(str(ACCOUNT_ID) + ":" + token_name)
-
-
 @freeze_time("2012-01-01 12:00:00")
 @mock_sts
 def test_get_federation_token_boto3():
@@ -651,49 +611,6 @@ def test_assume_role_with_saml_should_default_session_duration_to_3600_seconds_w
         credentials["Expiration"].isoformat().should.equal("2012-01-01T13:00:00+00:00")
 
 
-# Has boto3 equivalent
-@freeze_time("2012-01-01 12:00:00")
-@mock_sts_deprecated
-def test_assume_role_with_web_identity():
-    conn = boto.connect_sts()
-
-    policy = json.dumps(
-        {
-            "Statement": [
-                {
-                    "Sid": "Stmt13690092345534",
-                    "Action": ["S3:ListBucket"],
-                    "Effect": "Allow",
-                    "Resource": ["arn:aws:s3:::foobar-tester"],
-                }
-            ]
-        }
-    )
-    role_name = "test-role"
-    s3_role = "arn:aws:iam::{account_id}:role/{role_name}".format(
-        account_id=ACCOUNT_ID, role_name=role_name
-    )
-    session_name = "session-name"
-    role = conn.assume_role_with_web_identity(
-        s3_role, session_name, policy, duration_seconds=123
-    )
-
-    credentials = role.credentials
-    credentials.expiration.should.equal("2012-01-01T12:02:03.000Z")
-    credentials.session_token.should.have.length_of(356)
-    assert credentials.session_token.startswith("FQoGZXIvYXdzE")
-    credentials.access_key.should.have.length_of(20)
-    assert credentials.access_key.startswith("ASIA")
-    credentials.secret_key.should.have.length_of(40)
-
-    role.user.arn.should.equal(
-        "arn:aws:sts::{account_id}:assumed-role/{role_name}/{session_name}".format(
-            account_id=ACCOUNT_ID, role_name=role_name, session_name=session_name
-        )
-    )
-    role.user.assume_role_id.should.contain("session-name")
-
-
 @freeze_time("2012-01-01 12:00:00")
 @mock_sts
 def test_assume_role_with_web_identity_boto3():
