@@ -1,28 +1,12 @@
-import boto
-from boto.swf.exceptions import SWFResponseError
 import boto3
 from botocore.exceptions import ClientError
 import sure  # noqa # pylint: disable=unused-import
 import pytest
 
-from moto import mock_swf_deprecated
 from moto import mock_swf
 
 
 # RegisterActivityType endpoint
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_register_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "test-activity", "v1.0")
-
-    types = conn.list_activity_types("test-domain", "REGISTERED")
-    actype = types["typeInfos"][0]
-    actype["activityType"]["name"].should.equal("test-activity")
-    actype["activityType"]["version"].should.equal("v1.0")
-
-
 @mock_swf
 def test_register_activity_type_boto3():
     client = boto3.client("swf", region_name="us-west-2")
@@ -42,18 +26,6 @@ def test_register_activity_type_boto3():
     actype["activityType"]["version"].should.equal("v1.0")
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_register_already_existing_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "test-activity", "v1.0")
-
-    conn.register_activity_type.when.called_with(
-        "test-domain", "test-activity", "v1.0"
-    ).should.throw(SWFResponseError)
-
-
 @mock_swf
 def test_register_already_existing_activity_type_boto3():
     client = boto3.client("swf", region_name="us-west-2")
@@ -75,33 +47,7 @@ def test_register_already_existing_activity_type_boto3():
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_register_with_wrong_parameter_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-
-    conn.register_activity_type.when.called_with(
-        "test-domain", "test-activity", 12
-    ).should.throw(SWFResponseError)
-
-
 # ListActivityTypes endpoint
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_list_activity_types():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "b-test-activity", "v1.0")
-    conn.register_activity_type("test-domain", "a-test-activity", "v1.0")
-    conn.register_activity_type("test-domain", "c-test-activity", "v1.0")
-
-    all_activity_types = conn.list_activity_types("test-domain", "REGISTERED")
-    names = [
-        activity_type["activityType"]["name"]
-        for activity_type in all_activity_types["typeInfos"]
-    ]
-    names.should.equal(["a-test-activity", "b-test-activity", "c-test-activity"])
 
 
 # ListActivityTypes endpoint
@@ -130,25 +76,6 @@ def test_list_activity_types_boto3():
     names.should.equal(["a-test-activity", "b-test-activity", "c-test-activity"])
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_list_activity_types_reverse_order():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "b-test-activity", "v1.0")
-    conn.register_activity_type("test-domain", "a-test-activity", "v1.0")
-    conn.register_activity_type("test-domain", "c-test-activity", "v1.0")
-
-    all_activity_types = conn.list_activity_types(
-        "test-domain", "REGISTERED", reverse_order=True
-    )
-    names = [
-        activity_type["activityType"]["name"]
-        for activity_type in all_activity_types["typeInfos"]
-    ]
-    names.should.equal(["c-test-activity", "b-test-activity", "a-test-activity"])
-
-
 @mock_swf
 def test_list_activity_types_reverse_order_boto3():
     client = boto3.client("swf", region_name="us-west-2")
@@ -175,21 +102,6 @@ def test_list_activity_types_reverse_order_boto3():
     names.should.equal(["c-test-activity", "b-test-activity", "a-test-activity"])
 
 
-# DeprecateActivityType endpoint
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_deprecate_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "test-activity", "v1.0")
-    conn.deprecate_activity_type("test-domain", "test-activity", "v1.0")
-
-    actypes = conn.list_activity_types("test-domain", "DEPRECATED")
-    actype = actypes["typeInfos"][0]
-    actype["activityType"]["name"].should.equal("test-activity")
-    actype["activityType"]["version"].should.equal("v1.0")
-
-
 # DeprecateActivityType endpoint
 @mock_swf
 def test_deprecate_activity_type_boto3():
@@ -213,19 +125,6 @@ def test_deprecate_activity_type_boto3():
     actype["activityType"]["version"].should.equal("v1.0")
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_deprecate_already_deprecated_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type("test-domain", "test-activity", "v1.0")
-    conn.deprecate_activity_type("test-domain", "test-activity", "v1.0")
-
-    conn.deprecate_activity_type.when.called_with(
-        "test-domain", "test-activity", "v1.0"
-    ).should.throw(SWFResponseError)
-
-
 @mock_swf
 def test_deprecate_already_deprecated_activity_type_boto3():
     client = boto3.client("swf", region_name="us-west-2")
@@ -251,17 +150,6 @@ def test_deprecate_already_deprecated_activity_type_boto3():
     ex.value.response["ResponseMetadata"]["HTTPStatusCode"].should.equal(400)
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_deprecate_non_existent_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-
-    conn.deprecate_activity_type.when.called_with(
-        "test-domain", "non-existent", "v1.0"
-    ).should.throw(SWFResponseError)
-
-
 @mock_swf
 def test_deprecate_non_existent_activity_type_boto3():
     client = boto3.client("swf", region_name="us-west-2")
@@ -353,27 +241,6 @@ def test_undeprecate_non_existent_activity_type():
 
 
 # DescribeActivityType endpoint
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_describe_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-    conn.register_activity_type(
-        "test-domain",
-        "test-activity",
-        "v1.0",
-        task_list="foo",
-        default_task_heartbeat_timeout="32",
-    )
-
-    actype = conn.describe_activity_type("test-domain", "test-activity", "v1.0")
-    actype["configuration"]["defaultTaskList"]["name"].should.equal("foo")
-    infos = actype["typeInfo"]
-    infos["activityType"]["name"].should.equal("test-activity")
-    infos["activityType"]["version"].should.equal("v1.0")
-    infos["status"].should.equal("REGISTERED")
-
-
 @mock_swf
 def test_describe_activity_type_boto3():
     client = boto3.client("swf", region_name="us-east-1")
@@ -398,17 +265,6 @@ def test_describe_activity_type_boto3():
     infos["status"].should.equal("REGISTERED")
 
 
-# Has boto3 equivalent
-@mock_swf_deprecated
-def test_describe_non_existent_activity_type():
-    conn = boto.connect_swf("the_key", "the_secret")
-    conn.register_domain("test-domain", "60")
-
-    conn.describe_activity_type.when.called_with(
-        "test-domain", "non-existent", "v1.0"
-    ).should.throw(SWFResponseError)
-
-
 @mock_swf
 def test_describe_non_existent_activity_type_boto3():
     client = boto3.client("swf", region_name="us-east-1")
