@@ -1,4 +1,4 @@
-from moto import mock_xray_client, XRaySegment, mock_dynamodb2
+from moto import mock_xray_client, XRaySegment, mock_dynamodb
 import sure  # noqa # pylint: disable=unused-import
 import boto3
 
@@ -12,14 +12,14 @@ import botocore.endpoint
 original_make_api_call = botocore.client.BaseClient._make_api_call
 original_encode_headers = botocore.endpoint.Endpoint._encode_headers
 
-import requests
+import requests  # noqa # pylint: disable=all
 
 original_session_request = requests.Session.request
 original_session_prep_request = requests.Session.prepare_request
 
 
 @mock_xray_client
-@mock_dynamodb2
+@mock_dynamodb
 def test_xray_dynamo_request_id():
     # Could be ran in any order, so we need to tell sdk that its been unpatched
     xray_core_patcher._PATCHED_MODULES = set()
@@ -48,7 +48,7 @@ def test_xray_dynamo_request_id():
 def test_xray_dynamo_request_id_with_context_mgr():
     with mock_xray_client():
         assert isinstance(xray_core.xray_recorder._emitter, MockEmitter)
-        with mock_dynamodb2():
+        with mock_dynamodb():
             # Could be ran in any order, so we need to tell sdk that its been unpatched
             xray_core_patcher._PATCHED_MODULES = set()
             xray_core.patch_all()
